/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 03404
 |       DRUG ABUSE TREATMENT OUTCOME STUDY--ADOLESCENT (DATOS-A),
 |                       1993-1995: [UNITED STATES]
 |               (DATASET 0003:  1-MONTH INTREATMENT DATA)
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 03404-0003-statasetup.do)
 |
 **************************************************************************/

set mem 20m  /* Allocating 20 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "Drug Abuse Treatment Outcome Study--Adolescent (DATOS-A), 1993-1995: [United States], Dataset 0003"

#delimit ;
label define CASEID    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EDC_M     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "JAN. - MARCH" 2 "APR. - JUNE" 3 "JULY - SEPT."
                       4 "OCT. - DEC." ;
label define EDC_Y     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ET_L_I    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ETIME1_H  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ETIME1_M  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EAM_PM_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "AM"
                       2 "PM" ;
label define EA3       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EA3_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PUERTO RICAN" 2 "MEXICAN" 3 "CUBAN" 4 "CARIBBEAN"
                       5 "CENTRAL AMERICAN" 6 "SOUTH AMERICAN"
                       7 "OTHER/ETHNIC BACKGROUND" 15 "MIXED" ;
label define EA3_B     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "BLACK/AFRICAN AMERICAN" 5 "WHITE/CAUCASIAN"
                       6 "OTHER" ;
label define EA4       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "BLACK/AFRICAN AMERICAN" 5 "WHITE/CAUCASIAN"
                       6 "OTHER" ;
label define EA5       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "ONE FAMILY HOUSE/DUPLEX/CONDO"
                       2 "A MOBILE HOME/TRAILER"
                       3 "APARTMENT/MULTIPLE FAMILY BUILDING"
                       4 "HOTEL/ROOMING HOUSE/BOARDING HOUSE"
                       5 "HOSPITAL/MEDICAL INSTITUTION"
                       6 "JAIL/PRISON/JUVENILE DETENTION HOME"
                       7 "RESIDENTIAL DRUG TREAT CTR"
                       8 "OTHER GROUP RESIDENCE/HALFWAY HOUSE"
                       9 "IN A HOMELESS SHELTER"
                       10 "ON THE STREET/NO REGULAR PLACE" 11 "OTHER" ;
label define EA6       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       99 "99 OR MORE" ;
label define EA7       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "MARRIED" 2 "SEPARATED" 3 "DIVORCED" 4 "WIDOWED"
                       5 "LIVE/W/SOMEONE AS MARRIED" 6 "NEVER MARRIED" ;
label define EA8       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "HAS BEEN VERY MUCH OPPOSED"
                       2 "HAS BEEN SOMEWHAT OPPOSED"
                       3 "HAS NOT CARED ONE WAY/OTHER"
                       4 "APPROVED OF YOUR USE OF DRUGS"
                       5 "HAS NOT AWARE OF YOUR DRUG USE"
                       6 "NOT IN CONTACT WITH PARTNER" ;
label define EA8_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "NOT AT ALL" 2 "SOMEWHAT" 3 "VERY IMPORTANT" ;
label define EA8_B     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EA8_C     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EA8_D     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EA8_E     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EA9       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY MUCH" ;
label define EA10      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "WITH SPOUSE/SEXUAL PARTNER/CHILDREN"
                       2 "WITH SPOUSE/SEXUAL PARTNER ONLY"
                       3 "WITH CHILDREN ONLY" 4 "WITH BOTH PARENTS"
                       5 "WITH MOTHER ONLY" 6 "WITH FATHER ONLY"
                       7 "WITH PARENT(S) AND OWN CHILDREN"
                       8 "WITH OTHER FAMILY/ANY COMB 01 - 07"
                       9 "WITH FOSTER PARENTS"
                       10 "W/FAMILY/FRIENDS/BOARDERS/ROOMMATES"
                       11 "W/FRIENDS/ROOMMATES ONLY" 12 "ALONE"
                       13 "INSTITUTION/CLOSED FACILITY/HOSP"
                       14 "NO STABLE ARRANGEMENTS" 15 "OTHER" ;
label define EA11      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "VERY DISSATISFIED" 2 "SOMEWHAT DISSATISFIED"
                       3 "SOMEWHAT SATISFIED" 4 "VERY SATISFIED" ;
label define EA12      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 6 "6+" ;
label define EA13      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 6 "6+" ;
label define EA13A_02  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EA13A_03  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EA13A_04  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EA13A_05  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EA13A_06  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EA14      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EA14A_02  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EA14A_03  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EA14A_04  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EA14A_05  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EA14A_06  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EA15_00   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "CIRCLED" ;
label define EA15_01   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EA15_02   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EA15_03   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EA16      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" 3 "SOMEWHAT/MAYBE" ;
label define EA17      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "POOR"
                       2 "FAIR" 3 "WELL" ;
label define EA18      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY DIFFICULT" ;
label define EA19      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EA19_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EA19_B    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EA20      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY IMPORTANT" ;
label define EA21      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "SOME" 2 "A LOT" 93 "IF VOL: NO FAMILY/FRIENDS" ;
label define EA22      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "POOR"
                       2 "FAIR" 3 "WELL" ;
label define EA23_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "NOT AT ALL" 2 "LESS ONCE A WEEK"
                       3 "AT LEAST ONCE A WEEK" 4 "ALMOST DAILY" ;
label define EA23_B    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "NOT AT ALL" 2 "LESS ONCE A WEEK"
                       3 "AT LEAST ONCE A WEEK" 4 "ALMOST DAILY" ;
label define EA23_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "NOT AT ALL" 2 "LESS ONCE A WEEK"
                       3 "AT LEAST ONCE A WEEK" 4 "ALMOST DAILY" ;
label define EA24_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "NONE"
                       2 "ONE OR A FEW" 3 "MANY" ;
label define EA24_B    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "NONE"
                       2 "ONE OR A FEW" 3 "MANY" ;
label define EA24_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "NONE"
                       2 "ONE OR A FEW" 3 "MANY" ;
label define EA24_D    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "NONE"
                       2 "ONE OR A FEW" 3 "MANY" ;
label define EA24_E    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "NONE"
                       2 "ONE OR A FEW" 3 "MANY" ;
label define EA24_F    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "NONE"
                       2 "ONE OR A FEW" 3 "MANY" ;
label define EA25      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "VERY UNHAPPY" 2 "SOMEWHAT UNHAPPY"
                       3 "SOMEWHAT HAPPY" 4 "VERY HAPPY" ;
label define EA26      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "WORSE"
                       2 "BETTER" ;
label define EA27      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EA27A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "NOT AT ALL" 2 "SOMEWHAT" 3 "VERY SERIOUS" ;
label define EB1       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EB1_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EB1_B     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EB1_C     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "MIDDLE SCHOOL (JUNIOR HIGH)" 2 "HIGH SCHOOL"
                       3 "JUNIOR (2-YEAR) COLLEGE"
                       4 "4-YEAR COLLEGE OR UNIVERSITY"
                       5 "TECHNICAL/TRADE/VOCATIONAL SCHOOL"
                       6 "JOB CORPS PROGRAM" 7 "SPECIAL EDUCATION PROGRAM"
                       8 "OTHER" ;
label define EB1_D     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "BETTER THAN AVERAGE" 2 "AVERAGE" 3 "NOT SO GOOD" ;
label define EB1_E     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "DID AS WELL AS COULD"
                       2 "COULD HAVE DONE MUCH BETTER" ;
label define EB1_F     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EB1_G     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EB2       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EB2_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "DIPLOMA" 2 "GED" ;
label define EB3_0     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "CIRCLED" ;
label define EB3_1     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EB3_2     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EB3_3     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EB3_4     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EB3_5     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EB3_6     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EB4       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EB4_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "EXPIRED" 2 "SUSPENDED" 3 "REVOKED"
                       4 "IF VOL: NEVER HAD ONE" ;
label define EB5       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NONE OF THE TIME" 1 "SOME OF THE TIME"
                       2 "ALL OF THE TIME" ;
label define EC1       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EC1_A_02  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EC1_A_03  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EC1_A_04  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EC1_A_05  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EC1_A_06  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EC1_A_07  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define EC1_B     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "OWN NAME" 2 "OTHER FAMILY MEMBER" ;
label define EC1_C     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" 3 "PROGRAM CHARGES NO FEES" ;
label define EC1_D     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "LESS THAN HALF" 2 "HALF OR MORE" 3 "ALL"
                       4 "PROG CHARGES NO FEES" ;
label define EC1_E     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "SELF PAY" 2 "FAMILY/RELATIVES"
                       3 "WORKER'S COMPENSATION" 4 "OTHER" ;
label define EC2       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "LIVING AT PROGRAM" 1 "WALK" 2 "DRIVE"
                       3 "PUBLIC TRANSPORTATION" 4 "RIDE FROM FAMILY/FRIEND"
                       5 "TAXI CAB" 6 "PROG PROVIDED TRANSPORTATION"
                       7 "OTHER" ;
label define EC3       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "EASY"
                       2 "DIFFICULT" ;
label define EC3_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "SOMEWHAT EASY" 2 "VERY EASY" ;
label define EC3_B     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "SOMEWHAT DIFFICULT" 2 "VERY DIFFICULT" ;
label define EC4_00    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "CIRCLED" ;
label define EC4_01    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EC4_02    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EC4_03    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EC4_04    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EC4_05    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EC4_06    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EC4_07    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define EC4_08    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       8 "CIRCLED" ;
label define EC4_09    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       9 "CIRCLED" ;
label define EC5       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" 3 "UNCERTAIN" ;
label define EC5_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EC6       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EC6_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "REQUIRED, STIPULATED" 2 "SUGGESTED, ENCOURAGED" ;
label define EC7       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EC7_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "REGULAR" 2 "RANDOM" 3 "BOTH" ;
label define EC7_B_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EC7_B_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PER WEEK" 2 "PER MONTH" 3 "TOTAL/ALTOGETHER" ;
label define ED1       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ED1_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ED2       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ED2_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ED2_B     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ED2_C_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONE WEEK AFTER ADMISSION"
                       2 "AT LEAST ONE WEEK AFTER ADMISSION" ;
label define ED2_C_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ED2_D     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ED3       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ED3_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ED4       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ED4_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ED5       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ED5_A_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONE WEEK AFTER ADMISSION"
                       2 "AT LEAST ONE WEEK AFTER ADMISSION" ;
label define ED5_A_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ED5_B     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ED6       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ED6_A_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONE WEEK AFTER ADMISSION"
                       2 "AT LEAST ONE WEEK AFTER ADMISSION" ;
label define ED6_A_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ED6_B     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ED7       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ED7_A_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONE WEEK AFTER ADMISSION"
                       2 "AT LEAST ONE WEEK AFTER ADMISSION" ;
label define ED7_A_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ED7_B     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ED8       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ED8_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ED9       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ED10      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ED10_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ED11      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ED11_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "NOT AT ALL" 2 "SOMEWHAT" 3 "VERY SERIOUS" ;
label define ED12      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY TROUBLED" ;
label define ED13      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define ED14      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define ED15      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define ED16      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define ED17      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define ED18      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define ED19      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY IMPORTANT" ;
label define EE1       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE2       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE3       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EE4       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE5       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EE6       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EE7       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY TROUBLED" ;
label define EE8       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY IMPORTANT" ;
label define EE9       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "VERY POOR" 2 "FAIR" 3 "VERY GOOD" ;
label define EE10      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY DIFFICULT" ;
label define EE11      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "VERY POOR" 2 "FAIR" 3 "VERY GOOD" ;
label define EE12      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EE12_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN 1/2 PACK A DAY" 2 "ABOUT 1/2 PACK A DAY"
                       3 "ABOUT A PACK A DAY" 4 "ABOUT 1-1/2 PACKS A DAY"
                       5 "ABOUT 2 PACKS OR MORE A DAY" ;
label define EE13      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EE13_A_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EE13_A_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EE13_A_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EE14      1 "YES" 2 "NO" ;
label define EE14_A_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONE WEEK AFTER ADMISSION"
                       2 "AT LEAST ONE WEEK AFTER ADMISSION" ;
label define EE14_A_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE14_B_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "MORE THAN ONE WEEK AGO" 2 "WITHIN THE LAST WEEK" ;
label define EE14_B_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE14_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE PER MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 OR 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY" ;
label define EE15      1 "YES" 2 "NO" ;
label define EE15_A_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONE WEEK AFTER ADMISSION"
                       2 "AT LEAST ONE WEEK AFTER ADMISSION" ;
label define EE15_A_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE15_B_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "MORE THAN ONE WEEK AGO" 2 "WITHIN THE LAST WEEK" ;
label define EE15_B_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE15_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "BY MOUTH (EAT, CHEW)" 2 "BY SMOKING IT"
                       3 "BY INHALING/SNORTING/SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "BY FREEBASING"
                       7 "SOME OTHER WAY" ;
label define EE15_D    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE PER MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 OR 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY" ;
label define EE15_E    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED" 1 "LESS THAN ONCE PER MONTH"
                       2 "1 TO 3 TIMES A MONTH" 3 "1 TO 2 TIMES A WEEK"
                       4 "3 TO 4 TIMES A WEEK" 5 "5 TO 6 TIMES A WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2 OR 3 TIMES A DAY"
                       8 "4 OR MORE TIMES A DAY" ;
label define EE16      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EE16_A_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONE WEEK AFTER ADMISSION"
                       2 "AT LEAST ONE WEEK AFTER ADMISSION" ;
label define EE16_A_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE16_B_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "MORE THAN ONE WEEK AGO" 2 "WITHIN THE LAST WEEK" ;
label define EE16_B_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE16_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "BY MOUTH (EAT, CHEW)" 2 "BY SMOKING IT"
                       3 "BY INHALING/SNORTING/SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "BY FREEBASING"
                       7 "SOME OTHER WAY" ;
label define EE16_D    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE PER MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 OR 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY" ;
label define EE16_E    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED" 1 "LESS THAN ONCE PER MONTH"
                       2 "1 TO 3 TIMES A MONTH" 3 "1 TO 2 TIMES A WEEK"
                       4 "3 TO 4 TIMES A WEEK" 5 "5 TO 6 TIMES A WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2 OR 3 TIMES A DAY"
                       8 "4 OR MORE TIMES A DAY" ;
label define EE16_F    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "BY MOUTH (EAT, CHEW)" 2 "BY SMOKING IT"
                       3 "BY INHALING/SNORTING/SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "BY FREEBASING"
                       7 "SOME OTHER WAY" ;
label define EE17      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EE17_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE17_B_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "DARVON" 2 "DOLENE" 3 "SK-65" 4 "WYGESIC"
                       5 "LEVO-DROMORAN" 6 "PERCODAN" 7 "DEMEROL"
                       8 "DILAUDID" 9 "TYLENOL WITH CODEINE"
                       10 "PHENAPHEN WITH CODEINE" 11 "TALWIN" 12 "TALWIN NX"
                       13 "TALACEN" 14 "PROPOXYPHENE" 15 "CODEINE"
                       16 "ANILERIDINE" 17 "MORPHINE" 18 "METHADONE"
                       19 "STADOL" 20 "DARVOCET" 21 "LOMOTIL" 22 "PAREGORIC"
                       92 "OTHER" ;
label define EE17_B_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "DARVON" 2 "DOLENE" 3 "SK-65" 4 "WYGESIC"
                       5 "LEVO-DROMORAN" 6 "PERCODAN" 7 "DEMEROL"
                       8 "DILAUDID" 9 "TYLENOL WITH CODEINE"
                       10 "PHENAPHEN WITH CODEINE" 11 "TALWIN" 12 "TALWIN NX"
                       13 "TALACEN" 14 "PROPOXYPHENE" 15 "CODEINE"
                       16 "ANILERIDINE" 17 "MORPHINE" 18 "METHADONE"
                       19 "STADOL" 20 "DARVOCET" 21 "LOMOTIL" 22 "PAREGORIC" ;
label define EE17_B_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "DARVON" 2 "DOLENE" 3 "SK-65" 4 "WYGESIC"
                       5 "LEVO-DROMORAN" 6 "PERCODAN" 7 "DEMEROL"
                       8 "DILAUDID" 9 "TYLENOL WITH CODEINE"
                       10 "PHENAPHEN WITH CODEINE" 11 "TALWIN" 12 "TALWIN NX"
                       13 "TALACEN" 14 "PROPOXYPHENE" 15 "CODEINE"
                       16 "ANILERIDINE" 17 "MORPHINE" 18 "METHADONE"
                       19 "STADOL" 20 "DARVOCET" 21 "LOMOTIL" 22 "PAREGORIC" ;
label define EE17_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE18      1 "YES" 2 "NO" ;
label define EE18_A_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONE WEEK AFTER ADMISSION"
                       2 "AT LEAST ONE WEEK AFTER ADMISSION" ;
label define EE18_A_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE18_B_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "MORE THAN ONE WEEK AGO" 2 "WITHIN THE LAST WEEK" ;
label define EE18_B_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE18_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "BY MOUTH (EAT, CHEW)" 2 "BY SMOKING IT"
                       3 "BY INHALING/SNORTING/SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "BY FREEBASING"
                       7 "SOME OTHER WAY" ;
label define EE18_D    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE PER MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 OR 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY" ;
label define EE18_E    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED" 1 "LESS THAN ONCE PER MONTH"
                       2 "1 TO 3 TIMES A MONTH" 3 "1 TO 2 TIMES A WEEK"
                       4 "3 TO 4 TIMES A WEEK" 5 "5 TO 6 TIMES A WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2 OR 3 TIMES A DAY"
                       8 "4 OR MORE TIMES A DAY" ;
label define EE19      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EE19_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE19B1_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "BUTISOL" 2 "BUTICAPS" 3 "AMYTAL" 4 "MEBARAL"
                       5 "PLACIDYL" 6 "DORIDEN" 7 "NOLUDAR" 8 "NEMBUTAL"
                       9 "SECONAL" 10 "TUINAL" 11 "DALMANE" 12 "RESTORIL"
                       13 "HALCION" 14 "AMOBARBITAL" 15 "PHENOBARBITAL"
                       16 "METHAQUALONE (INCL. SOPR, QUAALUDE)"
                       17 "CHLORAL HYDRATE" 18 "PENTOBARBITAL"
                       19 "SECOBARBITAL" 20 "FLURAZEPAN" 21 "NOCTEC"
                       92 "OTHER" ;
label define EE19B1_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "BUTISOL" 2 "BUTICAPS" 3 "AMYTAL" 4 "MEBARAL"
                       5 "PLACIDYL" 6 "DORIDEN" 7 "NOLUDAR" 8 "NEMBUTAL"
                       9 "SECONAL" 10 "TUINAL" 11 "DALMANE" 12 "RESTORIL"
                       13 "HALCION" 14 "AMOBARBITAL" 15 "PHENOBARBITAL"
                       16 "METHAQUALONE (INCL. SOPR, QUAALUDE)"
                       17 "CHLORAL HYDRATE" 18 "PENTOBARBITAL"
                       19 "SECOBARBITAL" 20 "FLURAZEPAN" 21 "NOCTEC" ;
label define EE19B2_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "VALIUM" 2 "LIBRIUM" 3 "LIMBITROL" 4 "MENRIUM"
                       5 "SERAX" 6 "TRANXENE" 7 "ATIVAN" 8 "CENTRAX"
                       9 "XANAX" 10 "PAXIPAM" 11 "BUSPAR" 12 "MILTOWN"
                       13 "EQUANIL" 14 "DEPROL" 15 "VISTARIL" 16 "ATARAX"
                       17 "DURRAX" 18 "DIAZEPAM" 19 "SK-LYGEN"
                       20 "MEPROBAMATE" 21 "HYDROXYZINE" 22 "BENADRYL"
                       23 "CLONAZEPAN" 24 "KLONOPIN" ;
label define EE19B2_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "VALIUM" 2 "LIBRIUM" 3 "LIMBITROL" 4 "MENRIUM"
                       5 "SERAX" 6 "TRANXENE" 7 "ATIVAN" 8 "CENTRAX"
                       9 "XANAX" 10 "PAXIPAM" 11 "BUSPAR" 12 "MILTOWN"
                       13 "EQUANIL" 14 "DEPROL" 15 "VISTARIL" 16 "ATARAX"
                       17 "DURRAX" 18 "DIAZEPAM" 19 "SK-LYGEN"
                       20 "MEPROBAMATE" 21 "HYDROXYZINE" 22 "BENADRYL"
                       23 "CLONAZEPAN" 24 "KLONOPIN" ;
label define EE19_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE20      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EE20_A_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONE WEEK AFTER ADMISSION"
                       2 "AT LEAST ONE WEEK AFTER ADMISSION" ;
label define EE20_A_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE20_B_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "MORE THAN ONE WEEK AGO" 2 "WITHIN THE LAST WEEK" ;
label define EE20_B_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE20_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "BY MOUTH (EAT, CHEW)" 2 "BY SMOKING IT"
                       3 "BY INHALING/SNORTING/SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "BY FREEBASING"
                       7 "SOME OTHER WAY" ;
label define EE20_D    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE PER MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 OR 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY" ;
label define EE20_E_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EE20_E_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EE20_E_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EE20_E_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EE20_F    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "SEDATIVES AND SLEEPING PILLS" 2 "BARBITURATES"
                       3 "BENZODIAZEPINES, SUCH AS XANAX, VALIUM, OR LIBRIUM"
                       4 "OTHER TRANQUILIZERS" ;
label define EE21      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EE21_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE21_B_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "DEXEDRINE" 2 "DEXAMYL" 3 "ESKATROL" 4 "BENZEDRINE"
                       5 "BIPHETAMINE" 6 "DESOXYN" 7 "TENUATE" 8 "TEPANIL"
                       9 "DIDREX" 10 "PLEGINE" 11 "PRELUDIN" 12 "IONAMIN"
                       13 "FASTIN" 14 "PONDIMIN" 15 "VORANIL" 16 "SANOREX"
                       17 "MAZANOR" 18 "RITALIN" 19 "CYLERT"
                       20 "DEXTROAMPHETAMIN" 21 "METHEDRINE"
                       22 "METHAMPHETAMINE ('SPEED' OR 'CRANK')"
                       23 "OBEDRIN-L.A." ;
label define EE21_B_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "DEXEDRINE" 2 "DEXAMYL" 3 "ESKATROL" 4 "BENZEDRINE"
                       5 "BIPHETAMINE" 6 "DESOXYN" 7 "TENUATE" 8 "TEPANIL"
                       9 "DIDREX" 10 "PLEGINE" 11 "PRELUDIN" 12 "IONAMIN"
                       13 "FASTIN" 14 "PONDIMIN" 15 "VORANIL" 16 "SANOREX"
                       17 "MAZANOR" 18 "RITALIN" 19 "CYLERT"
                       20 "DEXTROAMPHETAMIN" 21 "METHEDRINE"
                       22 "METHAMPHETAMINE ('SPEED' OR 'CRANK')"
                       23 "OBEDRIN-L.A." ;
label define EE21_B_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "DEXEDRINE" 2 "DEXAMYL" 3 "ESKATROL" 4 "BENZEDRINE"
                       5 "BIPHETAMINE" 6 "DESOXYN" 7 "TENUATE" 8 "TEPANIL"
                       9 "DIDREX" 10 "PLEGINE" 11 "PRELUDIN" 12 "IONAMIN"
                       13 "FASTIN" 14 "PONDIMIN" 15 "VORANIL" 16 "SANOREX"
                       17 "MAZANOR" 18 "RITALIN" 19 "CYLERT"
                       20 "DEXTROAMPHETAMIN" 21 "METHEDRINE"
                       22 "METHAMPHETAMINE ('SPEED' OR 'CRANK')"
                       23 "OBEDRIN-L.A." ;
label define EE21_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE22      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EE22_A_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONE WEEK AFTER ADMISSION"
                       2 "AT LEAST ONE WEEK AFTER ADMISSION" ;
label define EE22_A_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE22_B_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "MORE THAN ONE WEEK AGO" 2 "WITHIN THE LAST WEEK" ;
label define EE22_B_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE22_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "BY MOUTH (EAT, CHEW)" 2 "BY SMOKING IT"
                       3 "BY INHALING/SNORTING/SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "BY FREEBASING"
                       7 "SOME OTHER WAY" ;
label define EE22_D    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE PER MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 OR 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY" ;
label define EE22_E    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED" 1 "LESS THAN ONCE PER MONTH"
                       2 "1 TO 3 TIMES A MONTH" 3 "1 TO 2 TIMES A WEEK"
                       4 "3 TO 4 TIMES A WEEK" 5 "5 TO 6 TIMES A WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2 OR 3 TIMES A DAY"
                       8 "4 OR MORE TIMES A DAY" ;
label define EE23      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NEITHER" 1 "MAJOR TRANQUILIZERS"
                       2 "MAJOR ANTIDEPRESSANTS" 3 "BOTH" ;
label define EE23_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NEITHER" 1 "MAJOR TRANQUILIZERS"
                       2 "MAJOR ANTIDEPRESSANTS" 3 "BOTH" ;
label define EE24      1 "YES" 2 "NO" ;
label define EE24_A_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONE WEEK AFTER ADMISSION"
                       2 "AT LEAST ONE WEEK AFTER ADMISSION" ;
label define EE24_A_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE24_B_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "MORE THAN ONE WEEK AGO" 2 "WITHIN THE LAST WEEK" ;
label define EE24_B_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE24_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "BY MOUTH (EAT, CHEW)" 2 "BY SMOKING IT"
                       3 "BY INHALING/SNORTING/SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "BY FREEBASING"
                       7 "SOME OTHER WAY" ;
label define EE24_D    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE PER MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 OR 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY" ;
label define EE24_E    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED" 1 "LESS THAN ONCE PER MONTH"
                       2 "1 TO 3 TIMES A MONTH" 3 "1 TO 2 TIMES A WEEK"
                       4 "3 TO 4 TIMES A WEEK" 5 "5 TO 6 TIMES A WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2 OR 3 TIMES A DAY"
                       8 "4 OR MORE TIMES A DAY" ;
label define EE25      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EE25_A_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONE WEEK AFTER ADMISSION"
                       2 "AT LEAST ONE WEEK AFTER ADMISSION" ;
label define EE25_A_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE25_B_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "MORE THAN ONE WEEK AGO" 2 "WITHIN THE LAST WEEK" ;
label define EE25_B_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE25_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE PER MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 OR 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY" ;
label define EE26      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       10 "ALCOHOL" 20 "MARIJUANA, HASHISH, THC"
                       30 "HALLUCINOGENS/PSYCHEDELICS"
                       40 "COCAINE IN ANY FORM" 41 "CRACK"
                       50 "HEROIN ALONE,WITH OTHER DRUGS"
                       51 "HEROIN/COCAINE TOGETHER AT SAME TIME"
                       60 "NARCOTICS/OPIATES" 61 "STREET/ILLEGAL METHADONE"
                       70 "DOWNERS/DEPRESSANTS"
                       80 "AMPHETAMINES/OTHER STIMULANTS/SPEED"
                       81 "METHAMPHETAMINES/ICE" 90 "ANY OTHER DRUGS"
                       91 "INHALANTS" ;
label define EE26_A_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONE WEEK AFTER ADMISSION"
                       2 "AT LEAST ONE WEEK AFTER ADMISSION" ;
label define EE26_A_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE26_B_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "MORE THAN ONE WEEK AGO" 2 "WITHIN THE LAST WEEK" ;
label define EE26_B_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE26_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "BY MOUTH (EAT, CHEW)" 2 "BY SMOKING IT"
                       3 "BY INHALING/SNORTING/SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "BY FREEBASING"
                       7 "SOME OTHER WAY" ;
label define EE26_D    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE PER MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 OR 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY" ;
label define EE27      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EE27_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       10 "ALCOHOL" 20 "MARIJUANA, HASHISH, THC"
                       30 "HALLUCINOGENS/PSYCHEDELICS"
                       40 "COCAINE IN ANY FORM" 41 "CRACK"
                       50 "HEROIN ALONE,WITH OTHER DRUGS"
                       51 "HEROIN/COCAINE TOGETHER AT SAME TIME"
                       60 "NARCOTICS/OPIATES" 61 "STREET/ILLEGAL METHADONE"
                       70 "DOWNERS/DEPRESSANTS"
                       80 "AMPHETAMINES/OTHER STIMULANTS/SPEED"
                       81 "METHAMPHETAMINES/ICE" 90 "ANY OTHER DRUGS"
                       91 "INHALANTS" ;
label define EE27_B_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONE WEEK AFTER ADMISSION"
                       2 "AT LEAST ONE WEEK AFTER ADMISSION" ;
label define EE27_B_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE27_C_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "MORE THAN ONE WEEK AGO" 2 "WITHIN THE LAST WEEK" ;
label define EE27_C_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE27_D    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "BY MOUTH (EAT, CHEW)" 2 "BY SMOKING IT"
                       3 "BY INHALING/SNORTING/SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "BY FREEBASING"
                       7 "SOME OTHER WAY" ;
label define EE27_E    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE PER MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 OR 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY" ;
label define EE28      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EE28_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       10 "ALCOHOL" 20 "MARIJUANA, HASHISH, THC"
                       30 "HALLUCINOGENS/PSYCHEDELICS"
                       40 "COCAINE IN ANY FORM" 41 "CRACK"
                       50 "HEROIN ALONE,WITH OTHER DRUGS"
                       51 "HEROIN/COCAINE TOGETHER AT SAME TIME"
                       60 "NARCOTICS/OPIATES" 61 "STREET/ILLEGAL METHADONE"
                       70 "DOWNERS/DEPRESSANTS"
                       80 "AMPHETAMINES/OTHER STIMULANTS/SPEED"
                       81 "METHAMPHETAMINES/ICE" 90 "ANY OTHER DRUGS"
                       91 "INHALANTS" ;
label define EE28_B_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONE WEEK AFTER ADMISSION"
                       2 "AT LEAST ONE WEEK AFTER ADMISSION" ;
label define EE28_B_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE28_C_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "MORE THAN ONE WEEK AGO" 2 "WITHIN THE LAST WEEK" ;
label define EE28_C_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE28_D    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "BY MOUTH (EAT, CHEW)" 2 "BY SMOKING IT"
                       3 "BY INHALING/SNORTING/SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "BY FREEBASING"
                       7 "SOME OTHER WAY" ;
label define EE28_E    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE PER MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 OR 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY" ;
label define EE29      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE30      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EE30_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE31      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EE31A_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE31A_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE31A_3   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE31A_4   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE31A_5   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE31A_6   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EE32      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EE33_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "RARELY" 2 "SOMETIMES" 3 "OFTEN" 4 "ALWAYS" ;
label define EE33_B    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "RARELY" 2 "SOMETIMES" 3 "OFTEN" 4 "ALWAYS" ;
label define EE33_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "RARELY" 2 "SOMETIMES" 3 "OFTEN" 4 "ALWAYS" ;
label define EE33_D    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "RARELY" 2 "SOMETIMES" 3 "OFTEN" 4 "ALWAYS" ;
label define EE33_E    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "RARELY" 2 "SOMETIMES" 3 "OFTEN" 4 "ALWAYS" ;
label define EE33_F    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "RARELY" 2 "SOMETIMES" 3 "OFTEN" 4 "ALWAYS" ;
label define EE34      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY MUCH" ;
label define EE35      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY IMPORTANT" ;
label define EE36      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "A LITTLE" 2 "A LOT" ;
label define EE37      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "A LITTLE" 2 "A LOT" ;
label define EE38      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY TEMPTED" ;
label define EE39_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define EE39_B    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define EE39_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define EE39_D    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define EE39_E    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define EE39_F    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define EE39_G    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define EE39_H    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define EE39_I    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define EE39_J    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define EE39_K    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define EE39_L    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define EE39_M    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define EE39_N    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define EE39_O    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define EE39_P    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define EE39_Q    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define EE39_R    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define EE39_S    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define EE39_T    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define EE40      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EE40_B_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define EE40_B_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define EE40_B_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define EE41_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define EE41_B    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define EE42      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY DIFFICULT" ;
label define EE43      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "VERY POOR" 2 "FAIR" 3 "VERY GOOD" ;
label define EE44      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY MUCH" ;
label define EE45      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY DIFFICULT" ;
label define EE46      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "VERY POOR" 2 "FAIR" 3 "VERY GOOD" ;
label define EE47      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY MUCH" ;
label define EE48_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define EE48_B    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define EE48_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define EE48_D    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define EE48_E    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define EE48_F    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define EE48_G    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define EE48_H    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define EE48_I    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define EE48_J    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define EE48_K    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define EE48_L    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define EF1       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NEVER HAD VAGINAL SEX WITH A FEMALE" 1 "NONE"
                       2 "1 FEMALE" 3 "2 TO 4 FEMALES" 4 "5 TO 9 FEMALES"
                       5 "10 TO 20 FEMALES" 6 "21 TO 99 FEMALES"
                       7 "100 OR MORE FEMALES" ;
label define EF1_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "NEVER"
                       2 "SOMETIMES" 3 "USUALLY" 4 "EVERY TIME" ;
label define EF2       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "NONE"
                       2 "1 FEMALE" 3 "2 TO 4 FEMALES" 4 "5 TO 9 FEMALES"
                       5 "10 TO 20 FEMALES" 6 "21 TO 99 FEMALES"
                       7 "100 OR MORE FEMALES" ;
label define EF2_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "NEVER"
                       2 "SOMETIMES" 3 "USUALLY" 4 "EVERY TIME" ;
label define EF3       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EF4       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EF5       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NEVER HAD SEX WITH A MALE" 1 "NONE" 2 "1 MALE"
                       3 "2 TO 4 MALES" 4 "5 TO 9 MALES" 5 "10 TO 20 MALES"
                       6 "21 TO 99 MALES" 7 "100 OR MORE MALES" ;
label define EF5_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "NEVER"
                       2 "SOMETIMES" 3 "USUALLY" 4 "EVERY TIME" ;
label define EF6       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EF7       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EF8       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EF9       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EF9_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "1 PERSON" 2 "2 TO 4 PEOPLE" 3 "5 OR MORE PEOPLE" ;
label define EF10      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NEVER HAD VAGINAL INTERCOURSE W/MALE" 1 "NONE"
                       2 "1 MALE" 3 "2 TO 4 MALES" 4 "5 TO 9 MALES"
                       5 "10 TO 20 MALES" 6 "21 TO 99 MALES"
                       7 "100 OR MORE MALES" ;
label define EF10_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "NEVER"
                       2 "SOMETIMES" 3 "USUALLY" 4 "EVERY TIME" ;
label define EF11      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NEVER HAD ANAL SEX WITH A MAN" 1 "NONE" 2 "1 MALE"
                       3 "2 TO 4 MALES" 4 "5 TO 9 MALES" 5 "10 TO 20 MALES"
                       6 "21 TO 99 MALES" 7 "100 OR MORE MALES" ;
label define EF11_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "NEVER"
                       2 "SOMETIMES" 3 "USUALLY" 4 "EVERY TIME" ;
label define EF12      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EF13      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EF14      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EF15      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EF16      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EF16_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "1 MALE"
                       2 "2 TO 4 MALES" 3 "5 OR MORE MALES" ;
label define EF17      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EF17_A_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EF17_A_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EF17_A_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EF17_A_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EF17_B    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "AT THIS PROGRAM" 2 "SOME OTHER PLACE" 3 "BOTH" ;
label define EF17_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EF17D_01  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EF17D_02  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EF17D_14  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       14 "CIRCLED" ;
label define EF17D_23  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       23 "CIRCLED" ;
label define EF17D_24  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       24 "CIRCLED" ;
label define EF17D_25  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       25 "CIRCLED" ;
label define EF17D_61  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       61 "CIRCLED" ;
label define EF17D_62  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       62 "CIRCLED" ;
label define EF17D_91  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define EF17_E    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EF18      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EG1       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "EXCELLENT" 2 "GOOD" 3 "FAIR" 4 "POOR" ;
label define EG2       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "MUCH BETTER" 2 "BETTER" 3 "THE SAME" 4 "WORSE"
                       5 "MUCH WORSE" ;
label define EG3       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "MUCH BETTER" 2 "BETTER" 3 "THE SAME" 4 "WORSE"
                       5 "MUCH WORSE" ;
label define EG4       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EG4_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EG4_B_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EG4_B_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EG4_B_3   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EG4_B_4   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EG4_C     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "1-3 MOS" 6 "3-6 MOS" 9 "7-9 MOS" ;
label define EG4_D     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "VERY MILD" 2 "MILD" 3 "MODERATE" 4 "SEVERE" ;
label define EG4_E     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EG4F_1    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EG4F_2    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EG4F_3    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EG4F_4    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EG4F_5    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EG4F_6    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EG4G      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EG5_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EG5_B     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EG5_C     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EG5_D     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EG5_E     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EG5_F     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EG7       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EG7_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EG8       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EG9       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EG10      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EG11      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EG12      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EG12A_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EG12A_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EG12A_3   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EG12A_4   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EG12B_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NO DIAGNOSIS" 1 "SUBSTANCE-RELATED CONDITIONS"
                       2 "MENTAL HEALTH CONDITIONS" 3 "ALL OTHER CONDITIONS" ;
label define EG12B_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NO DIAGNOSIS" 1 "SUBSTANCE-RELATED CONDITIONS"
                       2 "MENTAL HEALTH CONDITIONS" 3 "ALL OTHER CONDITIONS" ;
label define EG12B_3   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NO DIAGNOSIS" 1 "SUBSTANCE-RELATED CONDITIONS"
                       2 "MENTAL HEALTH CONDITIONS" 3 "ALL OTHER CONDITIONS" ;
label define EG13      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY MUCH" ;
label define EG14      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY IMPORTANT" ;
label define EG15      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EG15_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "NOT AT ALL" 2 "SOMEWHAT" 3 "VERY SERIOUS" ;
label define EH1       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EH1_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EH2_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EH3_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EH2_B     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EH3_B     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EH2_C     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EH3_C     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EH2_D     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EH3_D     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EH2_E     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EH3_E     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EH2_F     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EH3_F     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EH2_G     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EH3_G     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EH2_H     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EH3_H     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EH2_I     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EH3_I     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EH2_J     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EH3_J     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EH2_K     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EH3_K     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EH2_L     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EH3_L     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EH4       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EH5       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "1 OR 2 TIMES" 2 "3 TO 5 TIMES" 3 "6 TO 10 TIMES"
                       4 "11 TO 49 TIMES" 5 "50 OR MORE TIMES" ;
label define EH6       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EH6_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "NOT AT ALL SERIOUS" 2 "SOMEWHAT SERIOUS"
                       3 "VERY SERIOUS" ;
label define EH7       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY TROUBLED" ;
label define EH8       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EH8_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EH9       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY TROUBLED" ;
label define EJ1       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "WORKING LEGITIMATE JOB/YOURSELF"
                       2 "HAD A JOB BUT WAS NOT WORKING" 3 "LOOKING FOR WORK"
                       4 "HOMEMAKER" 5 "GOING TO SCHOOL/TRAINING PROG"
                       6 "UNABLE TO WORK, DISABLE" 7 "RETIRED"
                       8 "IN JAIL/RESI TREAT PROG/OTHER INSTI"
                       9 "INVOLVED IN DRUG RELATED ACTIVITY"
                       10 "INVOLVED IN OTHER ILLEGAL ACTIVITY"
                       11 "NOT WORKING/NOT INTEREST WORKING" 12 "OTHER" ;
label define EJ2       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EJ2_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "DID NOT EARN MONEY LEGALLY"
                       2 "DID EARN MONEY LEGALLY" ;
label define EJ2_B     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EJ2_C     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EJ2_D     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EJ2_E     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "SLACK WORK, LAYOFFS, STRIKE" 2 "SEASONAL WORKER"
                       3 "JOB TERMINATED" 4 "NEW JOB STARTED DURING WEEK"
                       5 "COULD ONLY FINE PART-TIME WORK"
                       6 "DRUG OR ALCOHOL PROBLEM" 7 "ILLNESS" 8 "VACATION"
                       9 "BUSY WITH OTHER ACTIVITIES"
                       10 "DID NOT WANT/NEED FULL-TIME WORK"
                       11 "WORKWEEK USUALLY UNDER 35 HOURS"
                       12 "UNABLE TO WORK" 13 "RETIRED"
                       14 "IN JAIL, RESIDENTIAL TREATMENT PROGRAM"
                       15 "INVOLVED IN ILLEGAL ACTIVITIES" 16 "OTHERS" ;
label define EJ2_F     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EJ2_G     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "SLACK WORK, LAYOFFS, STRIKE" 2 "SEASONAL WORKER"
                       3 "JOB TERMINATED" 4 "NEW JOB STARTED DURING WEEK"
                       5 "COULD ONLY FINE PART-TIME WORK"
                       6 "DRUG OR ALCOHOL PROBLEM" 7 "ILLNESS" 8 "VACATION"
                       9 "BUSY WITH OTHER ACTIVITIES"
                       10 "DID NOT WANT/NEED FULL-TIME WORK"
                       11 "WORKWEEK USUALLY UNDER 35 HOURS"
                       12 "UNABLE TO WORK" 13 "RETIRED"
                       14 "IN JAIL, RESIDENTIAL TREATMENT PROGRAM"
                       15 "INVOLVED IN ILLEGAL ACTIVITIES" 16 "OTHERS" ;
label define EJ3       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EJ3_A_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EJ3_A_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EJ3_A_3   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EJ3_A_4   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EJ3_A_5   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EJ3_A_6   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EJ3_A_7   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define EJ3_B     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EJ3_C_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EJ3_C_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EJ3_C_3   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EJ3_C_4   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EJ3_C_5   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EJ3_C_6   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EJ3_C_7   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define EJ3_C_8   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       8 "CIRCLED" ;
label define EJ3_C_9   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       9 "CIRCLED" ;
label define EJ3_C_10  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       10 "CIRCLED" ;
label define EJ3_C_11  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       11 "CIRCLED" ;
label define EJ4_0     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "CIRCLED" ;
label define EJ4_1     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EJ4_2     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EJ4_3     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EJ4_4     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EJ4_5     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EJ4_6     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EJ4_7     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define EJ4_8     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       8 "CIRCLED" ;
label define EJ4_9     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       9 "CIRCLED" ;
label define EJ4_10    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       10 "CIRCLED" ;
label define EJ4_11    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       11 "CIRCLED" ;
label define EJ4_12    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       12 "CIRCLED" ;
label define EJ4_13    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       13 "CIRCLED" ;
label define EJ4_14    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       14 "CIRCLED" ;
label define EJ4_15    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       15 "CIRCLED" ;
label define EJ4_16    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       16 "CIRCLED" ;
label define EJ5       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EJ6       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "LESS THAN ONE WEEK" ;
label define EJ7       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "LESS THAN ONE WEEK" ;
label define EJ8       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "LESS THAN ONE WEEK" ;
label define EJ9       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROFESSIONAL AND TECHNICAL"
                       2 "MANAGER AND ADMINISTRATOR" 3 "SALES"
                       4 "CLERICAL OR OFFICE WORKER" 5 "CRAFT AND KINDRED"
                       6 "OPERATIVES" 7 "TRANSPORTATION EQUIPMENT OPERATIVES"
                       8 "LABORERS (FARM & NONFARM)" 10 "SERVICE WORKER"
                       86 "OTHER" ;
label define EJ9_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "AGRICULTURE/FORESTRY/FISHERIES" 2 "CONSTRUCTION"
                       3 "MANUFACTURING"
                       4 "TRANSPORT./COMMUNIC./OTHER PUB UTILITIES"
                       5 "WHOLESALE TRADE" 6 "RETAIL TRADE"
                       7 "FINANCE/INSUR./REAL ESTATE"
                       8 "BUSINESS/REPAIR SERVICES" 9 "PERSONAL SERVICES"
                       10 "ENTERTAINMENT/REC. SVCS" 11 "PROF./RELATED SVCS"
                       12 "PUBLIC ADMIN." 13 "INDUSTRY NOT REPORTED" ;
label define EJ9_B     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EJ9_C_OC  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROFESSIONAL AND TECHNICAL"
                       2 "MANAGER AND ADMINISTRATOR" 3 "SALES"
                       4 "CLERICAL OR OFFICE WORKER" 5 "CRAFT AND KINDRED"
                       6 "OPERATIVES" 7 "TRANSPORTATION EQUIPMENT OPERATIVES"
                       8 "LABORERS (FARM & NONFARM)" 10 "SERVICE WORKER"
                       86 "OTHER" ;
label define EJ9_C     -9.0000 "LEGITIMATE NONRESPONSE" -8.0000 "MISSING"
                       -7.0000 "REFUSAL" -6.0000 "MULTIPLE RESPONSE"
                       -5.0000 "BAD DATA" -4.0000 "DON'T KNOW"
                       -3.0000 "NOT APPLICABLE" -2.0000 "RESPONSE ILLEGIBLE" ;
label define EJ9_COD   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "HOUR"
                       2 "WEEK" 3 "2 WEEKS" 4 "MONTH" 5 "YEAR" 6 "OTHER" ;
label define EJ10      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY MUCH" ;
label define EJ11      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY IMPORTANT" ;
label define EJ12      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EJ12_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "NOT AT ALL" 2 "SOMEWHAT" 3 "VERY SERIOUS" ;
label define EK1_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EK2_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EK1_B     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EK2_B     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EK1_C     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EK2_C     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EK1_D     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EK2_D     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EK1_E     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EK2_E     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EK1_F     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EK2_F     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EK3       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EK4       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EK5       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EK6_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EK6_B     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EK6_C     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EK6_D     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EK7       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EK7_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "NOT AT ALL" 2 "SOMEWHAT" 3 "VERY SERIOUS" ;
label define EK8       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY MUCH" ;
label define EK9       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY IMPORTANT" ;
label define EL1       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       99 "99 OR MORE" ;
label define EL1_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL2       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL2_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL2_B     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "YOU WERE SICK" 2 "FRIEND/FAMILY MEMBER SICK"
                       9 "OTHER ILLNESS RELATED"
                       10 "CHILD CARE ARRANGE PROBLEM"
                       11 "FAMILY MEMBER OBJECTED"
                       12 "FAMILY MEMBER DID NOT ATTEND W/YOU"
                       13 "FRIENDS PUT YOU DOWN TO SEEK HELP"
                       14 "STIGMA/COME TO PROG/DISCOURAGED YOU"
                       15 "FEAR OF DRUG TEST/BY EMPLOYER"
                       16 "YOU WERE IN SCHOOL" 19 "OTHER PRESSURES"
                       20 "DIFFICULTY W/TRANSPORTATION"
                       21 "DAILY SCHEDULE PREVENTED YOU"
                       22 "YOU WERE INCARCERATED"
                       23 "OTHER ACTIVITY KEPT FROM ATTENDING"
                       24 "COULD NOT ATTEND DURING PROG HRS"
                       25 "YOU DID NOT CARE FOR LOCATION"
                       26 "DISTANCE TO PROG WAS TOO FAR"
                       29 "OTHER ACCESS RELATED"
                       30 "TREATMENT/WAS NOT YOU EXPECTED"
                       31 "FELT/GET BETTER HELP ELSEWHERE"
                       32 "NOT TREATED IN A PROF MANNER"
                       33 "TOO MUCH PAPERWORK" 34 "TOO HIGH FEES"
                       35 "HAD TO WAIT TOO LONG"
                       36 "NOT FEEL COMFORTABLE W/COUNSELOR"
                       37 "YOU SOUGHT OTHER HELP"
                       38 "RESENTMENT OVER DRUG TEST"
                       39 "OTHER DISSATISFACTION REASON"
                       40 "PROBLEM IMPROVED ON ITS OWN"
                       41 "IMMEDIATE CRISIS WAS RESOLVED"
                       42 "DID NOT THINK YOU NEED TREATMENT"
                       49 "TREATMENT NOT HELPFUL" 50 "YOU FORGOT APPOINTMENT"
                       51 "YOU WERE DRUNK/HIGH" 52 "FELT OVERWHELMED"
                       53 "COUNSELOR CANCELLED APPOINTMENT"
                       54 "AFRAID OF BAD DRUG TEST RESULT" 59 "OTHER" ;
label define EL2_C     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL2_D     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "YOU WERE SICK" 2 "FRIEND/FAMILY MEMBER SICK"
                       9 "OTHER ILLNESS RELATED"
                       10 "CHILD CARE ARRANGE PROBLEM"
                       11 "FAMILY MEMBER OBJECTED"
                       12 "FAMILY MEMBER DID NOT ATTEND W/YOU"
                       13 "FRIENDS PUT YOU DOWN TO SEEK HELP"
                       14 "STIGMA/COME TO PROG/DISCOURAGED YOU"
                       15 "FEAR OF DRUG TEST/BY EMPLOYER"
                       16 "YOU WERE IN SCHOOL" 19 "OTHER PRESSURES"
                       20 "DIFFICULTY W/TRANSPORTATION"
                       21 "DAILY SCHEDULE PREVENTED YOU"
                       22 "YOU WERE INCARCERATED"
                       23 "OTHER ACTIVITY KEPT FROM ATTENDING"
                       24 "COULD NOT ATTEND DURING PROG HRS"
                       25 "YOU DID NOT CARE FOR LOCATION"
                       26 "DISTANCE TO PROG WAS TOO FAR"
                       29 "OTHER ACCESS RELATED"
                       30 "TREATMENT/WAS NOT YOU EXPECTED"
                       31 "FELT/GET BETTER HELP ELSEWHERE"
                       32 "NOT TREATED IN A PROF MANNER"
                       33 "TOO MUCH PAPERWORK" 34 "TOO HIGH FEES"
                       35 "HAD TO WAIT TOO LONG"
                       36 "NOT FEEL COMFORTABLE W/COUNSELOR"
                       37 "YOU SOUGHT OTHER HELP"
                       38 "RESENTMENT OVER DRUG TEST"
                       39 "OTHER DISSATISFACTION REASON"
                       40 "PROBLEM IMPROVED ON ITS OWN"
                       41 "IMMEDIATE CRISIS WAS RESOLVED"
                       42 "DID NOT THINK YOU NEED TREATMENT"
                       49 "TREATMENT NOT HELPFUL" 50 "YOU FORGOT APPOINTMENT"
                       51 "YOU WERE DRUNK/HIGH" 52 "FELT OVERWHELMED"
                       53 "COUNSELOR CANCELLED APPOINTMENT"
                       54 "AFRAID OF BAD DRUG TEST RESULT" 59 "OTHER" ;
label define EL2_E     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL2_F_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "YOU WERE SICK" 2 "FRIEND/FAMILY MEMBER SICK"
                       9 "OTHER ILLNESS RELATED"
                       10 "CHILD CARE ARRANGE PROBLEM"
                       11 "FAMILY MEMBER OBJECTED"
                       12 "FAMILY MEMBER DID NOT ATTEND W/YOU"
                       13 "FRIENDS PUT YOU DOWN TO SEEK HELP"
                       14 "STIGMA/COME TO PROG/DISCOURAGED YOU"
                       15 "FEAR OF DRUG TEST/BY EMPLOYER"
                       16 "YOU WERE IN SCHOOL" 19 "OTHER PRESSURES"
                       20 "DIFFICULTY W/TRANSPORTATION"
                       21 "DAILY SCHEDULE PREVENTED YOU"
                       22 "YOU WERE INCARCERATED"
                       23 "OTHER ACTIVITY KEPT FROM ATTENDING"
                       24 "COULD NOT ATTEND DURING PROG HRS"
                       25 "YOU DID NOT CARE FOR LOCATION"
                       26 "DISTANCE TO PROG WAS TOO FAR"
                       29 "OTHER ACCESS RELATED"
                       30 "TREATMENT/WAS NOT YOU EXPECTED"
                       31 "FELT/GET BETTER HELP ELSEWHERE"
                       32 "NOT TREATED IN A PROF MANNER"
                       33 "TOO MUCH PAPERWORK" 34 "TOO HIGH FEES"
                       35 "HAD TO WAIT TOO LONG"
                       36 "NOT FEEL COMFORTABLE W/COUNSELOR"
                       37 "YOU SOUGHT OTHER HELP"
                       38 "RESENTMENT OVER DRUG TEST"
                       39 "OTHER DISSATISFACTION REASON"
                       40 "PROBLEM IMPROVED ON ITS OWN"
                       41 "IMMEDIATE CRISIS WAS RESOLVED"
                       42 "DID NOT THINK YOU NEED TREATMENT"
                       49 "TREATMENT NOT HELPFUL" 50 "YOU FORGOT APPOINTMENT"
                       51 "YOU WERE DRUNK/HIGH" 52 "FELT OVERWHELMED"
                       53 "COUNSELOR CANCELLED APPOINTMENT"
                       54 "AFRAID OF BAD DRUG TEST RESULT" 59 "OTHER" ;
label define EL2_F_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL2_F_3   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL3       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL3_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL4       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL5       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL5_A_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL5_A_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL5_A_3   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL5_A_4   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL5_B_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL5_B_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL5_B_11  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       11 "CIRCLED" ;
label define EL5_B_12  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       12 "CIRCLED" ;
label define EL5_B_13  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       13 "CIRCLED" ;
label define EL5_B_21  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       21 "CIRCLED" ;
label define EL5_B_22  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       22 "CIRCLED" ;
label define EL5_B_23  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       23 "CIRCLED" ;
label define EL5_B_31  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       31 "CIRCLED" ;
label define EL5_B_71  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       71 "CIRCLED" ;
label define EL5_B_91  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define EL5_C     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL5_D     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY MUCH" ;
label define EL6       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL6_A_A   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL6_A_B   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL6_A_C   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL6_A_D   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL6_A_E   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL6_A_F   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL6_A_G   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define EL6_A_H   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       8 "CIRCLED" ;
label define EL6_A_I   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       9 "CIRCLED" ;
label define EL6_A_J   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       10 "CIRCLED" ;
label define EL6_B_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "COMMUNITY MENTAL HEALTH PROG"
                       2 "ALC REHABILITATION CENTER"
                       3 "28-DAY/OTHER SHORT TERM TRTMNT"
                       4 "THERAPEUTIC COMMUNITY" 5 "HALFWAY HOUSE"
                       6 "DETOXIFICATION TREATMENT UNIT"
                       7 "EMERGENCY ROOM/CRISIS CENTER" 8 "PRIVATE THERAPIST"
                       9 "OTHER OUTPATIENT TREATMENT"
                       10 "OTHER INPATIENT TREATMENT" ;
label define EL6_C_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL6_D_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROGRAM" 2 "OUTSIDE SOURCE" 3 "SELF" ;
label define EL6_E_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL6_B_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "COMMUNITY MENTAL HEALTH PROG"
                       2 "ALC REHABILITATION CENTER"
                       3 "28-DAY/OTHER SHORT TERM TRTMNT"
                       4 "THERAPEUTIC COMMUNITY" 5 "HALFWAY HOUSE"
                       6 "DETOXIFICATION TREATMENT UNIT"
                       7 "EMERGENCY ROOM/CRISIS CENTER" 8 "PRIVATE THERAPIST"
                       9 "OTHER OUTPATIENT TREATMENT"
                       10 "OTHER INPATIENT TREATMENT" ;
label define EL6_C_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL6_D_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROGRAM" 2 "OUTSIDE SOURCE" 3 "SELF" ;
label define EL6_E_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL6_B_3   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "COMMUNITY MENTAL HEALTH PROG"
                       2 "ALC REHABILITATION CENTER"
                       3 "28-DAY/OTHER SHORT TERM TRTMNT"
                       4 "THERAPEUTIC COMMUNITY" 5 "HALFWAY HOUSE"
                       6 "DETOXIFICATION TREATMENT UNIT"
                       7 "EMERGENCY ROOM/CRISIS CENTER" 8 "PRIVATE THERAPIST"
                       9 "OTHER OUTPATIENT TREATMENT"
                       10 "OTHER INPATIENT TREATMENT" ;
label define EL6_C_3   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL6_D_3   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROGRAM" 2 "OUTSIDE SOURCE" 3 "SELF" ;
label define EL6_E_3   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL6_B_4   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "COMMUNITY MENTAL HEALTH PROG"
                       2 "ALC REHABILITATION CENTER"
                       3 "28-DAY/OTHER SHORT TERM TRTMNT"
                       4 "THERAPEUTIC COMMUNITY" 5 "HALFWAY HOUSE"
                       6 "DETOXIFICATION TREATMENT UNIT"
                       7 "EMERGENCY ROOM/CRISIS CENTER" 8 "PRIVATE THERAPIST"
                       9 "OTHER OUTPATIENT TREATMENT"
                       10 "OTHER INPATIENT TREATMENT" ;
label define EL6_C_4   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL6_D_4   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROGRAM" 2 "OUTSIDE SOURCE" 3 "SELF" ;
label define EL6_E_4   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL7       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL7_A_A   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL7_A_B   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL7_A_C   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL7_A_D   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL7_A_E   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL7_A_F   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL7_A_G   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define EL7_A_H   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       8 "CIRCLED" ;
label define EL7_A_I   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       9 "CIRCLED" ;
label define EL7_B_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIVATE PHYSICIAN/PSYCHI/PSYCHO"
                       2 "28-DAY/OTHER SHORT TERM TREATMENT"
                       3 "THERAPEUTIC COMMUNITY" 4 "HALFWAY HOUSE"
                       5 "METHADONE TREAT PROG" 6 "NON-METHADONE"
                       7 "DETOXIFICATION TREATMENT UNIT"
                       8 "OTHER OUTPATIENT DRUG TREATMENT"
                       9 "OTHER INPATIENT DRUG TREATMENT" ;
label define EL7_C_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL7_D_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROGRAM" 2 "OUTSIDE SOURCE" 3 "SELF" ;
label define EL7_E_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL7_B_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIVATE PHYSICIAN/PSYCHI/PSYCHO"
                       2 "28-DAY/OTHER SHORT TERM TREATMENT"
                       3 "THERAPEUTIC COMMUNITY" 4 "HALFWAY HOUSE"
                       5 "METHADONE TREAT PROG" 6 "NON-METHADONE"
                       7 "DETOXIFICATION TREATMENT UNIT"
                       8 "OTHER OUTPATIENT DRUG TREATMENT"
                       9 "OTHER INPATIENT DRUG TREATMENT" ;
label define EL7_C_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL7_D_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROGRAM" 2 "OUTSIDE SOURCE" 3 "SELF" ;
label define EL7_E_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL7_B_3   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIVATE PHYSICIAN/PSYCHI/PSYCHO"
                       2 "28-DAY/OTHER SHORT TERM TREATMENT"
                       3 "THERAPEUTIC COMMUNITY" 4 "HALFWAY HOUSE"
                       5 "METHADONE TREAT PROG" 6 "NON-METHADONE"
                       7 "DETOXIFICATION TREATMENT UNIT"
                       8 "OTHER OUTPATIENT DRUG TREATMENT"
                       9 "OTHER INPATIENT DRUG TREATMENT" ;
label define EL7_C_3   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL7_D_3   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROGRAM" 2 "OUTSIDE SOURCE" 3 "SELF" ;
label define EL7_E_3   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL7_B_4   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIVATE PHYSICIAN/PSYCHI/PSYCHO"
                       2 "28-DAY/OTHER SHORT TERM TREATMENT"
                       3 "THERAPEUTIC COMMUNITY" 4 "HALFWAY HOUSE"
                       5 "METHADONE TREAT PROG" 6 "NON-METHADONE"
                       7 "DETOXIFICATION TREATMENT UNIT"
                       8 "OTHER OUTPATIENT DRUG TREATMENT"
                       9 "OTHER INPATIENT DRUG TREATMENT" ;
label define EL7_C_4   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL7_D_4   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROGRAM" 2 "OUTSIDE SOURCE" 3 "SELF" ;
label define EL7_E_4   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL8_0     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "CIRCLED" ;
label define EL8_1     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL8_2     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL8_11    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       11 "CIRCLED" ;
label define EL8_12    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       12 "CIRCLED" ;
label define EL8_13    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       13 "CIRCLED" ;
label define EL8_21    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       21 "CIRCLED" ;
label define EL8_22    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       22 "CIRCLED" ;
label define EL8_71    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       71 "CIRCLED" ;
label define EL8_91    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define EL8_A_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NO ONE"
                       1 "PRIMARY/REG COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define EL8_A_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NO ONE"
                       1 "PRIMARY/REG COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define EL9       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL9_A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL10      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL11      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "A LOT" ;
label define EL12      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "POOR"
                       2 "FAIR" 3 "GOOD" 4 "EXCELLENT" ;
label define EL13_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL13_B    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL13_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL13_D    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL13_E    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL13_F    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL13_G    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL13_H    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL13_I    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL13_J    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL13_K    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL13_K_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL13_K_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL13_K_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL13_K_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL14_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY MUCH" ;
label define EL14_B    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY MUCH" ;
label define EL15_M    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "JAN. - MARCH" 2 "APR. - JUNE" 3 "JULY - SEPT."
                       4 "OCT. - DEC." ;
label define EL15_Y    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL16      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL16_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL17      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL18      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "A LOT" ;
label define EL19      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "POOR"
                       2 "FAIR" 3 "GOOD" 4 "EXCELLENT" ;
label define EL20_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL20_B    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL20_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL20_D    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL20_E    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL20_F    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL20_G    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL20_H    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL20_I    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL20_J    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL20_K    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL20_K_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL20_K_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL20_K_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL20_K_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL21_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY MUCH" ;
label define EL21_B    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY MUCH" ;
label define EL22_M    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "JAN. - MARCH" 2 "APR. - JUNE" 3 "JULY - SEPT."
                       4 "OCT. - DEC." ;
label define EL22_Y    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL23      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL24      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL25      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 71 "STAFF FROM OTHER AGENCY" 91 "OTHER" ;
label define EL26_M    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "JAN. - MARCH" 2 "APR. - JUNE" 3 "JULY - SEPT."
                       4 "OCT. - DEC." ;
label define EL26_Y    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL27      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" 3 "DON'T KNOW" ;
label define EL28      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL28A_00  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "CIRCLED" ;
label define EL28A_01  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL28A_02  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL28A_11  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       11 "CIRCLED" ;
label define EL28A_12  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       12 "CIRCLED" ;
label define EL28A_13  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       13 "CIRCLED" ;
label define EL28A_21  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       21 "CIRCLED" ;
label define EL28A_22  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       22 "CIRCLED" ;
label define EL28A_23  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       23 "CIRCLED" ;
label define EL28A_24  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       24 "CIRCLED" ;
label define EL28A_25  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       25 "CIRCLED" ;
label define EL28A_26  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       26 "CIRCLED" ;
label define EL28A_71  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       71 "CIRCLED" ;
label define EL28A_91  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define EL28B     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "SELF"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 24 "VOCATIONAL COUNSELOR" 25 "PHYSICIAN"
                       26 "PHYSICIANS ASSISTANT"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define EL29      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL29_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL29_B_A  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL29_B_B  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL29_B_C  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL29_B_D  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL29_B_E  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL29_B_F  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL29_B_G  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL29_B_H  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL29_B_I  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL29_B_J  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL29_B_K  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL29BK_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL29BK_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL29BK_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL29BK_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL29_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL29_D    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "A LITTLE" 2 "A LOT" ;
label define EL29_E    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL30      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL30_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL30_B_M  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "JAN. - MARCH" 2 "APR. - JUNE" 3 "JULY - SEPT."
                       4 "OCT. - DEC." ;
label define EL30C_00  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "CIRCLED" ;
label define EL30C_01  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL30C_02  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL30C_11  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       11 "CIRCLED" ;
label define EL30C_12  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       12 "CIRCLED" ;
label define EL30C_13  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       13 "CIRCLED" ;
label define EL30C_21  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       21 "CIRCLED" ;
label define EL30C_22  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       22 "CIRCLED" ;
label define EL30C_23  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       23 "CIRCLED" ;
label define EL30C_24  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       24 "CIRCLED" ;
label define EL30C_25  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       25 "CIRCLED" ;
label define EL30C_26  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       26 "CIRCLED" ;
label define EL30C_27  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       27 "CIRCLED" ;
label define EL30C_71  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       71 "CIRCLED" ;
label define EL30C_91  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define EL30_D    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "A LITTLE" 2 "A LOT" ;
label define EL31      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL32      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY MUCH" ;
label define EL33      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "DIFFICULT" 2 "EASY" ;
label define EL33_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "VERY DIFFICULT" 2 "SOMEWHAT DIFFICULT" ;
label define EL33_B    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "VERY EASY" 2 "SOMEWHAT EASY" ;
label define EL34      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY CLOSELY" ;
label define EL35      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       10 "ALCOHOL" 20 "MARIJUANA, HASHISH, THC"
                       30 "HALLUCINOGENS/PSYCHEDELICS"
                       40 "COCAINE IN ANY FORM" 41 "CRACK"
                       50 "HEROIN ALONE,WITH OTHER DRUGS"
                       51 "HEROIN/COCAINE TOGETHER AT SAME TIME"
                       60 "NARCOTICS/OPIATES" 61 "STREET/ILLEGAL METHADONE"
                       70 "DOWNERS/DEPRESSANTS"
                       80 "AMPHETAMINES/OTHER STIMULANTS/SPEED"
                       81 "METHAMPHETAMINES/ICE" 90 "ANY OTHER DRUGS"
                       91 "INHALANTS" ;
label define EL35_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL36      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "ABSTAIN/NEVER USE AGAIN"
                       2 "REDUCE YOUR LEVEL OF USE"
                       3 "QUIT FOR A WHILE BUT USE LATER"
                       4 "CONTINUE TO USE/BEFORE ENTER PROG"
                       5 "IF VOL: OTHER" ;
label define EL37      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "A LITTLE" 2 "A LOT" ;
label define EL38      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "SAME"
                       2 "DIFFERENT" ;
label define EL39      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL39_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL39_B    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "NOT AT ALL" 2 "SOMEWHAT" 3 "VERY MUCH" ;
label define EL40      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "NEVER DRINK" 2 "DRINK OCCASIONALLY"
                       3 "DRINK REGULARLY" ;
label define EL41      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL41_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "QUIT FOR A WHILE/START LATER"
                       2 "QUIT/EVEN THOUGHT YOU SLIP FEW TIME"
                       3 "QUIT/NEVER DRINK ALC AGAIN" ;
label define EL42      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CONTINUE TO DRINK LIKE BEFORE"
                       2 "DRINK MORE ALC THAN BEFORE"
                       3 "CUT BACK ON DRINKING/>CONTROLLED"
                       4 "QUIT FOR A WHILE/START LATER" 5 "IF VOL: OTHER" ;
label define EL43      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "A LITTLE" 2 "A LOT" ;
label define EL44_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define EL44_B    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define EL45_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define EL45_B    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define EL45_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define EL45_D    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define EL45_E    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define EL45_F    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define EL45_G    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define EL45_H    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define EL45_I    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define EL45_J    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define EL45_K    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define EL45_L    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define EL46      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL47_01   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL47_02   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL47_11   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       11 "CIRCLED" ;
label define EL47_12   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       12 "CIRCLED" ;
label define EL47_13   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       13 "CIRCLED" ;
label define EL47_21   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       21 "CIRCLED" ;
label define EL47_22   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       22 "CIRCLED" ;
label define EL47_23   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       23 "CIRCLED" ;
label define EL47_71   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       71 "CIRCLED" ;
label define EL47_91   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define EL48_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL48_B    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL48_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL48_D    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL48_E    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL48_F    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL48_G    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL48_H    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL48_I    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL48_J    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL48_K    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL48_K_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL48_K_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL48_K_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL48_K_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL49_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY MUCH" ;
label define EL49_B    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY MUCH" ;
label define EL50      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       99 "99 OR MORE" ;
label define EL50_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL51      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "A LITTLE" 2 "A LOT" ;
label define EL52      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "POOR"
                       2 "FAIR" 3 "GOOD" 4 "EXCELLENT" ;
label define EL55      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL56      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL57      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL HELPFUL" 1 "SOMEWHAT HELPFUL"
                       2 "VERY HELPFUL" ;
label define EL58      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL58_A_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL58_A_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL58_A_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL58_A_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL58_B    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL58_C_M  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "JAN. - MARCH" 2 "APR. - JUNE" 3 "JULY - SEPT."
                       4 "OCT. - DEC." ;
label define EL58_D    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "AT THIS PROGRAM" 2 "AT SOME OTHER PLACE" 3 "BOTH" ;
label define EL59_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY MUCH" ;
label define EL59_B    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY MUCH" ;
label define EL60      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY MUCH" ;
label define EL63      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL64      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL65_01   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL65_02   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL65_11   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       11 "CIRCLED" ;
label define EL65_12   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       12 "CIRCLED" ;
label define EL65_13   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       13 "CIRCLED" ;
label define EL65_21   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       21 "CIRCLED" ;
label define EL65_22   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       22 "CIRCLED" ;
label define EL65_23   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       23 "CIRCLED" ;
label define EL65_28   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       28 "CIRCLED" ;
label define EL65_71   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       71 "CIRCLED" ;
label define EL65_91   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define EL65_A_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 28 "CERTIFIED FAMILY COUNSELOR"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define EL65_A_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 28 "CERTIFIED FAMILY COUNSELOR"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define EL66      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "INDIVIDUAL" 2 "GROUP" 3 "BOTH" ;
label define EL66_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL66_B    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL66_C_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL66_C_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL66_C_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL66_C_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL66_C_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL66_C_6  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL66_C_7  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define EL66_C_8  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       8 "CIRCLED" ;
label define EL66_C_9  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       9 "CIRCLED" ;
label define EL66_D    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL HELPFUL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL66_E    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL66_F    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL66_G_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL66_G_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL66_G_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL66_G_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL66_G_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL66_H_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL66_H_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL66_H_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL66_H_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL66_H_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL66_H_6  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL66_H_7  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define EL66_H_8  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       8 "CIRCLED" ;
label define EL66_H_9  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       9 "CIRCLED" ;
label define EL66_I    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL HELPFUL" 1 "SOMEWHAT HELPFUL"
                       2 "VERY HELPFUL" ;
label define EL67      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "INDIVIDUAL" 2 "GROUP" 3 "BOTH" ;
label define EL67_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL67_B    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL67_C_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL67_C_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL67_C_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL67_C_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL67_C_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL67_C_6  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL67_C_7  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define EL67_C_8  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       8 "CIRCLED" ;
label define EL67_C_9  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       9 "CIRCLED" ;
label define EL67_D    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL67_E    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL67_F    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL67_G_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL67_G_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL67_G_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL67_G_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL67_G_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL67_H_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL67_H_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL67_H_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL67_H_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL67_H_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL67_H_6  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL67_H_7  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define EL67_H_8  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       8 "CIRCLED" ;
label define EL67_H_9  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       9 "CIRCLED" ;
label define EL67_I    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL HELPFUL" 1 "SOMEWHAT HELPFUL"
                       2 "VERY HELPFUL" ;
label define EL68      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL68A_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL68A_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL68A_3   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL68A_4   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL68A_5   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL68A_6   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL68B_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "A COMMUNITY MENTAL HEALTH SERVICE"
                       2 "A PRIVATE PSYCHIATRIC HOSPITAL"
                       3 "ANY OTHER HOSPITAL OR FACILITY"
                       4 "AN EMERGENCY ROOM OR CRISIS CENTER"
                       5 "PRIVATE THERAPIST" 6 "OTHER" ;
label define EL68C_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROGRAM" 2 "SOMEONE ELSE" 3 "SELF" ;
label define EL68D_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL68E_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL68F1_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL68F1_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL68F111  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       11 "CIRCLED" ;
label define EL68F112  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       12 "CIRCLED" ;
label define EL68F113  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       13 "CIRCLED" ;
label define EL68F121  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       21 "CIRCLED" ;
label define EL68F122  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       22 "CIRCLED" ;
label define EL68F123  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       23 "CIRCLED" ;
label define EL68F128  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       28 "CIRCLED" ;
label define EL68F171  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       71 "CIRCLED" ;
label define EL68F191  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define EL68G_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 28 "CERTIFIED FAMILY COUNSELOR"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define EL68B_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "A COMMUNITY MENTAL HEALTH SERVICE"
                       2 "A PRIVATE PSYCHIATRIC HOSPITAL"
                       3 "ANY OTHER HOSPITAL OR FACILITY"
                       4 "AN EMERGENCY ROOM OR CRISIS CENTER"
                       5 "PRIVATE THERAPIST" 6 "OTHER" ;
label define EL68C_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROGRAM" 2 "SOMEONE ELSE" 3 "SELF" ;
label define EL68D_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL68E_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL68F2_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL68F2_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL68F211  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       11 "CIRCLED" ;
label define EL68F212  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       12 "CIRCLED" ;
label define EL68F213  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       13 "CIRCLED" ;
label define EL68F221  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       21 "CIRCLED" ;
label define EL68F222  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       22 "CIRCLED" ;
label define EL68F223  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       23 "CIRCLED" ;
label define EL68F228  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       28 "CIRCLED" ;
label define EL68F271  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       71 "CIRCLED" ;
label define EL68F291  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define EL68G_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 28 "CERTIFIED FAMILY COUNSELOR"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define EL69      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL69_A_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL69_B_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL69_A_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL69_B_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL69_A_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL69_B_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL69_A_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL69_B_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL69_A_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL69_B_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL70      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL71      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL72_01   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL72_02   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL72_22   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       22 "CIRCLED" ;
label define EL72_23   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       23 "CIRCLED" ;
label define EL72_24   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       24 "CIRCLED" ;
label define EL72_25   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       25 "CIRCLED" ;
label define EL72_26   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       26 "CIRCLED" ;
label define EL72_71   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       71 "CIRCLED" ;
label define EL72_91   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define EL72_A1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       22 "PSYCHIATRIST" 23 "NURSE" 24 "PHYSICIAN"
                       25 "PHYSICIANS ASSISTANT" 26 "DENTIST"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define EL72_A2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       22 "PSYCHIATRIST" 23 "NURSE" 24 "PHYSICIAN"
                       25 "PHYSICIANS ASSISTANT" 26 "DENTIST"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define EL73      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL73_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL73_B01  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL73_B02  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL73_B03  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL73_B04  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL73_B05  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL73_B06  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL73_B07  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define EL73_B08  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       8 "CIRCLED" ;
label define EL73_B09  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       9 "CIRCLED" ;
label define EL73_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL HELPFUL" 1 "SOMEWHAT HELPFUL"
                       2 "VERY HELPFUL" ;
label define EL74      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL74_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL74_B01  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL74_B02  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL74_B03  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL74_B04  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL74_B05  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL74_B06  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL74_B07  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define EL74_B08  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       8 "CIRCLED" ;
label define EL74_B09  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       9 "CIRCLED" ;
label define EL74_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL HELPFUL" 1 "SOMEWHAT HELPFUL"
                       2 "VERY HELPFUL" ;
label define EL75      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL75_A_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL75_A_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL75_A_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL75_A_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL75_A_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL75_A_6  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL75B_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIVATE PHYSICIAN OR DENTIST"
                       2 "HOSPITAL OR PUBLIC HEALTH CLINIC"
                       3 "MILITARY OR VA HOSPITAL OR CLINIC"
                       4 "HEALTH COOPERATIVE" 5 "OTHER MEDICAL" 6 "OTHER" ;
label define EL75C_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROGRAM" 2 "SOMEONE ELSE" 3 "SELF" ;
label define EL75D_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL75E_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL75F101  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL75F102  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL75F122  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       22 "CIRCLED" ;
label define EL75F123  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       23 "CIRCLED" ;
label define EL75F124  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       24 "CIRCLED" ;
label define EL75F125  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       25 "CIRCLED" ;
label define EL75F126  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       26 "CIRCLED" ;
label define EL75F171  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       71 "CIRCLED" ;
label define EL75F191  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define EL75G_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       22 "PSYCHIATRIST" 23 "NURSE" 24 "PHYSICIAN"
                       25 "PHYSICIAN'S ASSISTANT" 26 "DENTIST"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define EL75B_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIVATE PHYSICIAN OR DENTIST"
                       2 "HOSPITAL OR PUBLIC HEALTH CLINIC"
                       3 "MILITARY OR VA HOSPITAL OR CLINIC"
                       4 "HEALTH COOPERATIVE" 5 "OTHER MEDICAL" 6 "OTHER" ;
label define EL75C_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROGRAM" 2 "SOMEONE ELSE" 3 "SELF" ;
label define EL75D_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL75E_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL75F201  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL75F202  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL75F222  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       22 "CIRCLED" ;
label define EL75F223  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       23 "CIRCLED" ;
label define EL75F224  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       24 "CIRCLED" ;
label define EL75F225  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       25 "CIRCLED" ;
label define EL75F226  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       26 "CIRCLED" ;
label define EL75F271  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       71 "CIRCLED" ;
label define EL75F291  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define EL75G_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       22 "PSYCHIATRIST" 23 "NURSE" 24 "PHYSICIAN"
                       25 "PHYSICIAN'S ASSISTANT" 26 "DENTIST"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define EL76      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL76_A_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL76_A_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL76_A_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL76_A_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL77      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL77_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL77B_01  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL77B_02  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL77B_11  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       11 "CIRCLED" ;
label define EL77B_12  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       12 "CIRCLED" ;
label define EL77B_13  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       13 "CIRCLED" ;
label define EL77B_21  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       21 "CIRCLED" ;
label define EL77B_22  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       22 "CIRCLED" ;
label define EL77B_23  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       23 "CIRCLED" ;
label define EL77B_24  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       24 "CIRCLED" ;
label define EL77B_25  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       25 "CIRCLED" ;
label define EL77B_26  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       26 "CIRCLED" ;
label define EL77B_27  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       27 "CIRCLED" ;
label define EL77B_28  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       28 "CIRCLED" ;
label define EL77B_71  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       71 "CIRCLED" ;
label define EL77B_91  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define EL77_C_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL77_C_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL77_C_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL77_C_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL77_C_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL77_C_6  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL77_C_7  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define EL77_C_8  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       8 "CIRCLED" ;
label define EL78      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL79      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL80_01   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL80_02   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL80_11   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       11 "CIRCLED" ;
label define EL80_12   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       12 "CIRCLED" ;
label define EL80_13   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       13 "CIRCLED" ;
label define EL80_21   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       21 "CIRCLED" ;
label define EL80_22   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       22 "CIRCLED" ;
label define EL80_23   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       23 "CIRCLED" ;
label define EL80_28   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       28 "CIRCLED" ;
label define EL80_71   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       71 "CIRCLED" ;
label define EL80_91   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define EL80_A1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 28 "CERTIFIED FAMILY COUNSELOR"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define EL80_A2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 28 "CERTIFIED FAMILY COUNSELOR"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define EL81_01   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL81_02   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL81_03   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL81_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL81_B    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL81_C_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL81_C_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL81_C_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL81_C_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL81_C_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL81_C_6  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL81_D    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL81_E    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL81_F    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL81_G_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL81_G_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL81_G_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL81_G_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL81_G_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL81_H_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL81_H_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL81_H_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL81_H_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL81_H_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL81_H_6  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL81_I    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY" ;
label define EL81_J    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL81_K_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL81_K_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL81_K_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL81_K_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL81_K_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL81_K_6  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL81_K_7  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define EL81_K_8  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       8 "CIRCLED" ;
label define EL81_L_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL81_L_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL81_L_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL81_L_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL81_L_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL81_L_6  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL81_M    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL82_01   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL82_02   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL82_03   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL82_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL82_B    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL82_C_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL82_C_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL82_C_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL82_C_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL82_C_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL82_C_6  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL82_D    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL82_E    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL82_F    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL82_G_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL82_G_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL82_G_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL82_G_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL82_G_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL82_H_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL82_H_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL82_H_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL82_H_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL82_H_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL82_H_6  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL82_I    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL82_J    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL82_K_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL82_K_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL82_K_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL82_K_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL82_K_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL82_K_6  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL82_K_7  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define EL82_K_8  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       8 "CIRCLED" ;
label define EL82_L_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL82_L_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL82_L_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL82_L_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL82_L_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL82_L_6  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL82_M    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL83      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL83A_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL83A_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL83A_3   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL83A_4   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL83A_5   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL83B_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "SOCIAL SERVICES OR FAMILY SERVICES"
                       2 "MENTAL HEALTH CENTER"
                       3 "CHURCH OF RELIGIOUS ORGANIZATION"
                       4 "PRIVATE MARITAL OR FAMILY COUNSELOR" 5 "OTHER" ;
label define EL83C_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROGRAM" 2 "SOMEONE ELSE" 3 "SELF" ;
label define EL83D_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL83E_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL83F1_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL83F1_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL83F111  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       11 "CIRCLED" ;
label define EL83F112  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       12 "CIRCLED" ;
label define EL83F113  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       13 "CIRCLED" ;
label define EL83F121  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       21 "CIRCLED" ;
label define EL83F122  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       22 "CIRCLED" ;
label define EL83F123  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       23 "CIRCLED" ;
label define EL83F128  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       28 "CIRCLED" ;
label define EL83F171  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       71 "CIRCLED" ;
label define EL83F191  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define EL83G_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 28 "CERTIFIED FAMILY COUNSELOR"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define EL83B_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "SOCIAL SERVICES OR FAMILY SERVICES"
                       2 "MENTAL HEALTH CENTER"
                       3 "CHURCH OF RELIGIOUS ORGANIZATION"
                       4 "PRIVATE MARITAL OR FAMILY COUNSELOR" 5 "OTHER" ;
label define EL83C_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROGRAM" 2 "SOMEONE ELSE" 3 "SELF" ;
label define EL83D_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL83E_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL83F2_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL83F2_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL83F211  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       11 "CIRCLED" ;
label define EL83F212  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       12 "CIRCLED" ;
label define EL83F213  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       13 "CIRCLED" ;
label define EL83F221  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       21 "CIRCLED" ;
label define EL83F222  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       22 "CIRCLED" ;
label define EL83F223  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       23 "CIRCLED" ;
label define EL83F228  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       28 "CIRCLED" ;
label define EL83F271  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       71 "CIRCLED" ;
label define EL83F291  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define EL83G_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 28 "CERTIFIED FAMILY COUNSELOR"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define EL84      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL85      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL86_01   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL86_02   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL86_11   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       11 "CIRCLED" ;
label define EL86_12   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       12 "CIRCLED" ;
label define EL86_13   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       13 "CIRCLED" ;
label define EL86_21   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       21 "CIRCLED" ;
label define EL86_22   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       22 "CIRCLED" ;
label define EL86_23   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       23 "CIRCLED" ;
label define EL86_27   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       27 "CIRCLED" ;
label define EL86_29   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       29 "TEACHER" ;
label define EL86_71   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       71 "CIRCLED" ;
label define EL86_91   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define EL86_A1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 27 "VOCATIONAL COUNSELOR" 29 "TEACHER"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define EL86_A2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 27 "VOCATIONAL COUNSELOR" 29 "TEACHER"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define EL87_01   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL87_02   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL87_03   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL87_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       436 "OCC. COOKS"
                       487 "OCC. ANIMAL CARETAKERS, EXCEPT FARM" ;
label define EL87_B    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL87_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL87_D    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "DEGREE"
                       2 "DIPLOMA" 3 "CERTIFICATE" 4 "OTHER" ;
label define EL87_E    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL87_F    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL HELPFUL" 1 "SOMEWHAT HELPFUL"
                       2 "VERY HELPFUL" ;
label define EL87_G_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL87_G_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL87_G_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL87_G_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL87_G_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL87_G_6  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL87_G_7  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define EL87_G_8  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       8 "CIRCLED" ;
label define EL87_H    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL87_I    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL87_J    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL87_K    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL87_L_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL87_L_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL87_L_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL87_L_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL87_L_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL87_L_6  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL87_M    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "ALL INDIVIDUAL" 2 "ALL GROUP"
                       3 "BOTH INDIVIDUAL/GROUP" ;
label define EL87_N    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL87_O    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL87_P    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL88_01   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL88_02   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL88_03   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL88_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL88_B    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL88_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL88_D    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "DEGREE"
                       2 "DIPLOMA" 3 "CERTIFICATE" 4 "OTHER" ;
label define EL88_E    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL88_F    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL88_G_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL88_G_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL88_G_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL88_G_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL88_G_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL88_G_6  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL88_G_7  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define EL88_G_8  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       8 "CIRCLED" ;
label define EL88_H    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL88_I    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL88_J    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL88_K    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL88_L_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL88_L_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL88_L_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL88_L_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL88_L_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL88_L_6  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL88_M    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "ALL INDIVIDUAL" 2 "ALL GROUP"
                       3 "BOTH INDIVIDUAL/GROUP" ;
label define EL88_N    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL88_O    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL88_P    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL HELPFUL" 1 "SOMEWHAT HELPFUL"
                       2 "VERY HELPFUL" ;
label define EL89      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL89_A_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL89_A_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL89_A_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL89_A_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL89_A_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL89_A_6  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL89_A_7  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define EL89_A_8  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       8 "CIRCLED" ;
label define EL89_A_9  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       9 "CIRCLED" ;
label define EL89B_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STATE OFFICE OF EMPLOYMENT" 2 "DVR/OVR/VESID"
                       3 "JTPA/PIC" 4 "PUBLIC EMPLOYMENT/TRAINING AGENCIES"
                       5 "PRIVATE EMPLOYMENT/TRAINING AGENCIES"
                       6 "BUSINESS ORGANIZATIONS"
                       7 "VOCATIONAL/TECHNICAL/COMMUNITY COLLEGE"
                       8 "CHARITABLE AGENCIES" 9 "OTHER" ;
label define EL89C_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROGRAM" 2 "SOMEONE ELSE" 3 "SELF" ;
label define EL89D_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL89E_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL89F1_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL89F1_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL89F111  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       11 "CIRCLED" ;
label define EL89F112  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       12 "CIRCLED" ;
label define EL89F113  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       13 "CIRCLED" ;
label define EL89F121  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       21 "CIRCLED" ;
label define EL89F122  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       22 "CIRCLED" ;
label define EL89F123  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       23 "CIRCLED" ;
label define EL89F127  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       27 "CIRCLED" ;
label define EL89F129  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       29 "CIRCLED" ;
label define EL89F171  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       71 "CIRCLED" ;
label define EL89F191  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define EL89G_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 27 "VOCATIONAL COUNSELOR" 29 "TEACHER"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define EL89B_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STATE OFFICE OF EMPLOYMENT" 2 "DVR/OVR/VESID"
                       3 "JTPA/PIC" 4 "PUBLIC EMPLOYMENT/TRAINING AGENCIES"
                       5 "PRIVATE EMPLOYMENT/TRAINING AGENCIES"
                       6 "BUSINESS ORGANIZATIONS"
                       7 "VOCATIONAL/TECHNICAL/COMMUNITY COLLEGE"
                       8 "CHARITABLE AGENCIES" 9 "OTHER" ;
label define EL89C_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROGRAM" 2 "SOMEONE ELSE" 3 "SELF" ;
label define EL89D_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL89E_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL89F2_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL89F2_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL89F211  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       11 "CIRCLED" ;
label define EL89F212  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       12 "CIRCLED" ;
label define EL89F213  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       13 "CIRCLED" ;
label define EL89F221  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       21 "CIRCLED" ;
label define EL89F222  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       22 "CIRCLED" ;
label define EL89F223  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       23 "CIRCLED" ;
label define EL89F227  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       27 "CIRCLED" ;
label define EL89F229  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       29 "CIRCLED" ;
label define EL89F271  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       71 "CIRCLED" ;
label define EL89F291  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define EL89G_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 27 "VOCATIONAL COUNSELOR" 29 "TEACHER"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define EL90      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL91      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL92_01   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL92_02   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL92_11   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       11 "CIRCLED" ;
label define EL92_12   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       12 "CIRCLED" ;
label define EL92_13   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       13 "CIRCLED" ;
label define EL92_21   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       21 "CIRCLED" ;
label define EL92_22   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       22 "CIRCLED" ;
label define EL92_23   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       23 "CIRCLED" ;
label define EL92_27   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       27 "CIRCLED" ;
label define EL92_29   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       29 "CIRCLED" ;
label define EL92_71   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       71 "CIRCLED" ;
label define EL92_91   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define EL92A_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 27 "VOCATIONAL COUNSELOR" 29 "TEACHER"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define EL92A_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 27 "VOCATIONAL COUNSELOR" 29 "TEACHER"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define EL93      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       999 "999 OR MORE" ;
label define EL93_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL93_B_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL93_B_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL93_B_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL93_B_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL93_B_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL93_B_6  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL93_B_7  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define EL93_B_8  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       8 "CIRCLED" ;
label define EL93_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL94      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL94_A    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL94_B_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL94_B_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL94_B_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL94_B_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL94_B_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL94_B_6  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL94_B_7  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define EL94_B_8  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       8 "CIRCLED" ;
label define EL94_C    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL95      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL95_A_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL95_A_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL95_A_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL95_A_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL95_A_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL95_A_6  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL95B_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PUBLIC SCHOOL SYSTEM" 2 "JUNIOR COMMUNITY COLLEGE"
                       3 "FOUR YEAR COLLEGE/GRADUATE PROGRAM"
                       4 "PRIVATE EDUCATION PROGRAM" 5 "PUBLIC AGENCIES"
                       6 "OTHER" ;
label define EL95C_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROGRAM" 2 "SOMEONE ELSE" 3 "SELF" ;
label define EL95D_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       99 "99 OR MORE" ;
label define EL95E_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL HELPFUL" 1 "SOMEWHAT HELPFUL"
                       2 "VERY HELPFUL" ;
label define EL95F1_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL95F1_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL95F127  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       27 "CIRCLED" ;
label define EL95F129  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       29 "CIRCLED" ;
label define EL95F171  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       71 "CIRCLED" ;
label define EL95F191  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define EL95G_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       27 "PROG VOCATIONAL COUNSELOR" 29 "TEACHER"
                       71 "STAFF FROM ANOTHER AGENCY"
                       91 "OTHER PROGRAM STAFF" ;
label define EL95B_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PUBLIC SCHOOL SYSTEM" 2 "JUNIOR COMMUNITY COLLEGE"
                       3 "FOUR YEAR COLLEGE/GRADUATE PROGRAM"
                       4 "PRIVATE EDUCATION PROGRAM" 5 "PUBLIC AGENCIES"
                       6 "OTHER" ;
label define EL95C_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROGRAM" 2 "SOMEONE ELSE" 3 "SELF" ;
label define EL95D_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL95E_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL HELPFUL" 1 "SOMEWHAT HELPFUL"
                       2 "VERY HELPFUL" ;
label define EL95F2_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL95F2_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL95F227  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       27 "CIRCLED" ;
label define EL95F229  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       29 "CIRCLED" ;
label define EL95F271  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       71 "CIRCLED" ;
label define EL95F291  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define EL95G_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       27 "PROG VOCATIONAL COUNSELOR" 29 "TEACHER"
                       71 "STAFF FROM ANOTHER AGENCY"
                       91 "OTHER PROGRAM STAFF" ;
label define EL96      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL97      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL98_01   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL98_02   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL98_11   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       11 "CIRCLED" ;
label define EL98_12   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       12 "CIRCLED" ;
label define EL98_13   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       13 "CIRCLED" ;
label define EL98_21   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       21 "CIRCLED" ;
label define EL98_22   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       22 "CIRCLED" ;
label define EL98_23   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       23 "CIRCLED" ;
label define EL98_27   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       27 "CIRCLED" ;
label define EL98_28   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       28 "CIRCLED" ;
label define EL98_29   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       29 "CIRCLED" ;
label define EL98_30   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       30 "CIRCLED" ;
label define EL98_71   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       71 "CIRCLED" ;
label define EL98_91   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define EL98A_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 27 "VOCATIONAL COUNSELOR"
                       28 "CERTIFIED FAMILY COUNSELOR" 29 "TEACHER"
                       30 "TASC STAFF" 71 "STAFF FROM ANOTHER AGENCY"
                       91 "OTHER" ;
label define EL98A_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 27 "VOCATIONAL COUNSELOR"
                       28 "CERTIFIED FAMILY COUNSELOR" 29 "TEACHER"
                       30 "TASC STAFF" 71 "STAFF FROM ANOTHER AGENCY"
                       91 "OTHER" ;
label define EL99      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL99_A_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL99_A_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL99_A_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL99_A_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL99_A_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL99_A_6  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL99_B    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL100     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL100A_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL100A_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL100A_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL100A_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL100A_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL100A_6  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL100_B   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL101     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL101A_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL101A_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL101A_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL101A_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL101A_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL101A_6  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL101B_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "TASC PROGRAM STAFF" 2 "PAROLE OR PROBATION OFFICER"
                       3 "PRIVATE LAWYER" 4 "LEGAL AID"
                       5 "PUBLIC DEFENDER/COURT APPOINTED COUNSEL"
                       6 "OTHER LEGAL" ;
label define EL101C_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROGRAM" 2 "SOMEONE ELSE" 3 "SELF" ;
label define EL101D_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL101E_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL HELPFUL" 1 "SOMEWHAT HELPFUL"
                       2 "VERY HELPFUL" ;
label define EL101B_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "TASC PROGRAM STAFF" 2 "PAROLE OR PROBATION OFFICER"
                       3 "PRIVATE LAWYER" 4 "LEGAL AID"
                       5 "PUBLIC DEFENDER/COURT APPOINTED COUNSEL"
                       6 "OTHER LEGAL" ;
label define EL101C_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROGRAM" 2 "SOMEONE ELSE" 3 "SELF" ;
label define EL101D_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL101E_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL HELPFUL" 1 "SOMEWHAT HELPFUL"
                       2 "VERY HELPFUL" ;
label define EL102     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL103     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL104_01  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL104_02  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL104_11  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       11 "CIRCLED" ;
label define EL104_12  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       12 "CIRCLED" ;
label define EL104_13  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       13 "CIRCLED" ;
label define EL104_21  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       21 "CIRCLED" ;
label define EL104_22  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       22 "CIRCLED" ;
label define EL104_23  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       23 "CIRCLED" ;
label define EL104_27  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       27 "CIRCLED" ;
label define EL104_28  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       28 "CIRCLED" ;
label define EL104_29  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       29 "CIRCLED" ;
label define EL104_71  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       71 "CIRCLED" ;
label define EL104_91  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define EL104A_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 27 "VOCATIONAL COUNSELOR"
                       28 "CERTIFIED FAMILY COUNSELOR" 29 "TEACHER"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define EL104A_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 27 "VOCATIONAL COUNSELOR"
                       28 "CERTIFIED FAMILY COUNSELOR" 29 "TEACHER"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define EL105     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL105A_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL105A_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL105A_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL105A_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL105A_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL105A_6  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL105_B   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL106     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL106A_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL106A_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL106A_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EL106A_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EL106A_5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EL106A_6  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EL106_B   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL107     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL107A51  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       51 "CIRCLED" ;
label define EL107A52  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       52 "CIRCLED" ;
label define EL107A53  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       53 "CIRCLED" ;
label define EL107A54  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       54 "CIRCLED" ;
label define EL107A91  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define EL107B_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       51 "SOCIAL SERVICES" 52 "VOCATIONAL REHABILITATION"
                       53 "VETERANS AFFAIRS" 54 "SOCIAL SECURITY" 91 "OTHER" ;
label define EL107C_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROGRAM" 2 "SOMEONE ELSE" 3 "SELF" ;
label define EL107D_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL107E_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL107B_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       51 "SOCIAL SERVICES" 52 "VOCATIONAL REHABILITATION"
                       53 "VETERANS AFFAIRS" 54 "SOCIAL SECURITY" 91 "OTHER" ;
label define EL107C_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROGRAM" 2 "SOMEONE ELSE" 3 "SELF" ;
label define EL107D_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL107E_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define EL108     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL108_A   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL108_B   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL HELPFUL" 1 "SOMEWHAT HELPFUL"
                       2 "VERY HELPFUL" ;
label define EL109     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL110     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL111_A   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY MUCH" ;
label define EL111_B   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY MUCH" ;
label define EL113_01  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EL113_02  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EL113_11  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       11 "CIRCLED" ;
label define EL113_12  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       12 "CIRCLED" ;
label define EL113_13  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       13 "CIRCLED" ;
label define EL113_21  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       21 "CIRCLED" ;
label define EL113_22  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       22 "CIRCLED" ;
label define EL113_23  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       23 "CIRCLED" ;
label define EL113_24  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       24 "CIRCLED" ;
label define EL113_25  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       25 "CIRCLED" ;
label define EL113_26  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       26 "CIRCLED" ;
label define EL113_27  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       27 "CIRCLED" ;
label define EL113_28  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       28 "CIRCLED" ;
label define EL113_29  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       29 "CIRCLED" ;
label define EL113_71  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       71 "CIRCLED" ;
label define EL113_91  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define EL114_A   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL114_B   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL114_C   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL114_D   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL114_E   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL114_F   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL114_G   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL114_H   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL114_I   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL114_J   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL114_K   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL114K_1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL114K_2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL114K_3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL114K_4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "SOME SESSIONS" 2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define EL115     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NO SERVICES" 1 "REGULAR ADDICTION GROUP"
                       2 "OTHER GROUP COUNSELING" 3 "INDIVIDUAL COUNSELING"
                       4 "12-STEP/SELF-HELP GROUP" 5 "CRISIS COUNSELING"
                       6 "UNSCHEDULED HELP" 7 "TALKS/FILMS/DISCUSSIONS"
                       8 "DRUG COUNSELING" 9 "ALCOHOL COUNSELING"
                       10 "DRUG TESTING" 11 "PSYCHOLOGICAL/MENTAL HEALTH"
                       12 "FAMILY RELATIONSHIP COUNSELING" 13 "MEDICATION"
                       14 "MEDICAL" 15 "LEGAL" 16 "EDUCATION/JOB TRAINING"
                       17 "HELP FINDING A JOB" 18 "OTHER JOB ASSISTANCE"
                       19 "FINANCIAL ASSISTANCE" 91 "OTHER" ;
label define EL116     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NO SERVICES" 1 "REGULAR ADDICTION GROUP"
                       2 "OTHER GROUP COUNSELING" 3 "INDIVIDUAL COUNSELING"
                       4 "12-STEP/SELF-HELP GROUP" 5 "CRISIS COUNSELING"
                       6 "UNSCHEDULED HELP" 7 "TALKS/FILMS/DISCUSSIONS"
                       8 "DRUG COUNSELING" 9 "ALCOHOL COUNSELING"
                       10 "DRUG TESTING" 11 "PSYCHOLOGICAL/MENTAL HEALTH"
                       12 "FAMILY RELATIONSHIP COUNSELING" 13 "MEDICATION"
                       14 "MEDICAL" 15 "LEGAL" 16 "EDUCATION/JOB TRAINING"
                       17 "HELP FINDING A JOB" 18 "OTHER JOB ASSISTANCE"
                       19 "FINANCIAL ASSISTANCE" 91 "OTHER" ;
label define EL117     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL117_B1  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "SELF"
                       2 "COUNSELOR OR CASE MANAGER" 3 "ANOTHER STAFF MEMBER"
                       4 "ANOTHER CLIENT/RESIDENT/PATIENT"
                       5 "THE PROGRAM OVERALL"
                       6 "SOMETHING/SOMEONE OUTSIDE PROGRAM" 7 "OTHER" ;
label define EL117_B2  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "SELF"
                       2 "COUNSELOR OR CASE MANAGER" 3 "ANOTHER STAFF MEMBER"
                       4 "ANOTHER CLIENT/RESIDENT/PATIENT"
                       5 "THE PROGRAM OVERALL"
                       6 "SOMETHING/SOMEONE OUTSIDE PROGRAM" 7 "OTHER" ;
label define EL117_B3  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "SELF"
                       2 "COUNSELOR OR CASE MANAGER" 3 "ANOTHER STAFF MEMBER"
                       4 "ANOTHER CLIENT/RESIDENT/PATIENT"
                       5 "THE PROGRAM OVERALL"
                       6 "SOMETHING/SOMEONE OUTSIDE PROGRAM" 7 "OTHER" ;
label define EL117_B4  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "SELF"
                       2 "COUNSELOR OR CASE MANAGER" 3 "ANOTHER STAFF MEMBER"
                       4 "ANOTHER CLIENT/RESIDENT/PATIENT"
                       5 "THE PROGRAM OVERALL"
                       6 "SOMETHING/SOMEONE OUTSIDE PROGRAM" 7 "OTHER" ;
label define EL117_B5  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "SELF"
                       2 "COUNSELOR OR CASE MANAGER" 3 "ANOTHER STAFF MEMBER"
                       4 "ANOTHER CLIENT/RESIDENT/PATIENT"
                       5 "THE PROGRAM OVERALL"
                       6 "SOMETHING/SOMEONE OUTSIDE PROGRAM" 7 "OTHER" ;
label define EL118     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EL118_A   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "A LITTLE" 2 "A LOT" ;
label define EL119     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "A LITTLE" 2 "A LOT" ;
label define EL120     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "VERY FEW" 2 "SOME" 3 "MOST" ;
label define EL121_A   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "A LITTLE" 2 "A LOT" ;
label define EL121_B   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "A LITTLE" 2 "A LOT" ;
label define EL121_C   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "A LITTLE" 2 "A LOT" ;
label define EL121_D   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "A LITTLE" 2 "A LOT" ;
label define EL121_E   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "A LITTLE" 2 "A LOT" ;
label define EL121_F   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "A LITTLE" 2 "A LOT" ;
label define EL122     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY LIKELY" ;
label define EL123_W   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EL124     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "A LITTLE BIT" 2 "VERY MUCH" ;
label define EL125     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "A LITTLE BIT" 2 "VERY MUCH" ;
label define EL126     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "A LITTLE BIT" 2 "VERY MUCH" ;
label define EL127     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "A LITTLE BIT" 2 "VERY MUCH" ;
label define EL128     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "A LITTLE BIT" 2 "VERY MUCH" ;
label define ELDM      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "JAN. - MARCH" 2 "APR. - JUNE" 3 "JULY - SEPT."
                       4 "OCT. - DEC." ;
label define ELTH      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ELTM      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ELAMPM    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "AM"
                       2 "PM" ;
label define EM1       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EM2       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CAN'T DO/REFUSE" ;
label define EM3       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CAN'T DO/REFUSE" ;
label define EM4       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CAN'T DO/REFUSE" ;
label define EM5       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CAN'T DO/REFUSE" ;
label define EM6       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CAN'T DO/REFUSE" ;
label define EM7       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CAN'T DO/REFUSE" ;
label define EM8       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CAN'T DO/REFUSE" ;
label define EM9       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CAN'T DO/REFUSE" ;
label define EM10A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CAN'T DO/REFUSE" ;
label define EM10B     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CAN'T DO/REFUSE" ;
label define EM11A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CAN'T DO/REFUSE" ;
label define EM11B     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CAN'T DO/REFUSE" ;
label define EM11C     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CAN'T DO/REFUSE" ;
label define EM12A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR" 7 "SAYS CAN'T DO" ;
label define EM12B     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR" 7 "SAYS CAN'T DO" ;
label define EM12C     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR" 7 "SAYS CAN'T DO" ;
label define EM12D     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR" 7 "SAYS CAN'T DO" ;
label define EM12E     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR" 7 "SAYS CAN'T DO" ;
label define EM13      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NO ERROR" 1 "1 ERROR" 2 "2 ERRORS" 3 "3 ERRORS"
                       4 "4 ERRORS" 5 "5 ERRORS" ;
label define EM14A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CAN'T DO/REFUSE" ;
label define EM14B     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CAN'T DO/REFUSE" ;
label define EM14C     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CAN'T DO/REFUSE" ;
label define EM15A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CAN'T DO/REFUSE" 6 "HANDICAP" ;
label define EM15B     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CAN'T DO/REFUSE" 6 "HANDICAP" ;
label define EM16      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CAN'T DO/REFUSE" 6 "HANDICAP" ;
label define EM17      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CAN'T DO/REFUSE" 6 "HANDICAP"
                       7 "CAN'T READ ENGLISH" ;
label define EM18A     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CAN'T DO/REFUSE" 6 "HANDICAP" ;
label define EM18B     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CAN'T DO/REFUSE" 6 "HANDICAP" ;
label define EM18C     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CAN'T DO/REFUSE" 6 "HANDICAP" ;
label define EM19      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CAN'T DO" 6 "HANDICAP"
                       7 "CAN'T WRITE (ENGLISH)" ;
label define EM20      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CAN'T DO" 6 "HANDICAP" ;
label define EM21      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EMDM      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "JAN. - MARCH" 2 "APR. - JUNE" 3 "JULY - SEPT."
                       4 "OCT. - DEC." ;
label define EMTH      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EMTM      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EMAMPM    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "AM"
                       2 "PM" ;
label define EN1       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EN2       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EN2A      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EN3_1_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EN3_1_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "MILD"
                       2 "MODERATE" 3 "EXTREME" ;
label define EN3_2_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EN3_2_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "MILD"
                       2 "MODERATE" 3 "EXTREME" ;
label define EN3_3_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EN3_3_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "MILD"
                       2 "MODERATE" 3 "EXTREME" ;
label define EN3_4_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EN3_4_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "MILD"
                       2 "MODERATE" 3 "EXTREME" ;
label define EN4       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EN4A1     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define EN4A2     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define EN4A3     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define EN4A4     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define EN4A5     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define EN4A6     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define EN5       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "EAGER"
                       2 "RECEPTIVE" 3 "NO REACTION" 4 "RELUCTANT"
                       5 "REFUSED" 6 "NOT DISCUSSED" ;
label define EN6       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EN6A1     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EN6A2     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define JDATE_M   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "JAN. - MARCH" 2 "APR. - JUNE" 3 "JULY - SEPT."
                       4 "OCT. - DEC." ;
label define JDATE_Y   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EIA1_1    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EIA1_2    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EIA2_1    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EIA2_2    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EIA3_1    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EIA3_2    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EIA4_1    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EIA4_2    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EIA5_1    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EIA5_2    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EIA6_1    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EIA6_2    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EIA7_1    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EIA7_2    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       999 "999 OR MORE" ;
label define EIA8_1    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EIA8_2    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define EIA9_1    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EIA9_2    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       999 "999 OR MORE" ;
label define EIA10_1   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define EIA10_2   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define NP1A      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "A LITTLE BIT" 2 "MODERATELY"
                       3 "QUITE A BIT" 4 "EXTREMELY" ;
label define NP1B      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "A LITTLE BIT" 2 "MODERATELY"
                       3 "QUITE A BIT" 4 "EXTREMELY" ;
label define NP1C      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "A LITTLE BIT" 2 "MODERATELY"
                       3 "QUITE A BIT" 4 "EXTREMELY" ;
label define NP1D      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "A LITTLE BIT" 2 "MODERATELY"
                       3 "QUITE A BIT" 4 "EXTREMELY" ;
label define NP1E      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "A LITTLE BIT" 2 "MODERATELY"
                       3 "QUITE A BIT" 4 "EXTREMELY" ;
label define NP1F      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "A LITTLE BIT" 2 "MODERATELY"
                       3 "QUITE A BIT" 4 "EXTREMELY" ;
label define NP1G      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "A LITTLE BIT" 2 "MODERATELY"
                       3 "QUITE A BIT" 4 "EXTREMELY" ;
label define NP1H      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "A LITTLE BIT" 2 "MODERATELY"
                       3 "QUITE A BIT" 4 "EXTREMELY" ;
label define NP1I      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "A LITTLE BIT" 2 "MODERATELY"
                       3 "QUITE A BIT" 4 "EXTREMELY" ;
label define NP1J      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "A LITTLE BIT" 2 "MODERATELY"
                       3 "QUITE A BIT" 4 "EXTREMELY" ;
label define NP1K      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "A LITTLE BIT" 2 "MODERATELY"
                       3 "QUITE A BIT" 4 "EXTREMELY" ;
label define NP1L      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "A LITTLE BIT" 2 "MODERATELY"
                       3 "QUITE A BIT" 4 "EXTREMELY" ;
label define NP1M      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "A LITTLE BIT" 2 "MODERATELY"
                       3 "QUITE A BIT" 4 "EXTREMELY" ;
label define NP1N      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "A LITTLE BIT" 2 "MODERATELY"
                       3 "QUITE A BIT" 4 "EXTREMELY" ;
label define NP2A      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "TEENS LIKES WAY LEADING LIFE"
                       2 "TEENS DON'T LIKE WAY LEADING LIFE" ;
label define NP3A      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "SORT OF TRUE" 2 "REALLY TRUE" ;
label define NP2B      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "TEENS ENJOYABLE TO BE WITH"
                       2 "TEENS NOT SURE ENJOYABLE TO BE WITH" ;
label define NP3B      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "SORT OF TRUE" 2 "REALLY TRUE" ;
label define NP2C      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "TEENS HAPPY TO BE WAY THEY ARE"
                       2 "OTHER TEENS WOULD BE DIFFERENT" ;
label define NP3C      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "SORT OF TRUE" 2 "REALLY TRUE" ;
label define NP2D      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "UNCOMFORTABLE MEETING NEW PEOPLE"
                       2 "LIKE TO MEET NEW PEOPLE" ;
label define NP3D      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "SORT OF TRUE" 2 "REALLY TRUE" ;
label define NP2E      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "TEENS QUESTION WHETHER WORTHWHILE"
                       2 "TEENS FEEL THEY ARE WORTHWHILE" ;
label define NP3E      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "SORT OF TRUE" 2 "REALLY TRUE" ;
label define NP2F      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "TEENS DISAPPOINTED WITH SELF"
                       2 "TEENS PLEASED WITH SELF" ;
label define NP3F      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "SORT OF TRUE" 2 "REALLY TRUE" ;
label define NP2G      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "TEENS FEEL AT EASE WITH OTHER"
                       2 "OTHER TEENS ARE QUITE SHY" ;
label define NP3G      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "SORT OF TRUE" 2 "REALLY TRUE" ;
label define NP2H      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "TEENS DISSATISFIED WITH SELF"
                       2 "TEENS SATISFIED WITH SELF" ;
label define NP3H      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "SORT OF TRUE" 2 "REALLY TRUE" ;
label define NP2I      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "SOME TEENS ARE NOT SOCIABLE"
                       2 "OTHER TEENS ARE SOCIABLE" ;
label define NP3I      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "SORT OF TRUE" 2 "REALLY TRUE" ;
label define NP2J      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "SOME TEENS LIKE THEMSELVES"
                       2 "OTHER TEENS WOULD BE SOMEONE ELSE" ;
label define NP3J      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "SORT OF TRUE" 2 "REALLY TRUE" ;
label define QU1       0 "NO" 1 "YES" ;
label define IA1       0 "NO" 1 "YES" ;
label define SU1       0 "NO" 1 "YES" ;
label define MODALITY  1 "RESIDENTIAL" 2 "SHORT-TERM INPATIENT"
                       3 "METHADONE MAINTENANCE" 4 "OUTPATIENT DRUG FREE" ;
label define SEX       1 "MALE" 2 "FEMALE" ;
label define AGE       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       12 "12 OR YOUNGER" 18 "18 OR OLDER" ;
label define HLTHINS   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "PRIVATE /OTHER" 2 "PUBLIC" 3 "UNKNOWN TYPE" ;
label define FTWORK    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "1-13 WKS" 2 "14-39 WKS" 3 "40-52 WKS" ;
label define MSTAT     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "MARRIED" 2 "SEPARATED" 3 "DIVORCED OR WIDOWED"
                       5 "LIVING AS MARRIED" 6 "NEVER MARRIED" ;
label define INSCHOOL  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NO"
                       1 "YES" ;
label define RACE      1 "CAUCASIAN/WHITE" 2 "AFRO-AMERICAN/BLACK"
                       3 "HISPANIC" 4 "OTHER" ;
label define EDLEV     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "GRADE SCHOOL" 2 "MIDDLE SCHOOL" 3 "GRADE 9"
                       4 "GRADE 10" 5 "GRADE 11" 6 "GRADE 12"
                       7 "HS GRADUATE/GED" ;
label define RACESEX   1 "CAUCASIAN/WHITE MALE" 2 "AFRO-AMERICAN/BLACK MALE"
                       3 "HISPANIC MALE" 4 "OTHER MALE"
                       5 "CAUCASIAN/WHITE FEMALE"
                       6 "AFRO-AMERICAN/BLACK FEMALE" 7 "HISPANIC FEMALE"
                       8 "OTHER FEMALE" ;
label define HVY_ALC   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT A HEAVY USER" 1 "HEAVY ALCOHOL USER" ;
label define ALCR      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NO USE"
                       1 "MONTHLY" 2 "WEEKLY" 3 "DAILY" ;
label define MRJR      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NO USE"
                       1 "MONTHLY" 2 "WEEKLY" 3 "DAILY" ;
label define COCR      0 "NO USE" 1 "MONTHLY" 2 "WEEKLY" 3 "DAILY" ;
label define HERR      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NO USE"
                       1 "MONTHLY" 2 "WEEKLY" 3 "DAILY" ;
label define NARR      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NO USE"
                       1 "MONTHLY" 2 "WEEKLY" 3 "DAILY" ;
label define SEDR      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NO USE"
                       1 "MONTHLY" 2 "WEEKLY" 3 "DAILY" ;
label define AMPR      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NO USE"
                       1 "MONTHLY" 2 "WEEKLY" 3 "DAILY" ;
label define HALR      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NO USE"
                       1 "MONTHLY" 2 "WEEKLY" 3 "DAILY" ;
label define INHR      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NO USE"
                       1 "MONTHLY" 2 "WEEKLY" 3 "DAILY" ;
label define ALCWK     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "LESS THAN WEEKLY USE" 1 "WEEKLY OR MORE USE" ;
label define MRJWK     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "LESS THAN WEEKLY USE" 1 "WEEKLY OR MORE USE" ;
label define COCWK     0 "LESS THAN WEEKLY USE" 1 "WEEKLY OR MORE USE" ;
label define HERWK     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "LESS THAN WEEKLY USE" 1 "WEEKLY OR MORE USE" ;
label define NARWK     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "LESS THAN WEEKLY USE" 1 "WEEKLY OR MORE USE" ;
label define SEDWK     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "LESS THAN WEEKLY USE" 1 "WEEKLY OR MORE USE" ;
label define AMPWK     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "LESS THAN WEEKLY USE" 1 "WEEKLY OR MORE USE" ;
label define HALWK     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "LESS THAN WEEKLY USE" 1 "WEEKLY OR MORE USE" ;
label define INHWK     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "LESS THAN WEEKLY USE" 1 "WEEKLY OR MORE USE" ;
label define MRJ_EV    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NO USE"
                       1 "1 - 5 TIMES" 2 "MORE THAN 5 TIMES" ;
label define COC_EV    0 "NO USE" 1 "1 - 5 TIMES" 2 "MORE THAN 5 TIMES" ;
label define HER_EV    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NO USE"
                       1 "1 - 5 TIMES" 2 "MORE THAN 5 TIMES" ;
label define NAR_EV    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NO USE"
                       1 "1 - 5 TIMES" 2 "MORE THAN 5 TIMES" ;
label define SED_EV    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NO USE"
                       1 "1 - 5 TIMES" 2 "MORE THAN 5 TIMES" ;
label define AMP_EV    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NO USE"
                       1 "1 - 5 TIMES" 2 "MORE THAN 5 TIMES" ;
label define HAL_EV    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NO USE"
                       1 "1 - 5 TIMES" 2 "MORE THAN 5 TIMES" ;
label define INH_EV    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NO USE"
                       1 "1 - 5 TIMES" 2 "MORE THAN 5 TIMES" ;
label define CJ_STAT   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NO LEGAL STATUS" 1 "IN JAIL/DETENTION"
                       2 "PROBATION" 3 "PAROLE" 4 "CASE PENDING" ;
label define IAY_SIA   -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "1-2 ACTS" 2 "3-10 ACTS" 3 "10 OR MORE ACTS" ;
label define MAJSRC    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NO INCOME" 1 "LEGAL WORK" 2 "PUB ASSISTANCE"
                       3 "SOCIAL SECURITY" 4 "FAMILY, FRIENDS"
                       5 "ILLEGAL SOURCES" 6 "OTHER SOURCES" ;
label define REFER     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "SELF (ONLY IF NO OTHER PRIMARY OR SECONDARY MENTIONED)"
                       1 "MEDICAL SERVICE" 2 "COMMUNITY AGENCY"
                       3 "LEGAL SYSTEM" 4 "FAMILY OR FRIENDS"
                       5 "SCHOOL OR EMPLOYER" 6 "OTHER" ;
label define RESTRICT  -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NO WEEKS RESTRICTED" 1 "1 TO 4 WEEKS RESTRICTED"
                       2 "5 TO 13 WEEKS RESTRICTED"
                       3 "14 TO 26 WEEKS RESTRICTED"
                       4 "27 TO 39 WEEKS RESTRICTED"
                       5 "40 TO 50 WEEKS RESTRICTED"
                       6 "51 TO 52 WEEKS RESTRICTED" ;
label define DRUGTX    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "4 OR MORE" ;
label define SCHOOL    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT IN SCHOOL" 1 "SPECIAL EDUCATION"
                       2 "MIDDLE SCHOOL" 3 "HIGH SCHOOL" 4 "POST-SECONDARY"
                       5 "OTHER" ;
label define DEP_YR    0 "NO SIGNS OF DEPRESSION" 1 "FELT DEPRESSED"
                       2 "SUICIDAL THOUGHTS" 3 "SUICIDAL ATTEMPT (S)" ;
label define EMPSTAT   1 "WORKING" 2 "LOOKING FOR WORK/GOING TO SCHOOL"
                       3 "KEEPING HOUSE" 4 "DISABLED/RETIRED"
                       5 "IN JAIL, RESIDENTIAL TX, OTHER INST"
                       6 "DRUG RELATED OR ILLEGAL ACTIVITIES"
                       7 "OTHER, MULTIPLE" ;
label define IAPY      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "MONTHLY" 2 "WEEKLY" 3 "DAILY" ;
label define PDT       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "1-2" 2 "3 OR MORE" ;
label define CRKR      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NO USE"
                       1 "MONTHLY" 2 "WEEKLY" 3 "DAILY" ;
label define CRKWK     -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "LESS THAN WEEKLY USE" 1 "WEEKLY OR MORE USE" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace CASEID = . if (CASEID <= -1 )
replace EDC_M = . if (EDC_M <= -1 )
replace EDC_Y = . if (EDC_Y <= -1 )
replace ET_L_I = . if (ET_L_I <= -1 )
replace ETIME1_H = . if (ETIME1_H <= -1 )
replace ETIME1_M = . if (ETIME1_M <= -1 )
replace EAM_PM_1 = . if (EAM_PM_1 <= -1 )
replace EA3 = . if (EA3 <= -1 )
replace EA3_A = . if (EA3_A <= -1 )
replace EA3_B = . if (EA3_B <= -1 )
replace EA4 = . if (EA4 <= -1 )
replace EA5 = . if (EA5 <= -1 )
replace EA6 = . if (EA6 <= -1 )
replace EA7 = . if (EA7 <= -1 )
replace EA8 = . if (EA8 <= -1 )
replace EA8_A = . if (EA8_A <= -1 )
replace EA8_B = . if (EA8_B <= -1 )
replace EA8_C = . if (EA8_C <= -1 )
replace EA8_D = . if (EA8_D <= -1 )
replace EA8_E = . if (EA8_E <= -1 )
replace EA9 = . if (EA9 <= -1 )
replace EA10 = . if (EA10 <= -1 )
replace EA11 = . if (EA11 <= -1 )
replace EA12 = . if (EA12 <= -1 )
replace EA13 = . if (EA13 <= -1 )
replace EA13A_02 = . if (EA13A_02 <= -1 )
replace EA13A_03 = . if (EA13A_03 <= -1 )
replace EA13A_04 = . if (EA13A_04 <= -1 )
replace EA13A_05 = . if (EA13A_05 <= -1 )
replace EA13A_06 = . if (EA13A_06 <= -1 )
replace EA14 = . if (EA14 <= -1 )
replace EA14A_02 = . if (EA14A_02 <= -1 )
replace EA14A_03 = . if (EA14A_03 <= -1 )
replace EA14A_04 = . if (EA14A_04 <= -1 )
replace EA14A_05 = . if (EA14A_05 <= -1 )
replace EA14A_06 = . if (EA14A_06 <= -1 )
replace EA15_00 = . if (EA15_00 <= -1 )
replace EA15_01 = . if (EA15_01 <= -1 )
replace EA15_02 = . if (EA15_02 <= -1 )
replace EA15_03 = . if (EA15_03 <= -1 )
replace EA16 = . if (EA16 <= -1 )
replace EA17 = . if (EA17 <= -1 )
replace EA18 = . if (EA18 <= -1 )
replace EA19 = . if (EA19 <= -1 )
replace EA19_A = . if (EA19_A <= -1 )
replace EA19_B = . if (EA19_B <= -1 )
replace EA20 = . if (EA20 <= -1 )
replace EA21 = . if (EA21 <= -1 )
replace EA22 = . if (EA22 <= -1 )
replace EA23_A = . if (EA23_A <= -1 )
replace EA23_B = . if (EA23_B <= -1 )
replace EA23_C = . if (EA23_C <= -1 )
replace EA24_A = . if (EA24_A <= -1 )
replace EA24_B = . if (EA24_B <= -1 )
replace EA24_C = . if (EA24_C <= -1 )
replace EA24_D = . if (EA24_D <= -1 )
replace EA24_E = . if (EA24_E <= -1 )
replace EA24_F = . if (EA24_F <= -1 )
replace EA25 = . if (EA25 <= -1 )
replace EA26 = . if (EA26 <= -1 )
replace EA27 = . if (EA27 <= -1 )
replace EA27A = . if (EA27A <= -1 )
replace EB1 = . if (EB1 <= -1 )
replace EB1_A = . if (EB1_A <= -1 )
replace EB1_B = . if (EB1_B <= -1 )
replace EB1_C = . if (EB1_C <= -1 )
replace EB1_D = . if (EB1_D <= -1 )
replace EB1_E = . if (EB1_E <= -1 )
replace EB1_F = . if (EB1_F <= -1 )
replace EB1_G = . if (EB1_G <= -1 )
replace EB2 = . if (EB2 <= -1 )
replace EB2_A = . if (EB2_A <= -1 )
replace EB3_0 = . if (EB3_0 <= -1 )
replace EB3_1 = . if (EB3_1 <= -1 )
replace EB3_2 = . if (EB3_2 <= -1 )
replace EB3_3 = . if (EB3_3 <= -1 )
replace EB3_4 = . if (EB3_4 <= -1 )
replace EB3_5 = . if (EB3_5 <= -1 )
replace EB3_6 = . if (EB3_6 <= -1 )
replace EB4 = . if (EB4 <= -1 )
replace EB4_A = . if (EB4_A <= -1 )
replace EB5 = . if (EB5 <= -1 )
replace EC1 = . if (EC1 <= -1 )
replace EC1_A_02 = . if (EC1_A_02 <= -1 )
replace EC1_A_03 = . if (EC1_A_03 <= -1 )
replace EC1_A_04 = . if (EC1_A_04 <= -1 )
replace EC1_A_05 = . if (EC1_A_05 <= -1 )
replace EC1_A_06 = . if (EC1_A_06 <= -1 )
replace EC1_A_07 = . if (EC1_A_07 <= -1 )
replace EC1_B = . if (EC1_B <= -1 )
replace EC1_C = . if (EC1_C <= -1 )
replace EC1_D = . if (EC1_D <= -1 )
replace EC1_E = . if (EC1_E <= -1 )
replace EC2 = . if (EC2 <= -1 )
replace EC3 = . if (EC3 <= -1 )
replace EC3_A = . if (EC3_A <= -1 )
replace EC3_B = . if (EC3_B <= -1 )
replace EC4_00 = . if (EC4_00 <= -1 )
replace EC4_01 = . if (EC4_01 <= -1 )
replace EC4_02 = . if (EC4_02 <= -1 )
replace EC4_03 = . if (EC4_03 <= -1 )
replace EC4_04 = . if (EC4_04 <= -1 )
replace EC4_05 = . if (EC4_05 <= -1 )
replace EC4_06 = . if (EC4_06 <= -1 )
replace EC4_07 = . if (EC4_07 <= -1 )
replace EC4_08 = . if (EC4_08 <= -1 )
replace EC4_09 = . if (EC4_09 <= -1 )
replace EC5 = . if (EC5 <= -1 )
replace EC5_A = . if (EC5_A <= -1 )
replace EC6 = . if (EC6 <= -1 )
replace EC6_A = . if (EC6_A <= -1 )
replace EC7 = . if (EC7 <= -1 )
replace EC7_A = . if (EC7_A <= -1 )
replace EC7_B_1 = . if (EC7_B_1 <= -1 )
replace EC7_B_2 = . if (EC7_B_2 <= -1 )
replace ED1 = . if (ED1 <= -1 )
replace ED1_A = . if (ED1_A <= -1 )
replace ED2 = . if (ED2 <= -1 )
replace ED2_A = . if (ED2_A <= -1 )
replace ED2_B = . if (ED2_B <= -1 )
replace ED2_C_1 = . if (ED2_C_1 <= -1 )
replace ED2_C_2 = . if (ED2_C_2 <= -1 )
replace ED2_D = . if (ED2_D <= -1 )
replace ED3 = . if (ED3 <= -1 )
replace ED3_A = . if (ED3_A <= -1 )
replace ED4 = . if (ED4 <= -1 )
replace ED4_A = . if (ED4_A <= -1 )
replace ED5 = . if (ED5 <= -1 )
replace ED5_A_1 = . if (ED5_A_1 <= -1 )
replace ED5_A_2 = . if (ED5_A_2 <= -1 )
replace ED5_B = . if (ED5_B <= -1 )
replace ED6 = . if (ED6 <= -1 )
replace ED6_A_1 = . if (ED6_A_1 <= -1 )
replace ED6_A_2 = . if (ED6_A_2 <= -1 )
replace ED6_B = . if (ED6_B <= -1 )
replace ED7 = . if (ED7 <= -1 )
replace ED7_A_1 = . if (ED7_A_1 <= -1 )
replace ED7_A_2 = . if (ED7_A_2 <= -1 )
replace ED7_B = . if (ED7_B <= -1 )
replace ED8 = . if (ED8 <= -1 )
replace ED8_A = . if (ED8_A <= -1 )
replace ED9 = . if (ED9 <= -1 )
replace ED10 = . if (ED10 <= -1 )
replace ED10_A = . if (ED10_A <= -1 )
replace ED11 = . if (ED11 <= -1 )
replace ED11_A = . if (ED11_A <= -1 )
replace ED12 = . if (ED12 <= -1 )
replace ED13 = . if (ED13 <= -1 )
replace ED14 = . if (ED14 <= -1 )
replace ED15 = . if (ED15 <= -1 )
replace ED16 = . if (ED16 <= -1 )
replace ED17 = . if (ED17 <= -1 )
replace ED18 = . if (ED18 <= -1 )
replace ED19 = . if (ED19 <= -1 )
replace EE1 = . if (EE1 <= -1 )
replace EE2 = . if (EE2 <= -1 )
replace EE3 = . if (EE3 <= -1 )
replace EE4 = . if (EE4 <= -1 )
replace EE5 = . if (EE5 <= -1 )
replace EE6 = . if (EE6 <= -1 )
replace EE7 = . if (EE7 <= -1 )
replace EE8 = . if (EE8 <= -1 )
replace EE9 = . if (EE9 <= -1 )
replace EE10 = . if (EE10 <= -1 )
replace EE11 = . if (EE11 <= -1 )
replace EE12 = . if (EE12 <= -1 )
replace EE12_A = . if (EE12_A <= -1 )
replace EE13 = . if (EE13 <= -1 )
replace EE13_A_1 = . if (EE13_A_1 <= -1 )
replace EE13_A_2 = . if (EE13_A_2 <= -1 )
replace EE13_A_3 = . if (EE13_A_3 <= -1 )
replace EE14_A_1 = . if (EE14_A_1 <= -1 )
replace EE14_A_2 = . if (EE14_A_2 <= -1 )
replace EE14_B_1 = . if (EE14_B_1 <= -1 )
replace EE14_B_2 = . if (EE14_B_2 <= -1 )
replace EE14_C = . if (EE14_C <= -1 )
replace EE15_A_1 = . if (EE15_A_1 <= -1 )
replace EE15_A_2 = . if (EE15_A_2 <= -1 )
replace EE15_B_1 = . if (EE15_B_1 <= -1 )
replace EE15_B_2 = . if (EE15_B_2 <= -1 )
replace EE15_C = . if (EE15_C <= -1 )
replace EE15_D = . if (EE15_D <= -1 )
replace EE15_E = . if (EE15_E <= -1 )
replace EE16 = . if (EE16 <= -1 )
replace EE16_A_1 = . if (EE16_A_1 <= -1 )
replace EE16_A_2 = . if (EE16_A_2 <= -1 )
replace EE16_B_1 = . if (EE16_B_1 <= -1 )
replace EE16_B_2 = . if (EE16_B_2 <= -1 )
replace EE16_C = . if (EE16_C <= -1 )
replace EE16_D = . if (EE16_D <= -1 )
replace EE16_E = . if (EE16_E <= -1 )
replace EE16_F = . if (EE16_F <= -1 )
replace EE17 = . if (EE17 <= -1 )
replace EE17_A = . if (EE17_A <= -1 )
replace EE17_B_1 = . if (EE17_B_1 <= -1 )
replace EE17_B_2 = . if (EE17_B_2 <= -1 )
replace EE17_B_3 = . if (EE17_B_3 <= -1 )
replace EE17_C = . if (EE17_C <= -1 )
replace EE18_A_1 = . if (EE18_A_1 <= -1 )
replace EE18_A_2 = . if (EE18_A_2 <= -1 )
replace EE18_B_1 = . if (EE18_B_1 <= -1 )
replace EE18_B_2 = . if (EE18_B_2 <= -1 )
replace EE18_C = . if (EE18_C <= -1 )
replace EE18_D = . if (EE18_D <= -1 )
replace EE18_E = . if (EE18_E <= -1 )
replace EE19 = . if (EE19 <= -1 )
replace EE19_A = . if (EE19_A <= -1 )
replace EE19B1_1 = . if (EE19B1_1 <= -1 )
replace EE19B1_2 = . if (EE19B1_2 <= -1 )
replace EE19B2_1 = . if (EE19B2_1 <= -1 )
replace EE19B2_2 = . if (EE19B2_2 <= -1 )
replace EE19_C = . if (EE19_C <= -1 )
replace EE20 = . if (EE20 <= -1 )
replace EE20_A_1 = . if (EE20_A_1 <= -1 )
replace EE20_A_2 = . if (EE20_A_2 <= -1 )
replace EE20_B_1 = . if (EE20_B_1 <= -1 )
replace EE20_B_2 = . if (EE20_B_2 <= -1 )
replace EE20_C = . if (EE20_C <= -1 )
replace EE20_D = . if (EE20_D <= -1 )
replace EE20_E_1 = . if (EE20_E_1 <= -1 )
replace EE20_E_2 = . if (EE20_E_2 <= -1 )
replace EE20_E_3 = . if (EE20_E_3 <= -1 )
replace EE20_E_4 = . if (EE20_E_4 <= -1 )
replace EE20_F = . if (EE20_F <= -1 )
replace EE21 = . if (EE21 <= -1 )
replace EE21_A = . if (EE21_A <= -1 )
replace EE21_B_1 = . if (EE21_B_1 <= -1 )
replace EE21_B_2 = . if (EE21_B_2 <= -1 )
replace EE21_B_3 = . if (EE21_B_3 <= -1 )
replace EE21_C = . if (EE21_C <= -1 )
replace EE22 = . if (EE22 <= -1 )
replace EE22_A_1 = . if (EE22_A_1 <= -1 )
replace EE22_A_2 = . if (EE22_A_2 <= -1 )
replace EE22_B_1 = . if (EE22_B_1 <= -1 )
replace EE22_B_2 = . if (EE22_B_2 <= -1 )
replace EE22_C = . if (EE22_C <= -1 )
replace EE22_D = . if (EE22_D <= -1 )
replace EE22_E = . if (EE22_E <= -1 )
replace EE23 = . if (EE23 <= -1 )
replace EE23_A = . if (EE23_A <= -1 )
replace EE24_A_1 = . if (EE24_A_1 <= -1 )
replace EE24_A_2 = . if (EE24_A_2 <= -1 )
replace EE24_B_1 = . if (EE24_B_1 <= -1 )
replace EE24_B_2 = . if (EE24_B_2 <= -1 )
replace EE24_C = . if (EE24_C <= -1 )
replace EE24_D = . if (EE24_D <= -1 )
replace EE24_E = . if (EE24_E <= -1 )
replace EE25 = . if (EE25 <= -1 )
replace EE25_A_1 = . if (EE25_A_1 <= -1 )
replace EE25_A_2 = . if (EE25_A_2 <= -1 )
replace EE25_B_1 = . if (EE25_B_1 <= -1 )
replace EE25_B_2 = . if (EE25_B_2 <= -1 )
replace EE25_C = . if (EE25_C <= -1 )
replace EE26 = . if (EE26 <= -1 )
replace EE26_A_1 = . if (EE26_A_1 <= -1 )
replace EE26_A_2 = . if (EE26_A_2 <= -1 )
replace EE26_B_1 = . if (EE26_B_1 <= -1 )
replace EE26_B_2 = . if (EE26_B_2 <= -1 )
replace EE26_C = . if (EE26_C <= -1 )
replace EE26_D = . if (EE26_D <= -1 )
replace EE27 = . if (EE27 <= -1 )
replace EE27_A = . if (EE27_A <= -1 )
replace EE27_B_1 = . if (EE27_B_1 <= -1 )
replace EE27_B_2 = . if (EE27_B_2 <= -1 )
replace EE27_C_1 = . if (EE27_C_1 <= -1 )
replace EE27_C_2 = . if (EE27_C_2 <= -1 )
replace EE27_D = . if (EE27_D <= -1 )
replace EE27_E = . if (EE27_E <= -1 )
replace EE28 = . if (EE28 <= -1 )
replace EE28_A = . if (EE28_A <= -1 )
replace EE28_B_1 = . if (EE28_B_1 <= -1 )
replace EE28_B_2 = . if (EE28_B_2 <= -1 )
replace EE28_C_1 = . if (EE28_C_1 <= -1 )
replace EE28_C_2 = . if (EE28_C_2 <= -1 )
replace EE28_D = . if (EE28_D <= -1 )
replace EE28_E = . if (EE28_E <= -1 )
replace EE29 = . if (EE29 <= -1 )
replace EE30 = . if (EE30 <= -1 )
replace EE30_A = . if (EE30_A <= -1 )
replace EE31 = . if (EE31 <= -1 )
replace EE31A_1 = . if (EE31A_1 <= -1 )
replace EE31A_2 = . if (EE31A_2 <= -1 )
replace EE31A_3 = . if (EE31A_3 <= -1 )
replace EE31A_4 = . if (EE31A_4 <= -1 )
replace EE31A_5 = . if (EE31A_5 <= -1 )
replace EE31A_6 = . if (EE31A_6 <= -1 )
replace EE32 = . if (EE32 <= -1 )
replace EE33_A = . if (EE33_A <= -1 )
replace EE33_B = . if (EE33_B <= -1 )
replace EE33_C = . if (EE33_C <= -1 )
replace EE33_D = . if (EE33_D <= -1 )
replace EE33_E = . if (EE33_E <= -1 )
replace EE33_F = . if (EE33_F <= -1 )
replace EE34 = . if (EE34 <= -1 )
replace EE35 = . if (EE35 <= -1 )
replace EE36 = . if (EE36 <= -1 )
replace EE37 = . if (EE37 <= -1 )
replace EE38 = . if (EE38 <= -1 )
replace EE39_A = . if (EE39_A <= -1 )
replace EE39_B = . if (EE39_B <= -1 )
replace EE39_C = . if (EE39_C <= -1 )
replace EE39_D = . if (EE39_D <= -1 )
replace EE39_E = . if (EE39_E <= -1 )
replace EE39_F = . if (EE39_F <= -1 )
replace EE39_G = . if (EE39_G <= -1 )
replace EE39_H = . if (EE39_H <= -1 )
replace EE39_I = . if (EE39_I <= -1 )
replace EE39_J = . if (EE39_J <= -1 )
replace EE39_K = . if (EE39_K <= -1 )
replace EE39_L = . if (EE39_L <= -1 )
replace EE39_M = . if (EE39_M <= -1 )
replace EE39_N = . if (EE39_N <= -1 )
replace EE39_O = . if (EE39_O <= -1 )
replace EE39_P = . if (EE39_P <= -1 )
replace EE39_Q = . if (EE39_Q <= -1 )
replace EE39_R = . if (EE39_R <= -1 )
replace EE39_S = . if (EE39_S <= -1 )
replace EE39_T = . if (EE39_T <= -1 )
replace EE40 = . if (EE40 <= -1 )
replace EE40_B_1 = . if (EE40_B_1 <= -1 )
replace EE40_B_2 = . if (EE40_B_2 <= -1 )
replace EE40_B_3 = . if (EE40_B_3 <= -1 )
replace EE41_A = . if (EE41_A <= -1 )
replace EE41_B = . if (EE41_B <= -1 )
replace EE42 = . if (EE42 <= -1 )
replace EE43 = . if (EE43 <= -1 )
replace EE44 = . if (EE44 <= -1 )
replace EE45 = . if (EE45 <= -1 )
replace EE46 = . if (EE46 <= -1 )
replace EE47 = . if (EE47 <= -1 )
replace EE48_A = . if (EE48_A <= -1 )
replace EE48_B = . if (EE48_B <= -1 )
replace EE48_C = . if (EE48_C <= -1 )
replace EE48_D = . if (EE48_D <= -1 )
replace EE48_E = . if (EE48_E <= -1 )
replace EE48_F = . if (EE48_F <= -1 )
replace EE48_G = . if (EE48_G <= -1 )
replace EE48_H = . if (EE48_H <= -1 )
replace EE48_I = . if (EE48_I <= -1 )
replace EE48_J = . if (EE48_J <= -1 )
replace EE48_K = . if (EE48_K <= -1 )
replace EE48_L = . if (EE48_L <= -1 )
replace EF1 = . if (EF1 <= -1 )
replace EF1_A = . if (EF1_A <= -1 )
replace EF2 = . if (EF2 <= -1 )
replace EF2_A = . if (EF2_A <= -1 )
replace EF3 = . if (EF3 <= -1 )
replace EF4 = . if (EF4 <= -1 )
replace EF5 = . if (EF5 <= -1 )
replace EF5_A = . if (EF5_A <= -1 )
replace EF6 = . if (EF6 <= -1 )
replace EF7 = . if (EF7 <= -1 )
replace EF8 = . if (EF8 <= -1 )
replace EF9 = . if (EF9 <= -1 )
replace EF9_A = . if (EF9_A <= -1 )
replace EF10 = . if (EF10 <= -1 )
replace EF10_A = . if (EF10_A <= -1 )
replace EF11 = . if (EF11 <= -1 )
replace EF11_A = . if (EF11_A <= -1 )
replace EF12 = . if (EF12 <= -1 )
replace EF13 = . if (EF13 <= -1 )
replace EF14 = . if (EF14 <= -1 )
replace EF15 = . if (EF15 <= -1 )
replace EF16 = . if (EF16 <= -1 )
replace EF16_A = . if (EF16_A <= -1 )
replace EF17 = . if (EF17 <= -1 )
replace EF17_A_1 = . if (EF17_A_1 <= -1 )
replace EF17_A_2 = . if (EF17_A_2 <= -1 )
replace EF17_A_3 = . if (EF17_A_3 <= -1 )
replace EF17_A_4 = . if (EF17_A_4 <= -1 )
replace EF17_B = . if (EF17_B <= -1 )
replace EF17_C = . if (EF17_C <= -1 )
replace EF17D_01 = . if (EF17D_01 <= -1 )
replace EF17D_02 = . if (EF17D_02 <= -1 )
replace EF17D_14 = . if (EF17D_14 <= -1 )
replace EF17D_23 = . if (EF17D_23 <= -1 )
replace EF17D_24 = . if (EF17D_24 <= -1 )
replace EF17D_25 = . if (EF17D_25 <= -1 )
replace EF17D_61 = . if (EF17D_61 <= -1 )
replace EF17D_62 = . if (EF17D_62 <= -1 )
replace EF17D_91 = . if (EF17D_91 <= -1 )
replace EF17_E = . if (EF17_E <= -1 )
replace EF18 = . if (EF18 <= -1 )
replace EG1 = . if (EG1 <= -1 )
replace EG2 = . if (EG2 <= -1 )
replace EG3 = . if (EG3 <= -1 )
replace EG4 = . if (EG4 <= -1 )
replace EG4_A = . if (EG4_A <= -1 )
replace EG4_B_1 = . if (EG4_B_1 <= -1 )
replace EG4_B_2 = . if (EG4_B_2 <= -1 )
replace EG4_B_3 = . if (EG4_B_3 <= -1 )
replace EG4_B_4 = . if (EG4_B_4 <= -1 )
replace EG4_C = . if (EG4_C <= -1 )
replace EG4_D = . if (EG4_D <= -1 )
replace EG4_E = . if (EG4_E <= -1 )
replace EG4F_1 = . if (EG4F_1 <= -1 )
replace EG4F_2 = . if (EG4F_2 <= -1 )
replace EG4F_3 = . if (EG4F_3 <= -1 )
replace EG4F_4 = . if (EG4F_4 <= -1 )
replace EG4F_5 = . if (EG4F_5 <= -1 )
replace EG4F_6 = . if (EG4F_6 <= -1 )
replace EG4G = . if (EG4G <= -1 )
replace EG5_A = . if (EG5_A <= -1 )
replace EG5_B = . if (EG5_B <= -1 )
replace EG5_C = . if (EG5_C <= -1 )
replace EG5_D = . if (EG5_D <= -1 )
replace EG5_E = . if (EG5_E <= -1 )
replace EG5_F = . if (EG5_F <= -1 )
replace EG7 = . if (EG7 <= -1 )
replace EG7_A = . if (EG7_A <= -1 )
replace EG8 = . if (EG8 <= -1 )
replace EG9 = . if (EG9 <= -1 )
replace EG10 = . if (EG10 <= -1 )
replace EG11 = . if (EG11 <= -1 )
replace EG12 = . if (EG12 <= -1 )
replace EG12A_1 = . if (EG12A_1 <= -1 )
replace EG12A_2 = . if (EG12A_2 <= -1 )
replace EG12A_3 = . if (EG12A_3 <= -1 )
replace EG12A_4 = . if (EG12A_4 <= -1 )
replace EG12B_1 = . if (EG12B_1 <= -1 )
replace EG12B_2 = . if (EG12B_2 <= -1 )
replace EG12B_3 = . if (EG12B_3 <= -1 )
replace EG13 = . if (EG13 <= -1 )
replace EG14 = . if (EG14 <= -1 )
replace EG15 = . if (EG15 <= -1 )
replace EG15_A = . if (EG15_A <= -1 )
replace EH1 = . if (EH1 <= -1 )
replace EH1_A = . if (EH1_A <= -1 )
replace EH2_A = . if (EH2_A <= -1 )
replace EH3_A = . if (EH3_A <= -1 )
replace EH2_B = . if (EH2_B <= -1 )
replace EH3_B = . if (EH3_B <= -1 )
replace EH2_C = . if (EH2_C <= -1 )
replace EH3_C = . if (EH3_C <= -1 )
replace EH2_D = . if (EH2_D <= -1 )
replace EH3_D = . if (EH3_D <= -1 )
replace EH2_E = . if (EH2_E <= -1 )
replace EH3_E = . if (EH3_E <= -1 )
replace EH2_F = . if (EH2_F <= -1 )
replace EH3_F = . if (EH3_F <= -1 )
replace EH2_G = . if (EH2_G <= -1 )
replace EH3_G = . if (EH3_G <= -1 )
replace EH2_H = . if (EH2_H <= -1 )
replace EH3_H = . if (EH3_H <= -1 )
replace EH2_I = . if (EH2_I <= -1 )
replace EH3_I = . if (EH3_I <= -1 )
replace EH2_J = . if (EH2_J <= -1 )
replace EH3_J = . if (EH3_J <= -1 )
replace EH2_K = . if (EH2_K <= -1 )
replace EH3_K = . if (EH3_K <= -1 )
replace EH2_L = . if (EH2_L <= -1 )
replace EH3_L = . if (EH3_L <= -1 )
replace EH4 = . if (EH4 <= -1 )
replace EH5 = . if (EH5 <= -1 )
replace EH6 = . if (EH6 <= -1 )
replace EH6_A = . if (EH6_A <= -1 )
replace EH7 = . if (EH7 <= -1 )
replace EH8 = . if (EH8 <= -1 )
replace EH8_A = . if (EH8_A <= -1 )
replace EH9 = . if (EH9 <= -1 )
replace EJ1 = . if (EJ1 <= -1 )
replace EJ2 = . if (EJ2 <= -1 )
replace EJ2_A = . if (EJ2_A <= -1 )
replace EJ2_B = . if (EJ2_B <= -1 )
replace EJ2_C = . if (EJ2_C <= -1 )
replace EJ2_D = . if (EJ2_D <= -1 )
replace EJ2_E = . if (EJ2_E <= -1 )
replace EJ2_F = . if (EJ2_F <= -1 )
replace EJ2_G = . if (EJ2_G <= -1 )
replace EJ3 = . if (EJ3 <= -1 )
replace EJ3_A_1 = . if (EJ3_A_1 <= -1 )
replace EJ3_A_2 = . if (EJ3_A_2 <= -1 )
replace EJ3_A_3 = . if (EJ3_A_3 <= -1 )
replace EJ3_A_4 = . if (EJ3_A_4 <= -1 )
replace EJ3_A_5 = . if (EJ3_A_5 <= -1 )
replace EJ3_A_6 = . if (EJ3_A_6 <= -1 )
replace EJ3_A_7 = . if (EJ3_A_7 <= -1 )
replace EJ3_B = . if (EJ3_B <= -1 )
replace EJ3_C_1 = . if (EJ3_C_1 <= -1 )
replace EJ3_C_2 = . if (EJ3_C_2 <= -1 )
replace EJ3_C_3 = . if (EJ3_C_3 <= -1 )
replace EJ3_C_4 = . if (EJ3_C_4 <= -1 )
replace EJ3_C_5 = . if (EJ3_C_5 <= -1 )
replace EJ3_C_6 = . if (EJ3_C_6 <= -1 )
replace EJ3_C_7 = . if (EJ3_C_7 <= -1 )
replace EJ3_C_8 = . if (EJ3_C_8 <= -1 )
replace EJ3_C_9 = . if (EJ3_C_9 <= -1 )
replace EJ3_C_10 = . if (EJ3_C_10 <= -1 )
replace EJ3_C_11 = . if (EJ3_C_11 <= -1 )
replace EJ4_0 = . if (EJ4_0 <= -1 )
replace EJ4_1 = . if (EJ4_1 <= -1 )
replace EJ4_2 = . if (EJ4_2 <= -1 )
replace EJ4_3 = . if (EJ4_3 <= -1 )
replace EJ4_4 = . if (EJ4_4 <= -1 )
replace EJ4_5 = . if (EJ4_5 <= -1 )
replace EJ4_6 = . if (EJ4_6 <= -1 )
replace EJ4_7 = . if (EJ4_7 <= -1 )
replace EJ4_8 = . if (EJ4_8 <= -1 )
replace EJ4_9 = . if (EJ4_9 <= -1 )
replace EJ4_10 = . if (EJ4_10 <= -1 )
replace EJ4_11 = . if (EJ4_11 <= -1 )
replace EJ4_12 = . if (EJ4_12 <= -1 )
replace EJ4_13 = . if (EJ4_13 <= -1 )
replace EJ4_14 = . if (EJ4_14 <= -1 )
replace EJ4_15 = . if (EJ4_15 <= -1 )
replace EJ4_16 = . if (EJ4_16 <= -1 )
replace EJ5 = . if (EJ5 <= -1 )
replace EJ6 = . if (EJ6 <= -1 )
replace EJ7 = . if (EJ7 <= -1 )
replace EJ8 = . if (EJ8 <= -1 )
replace EJ9 = . if (EJ9 <= -1 )
replace EJ9_A = . if (EJ9_A <= -1 )
replace EJ9_B = . if (EJ9_B <= -1 )
replace EJ9_C_OC = . if (EJ9_C_OC <= -1 )
replace EJ9_C = . if (EJ9_C <= -1.0000 )
replace EJ9_COD = . if (EJ9_COD <= -1 )
replace EJ10 = . if (EJ10 <= -1 )
replace EJ11 = . if (EJ11 <= -1 )
replace EJ12 = . if (EJ12 <= -1 )
replace EJ12_A = . if (EJ12_A <= -1 )
replace EK1_A = . if (EK1_A <= -1 )
replace EK2_A = . if (EK2_A <= -1 )
replace EK1_B = . if (EK1_B <= -1 )
replace EK2_B = . if (EK2_B <= -1 )
replace EK1_C = . if (EK1_C <= -1 )
replace EK2_C = . if (EK2_C <= -1 )
replace EK1_D = . if (EK1_D <= -1 )
replace EK2_D = . if (EK2_D <= -1 )
replace EK1_E = . if (EK1_E <= -1 )
replace EK2_E = . if (EK2_E <= -1 )
replace EK1_F = . if (EK1_F <= -1 )
replace EK2_F = . if (EK2_F <= -1 )
replace EK3 = . if (EK3 <= -1 )
replace EK4 = . if (EK4 <= -1 )
replace EK5 = . if (EK5 <= -1 )
replace EK6_A = . if (EK6_A <= -1 )
replace EK6_B = . if (EK6_B <= -1 )
replace EK6_C = . if (EK6_C <= -1 )
replace EK6_D = . if (EK6_D <= -1 )
replace EK7 = . if (EK7 <= -1 )
replace EK7_A = . if (EK7_A <= -1 )
replace EK8 = . if (EK8 <= -1 )
replace EK9 = . if (EK9 <= -1 )
replace EL1 = . if (EL1 <= -1 )
replace EL1_A = . if (EL1_A <= -1 )
replace EL2 = . if (EL2 <= -1 )
replace EL2_A = . if (EL2_A <= -1 )
replace EL2_B = . if (EL2_B <= -1 )
replace EL2_C = . if (EL2_C <= -1 )
replace EL2_D = . if (EL2_D <= -1 )
replace EL2_E = . if (EL2_E <= -1 )
replace EL2_F_1 = . if (EL2_F_1 <= -1 )
replace EL2_F_2 = . if (EL2_F_2 <= -1 )
replace EL2_F_3 = . if (EL2_F_3 <= -1 )
replace EL3 = . if (EL3 <= -1 )
replace EL3_A = . if (EL3_A <= -1 )
replace EL4 = . if (EL4 <= -1 )
replace EL5 = . if (EL5 <= -1 )
replace EL5_A_1 = . if (EL5_A_1 <= -1 )
replace EL5_A_2 = . if (EL5_A_2 <= -1 )
replace EL5_A_3 = . if (EL5_A_3 <= -1 )
replace EL5_A_4 = . if (EL5_A_4 <= -1 )
replace EL5_B_1 = . if (EL5_B_1 <= -1 )
replace EL5_B_2 = . if (EL5_B_2 <= -1 )
replace EL5_B_11 = . if (EL5_B_11 <= -1 )
replace EL5_B_12 = . if (EL5_B_12 <= -1 )
replace EL5_B_13 = . if (EL5_B_13 <= -1 )
replace EL5_B_21 = . if (EL5_B_21 <= -1 )
replace EL5_B_22 = . if (EL5_B_22 <= -1 )
replace EL5_B_23 = . if (EL5_B_23 <= -1 )
replace EL5_B_31 = . if (EL5_B_31 <= -1 )
replace EL5_B_71 = . if (EL5_B_71 <= -1 )
replace EL5_B_91 = . if (EL5_B_91 <= -1 )
replace EL5_C = . if (EL5_C <= -1 )
replace EL5_D = . if (EL5_D <= -1 )
replace EL6 = . if (EL6 <= -1 )
replace EL6_A_A = . if (EL6_A_A <= -1 )
replace EL6_A_B = . if (EL6_A_B <= -1 )
replace EL6_A_C = . if (EL6_A_C <= -1 )
replace EL6_A_D = . if (EL6_A_D <= -1 )
replace EL6_A_E = . if (EL6_A_E <= -1 )
replace EL6_A_F = . if (EL6_A_F <= -1 )
replace EL6_A_G = . if (EL6_A_G <= -1 )
replace EL6_A_H = . if (EL6_A_H <= -1 )
replace EL6_A_I = . if (EL6_A_I <= -1 )
replace EL6_A_J = . if (EL6_A_J <= -1 )
replace EL6_B_1 = . if (EL6_B_1 <= -1 )
replace EL6_C_1 = . if (EL6_C_1 <= -1 )
replace EL6_D_1 = . if (EL6_D_1 <= -1 )
replace EL6_E_1 = . if (EL6_E_1 <= -1 )
replace EL6_B_2 = . if (EL6_B_2 <= -1 )
replace EL6_C_2 = . if (EL6_C_2 <= -1 )
replace EL6_D_2 = . if (EL6_D_2 <= -1 )
replace EL6_E_2 = . if (EL6_E_2 <= -1 )
replace EL6_B_3 = . if (EL6_B_3 <= -1 )
replace EL6_C_3 = . if (EL6_C_3 <= -1 )
replace EL6_D_3 = . if (EL6_D_3 <= -1 )
replace EL6_E_3 = . if (EL6_E_3 <= -1 )
replace EL6_B_4 = . if (EL6_B_4 <= -1 )
replace EL6_C_4 = . if (EL6_C_4 <= -1 )
replace EL6_D_4 = . if (EL6_D_4 <= -1 )
replace EL6_E_4 = . if (EL6_E_4 <= -1 )
replace EL7 = . if (EL7 <= -1 )
replace EL7_A_A = . if (EL7_A_A <= -1 )
replace EL7_A_B = . if (EL7_A_B <= -1 )
replace EL7_A_C = . if (EL7_A_C <= -1 )
replace EL7_A_D = . if (EL7_A_D <= -1 )
replace EL7_A_E = . if (EL7_A_E <= -1 )
replace EL7_A_F = . if (EL7_A_F <= -1 )
replace EL7_A_G = . if (EL7_A_G <= -1 )
replace EL7_A_H = . if (EL7_A_H <= -1 )
replace EL7_A_I = . if (EL7_A_I <= -1 )
replace EL7_B_1 = . if (EL7_B_1 <= -1 )
replace EL7_C_1 = . if (EL7_C_1 <= -1 )
replace EL7_D_1 = . if (EL7_D_1 <= -1 )
replace EL7_E_1 = . if (EL7_E_1 <= -1 )
replace EL7_B_2 = . if (EL7_B_2 <= -1 )
replace EL7_C_2 = . if (EL7_C_2 <= -1 )
replace EL7_D_2 = . if (EL7_D_2 <= -1 )
replace EL7_E_2 = . if (EL7_E_2 <= -1 )
replace EL7_B_3 = . if (EL7_B_3 <= -1 )
replace EL7_C_3 = . if (EL7_C_3 <= -1 )
replace EL7_D_3 = . if (EL7_D_3 <= -1 )
replace EL7_E_3 = . if (EL7_E_3 <= -1 )
replace EL7_B_4 = . if (EL7_B_4 <= -1 )
replace EL7_C_4 = . if (EL7_C_4 <= -1 )
replace EL7_D_4 = . if (EL7_D_4 <= -1 )
replace EL7_E_4 = . if (EL7_E_4 <= -1 )
replace EL8_0 = . if (EL8_0 <= -1 )
replace EL8_1 = . if (EL8_1 <= -1 )
replace EL8_2 = . if (EL8_2 <= -1 )
replace EL8_11 = . if (EL8_11 <= -1 )
replace EL8_12 = . if (EL8_12 <= -1 )
replace EL8_13 = . if (EL8_13 <= -1 )
replace EL8_21 = . if (EL8_21 <= -1 )
replace EL8_22 = . if (EL8_22 <= -1 )
replace EL8_71 = . if (EL8_71 <= -1 )
replace EL8_91 = . if (EL8_91 <= -1 )
replace EL8_A_1 = . if (EL8_A_1 <= -1 )
replace EL8_A_2 = . if (EL8_A_2 <= -1 )
replace EL9 = . if (EL9 <= -1 )
replace EL9_A = . if (EL9_A <= -1 )
replace EL10 = . if (EL10 <= -1 )
replace EL11 = . if (EL11 <= -1 )
replace EL12 = . if (EL12 <= -1 )
replace EL13_A = . if (EL13_A <= -1 )
replace EL13_B = . if (EL13_B <= -1 )
replace EL13_C = . if (EL13_C <= -1 )
replace EL13_D = . if (EL13_D <= -1 )
replace EL13_E = . if (EL13_E <= -1 )
replace EL13_F = . if (EL13_F <= -1 )
replace EL13_G = . if (EL13_G <= -1 )
replace EL13_H = . if (EL13_H <= -1 )
replace EL13_I = . if (EL13_I <= -1 )
replace EL13_J = . if (EL13_J <= -1 )
replace EL13_K = . if (EL13_K <= -1 )
replace EL13_K_1 = . if (EL13_K_1 <= -1 )
replace EL13_K_2 = . if (EL13_K_2 <= -1 )
replace EL13_K_3 = . if (EL13_K_3 <= -1 )
replace EL13_K_4 = . if (EL13_K_4 <= -1 )
replace EL14_A = . if (EL14_A <= -1 )
replace EL14_B = . if (EL14_B <= -1 )
replace EL15_M = . if (EL15_M <= -1 )
replace EL15_Y = . if (EL15_Y <= -1 )
replace EL16 = . if (EL16 <= -1 )
replace EL16_A = . if (EL16_A <= -1 )
replace EL17 = . if (EL17 <= -1 )
replace EL18 = . if (EL18 <= -1 )
replace EL19 = . if (EL19 <= -1 )
replace EL20_A = . if (EL20_A <= -1 )
replace EL20_B = . if (EL20_B <= -1 )
replace EL20_C = . if (EL20_C <= -1 )
replace EL20_D = . if (EL20_D <= -1 )
replace EL20_E = . if (EL20_E <= -1 )
replace EL20_F = . if (EL20_F <= -1 )
replace EL20_G = . if (EL20_G <= -1 )
replace EL20_H = . if (EL20_H <= -1 )
replace EL20_I = . if (EL20_I <= -1 )
replace EL20_J = . if (EL20_J <= -1 )
replace EL20_K = . if (EL20_K <= -1 )
replace EL20_K_1 = . if (EL20_K_1 <= -1 )
replace EL20_K_2 = . if (EL20_K_2 <= -1 )
replace EL20_K_3 = . if (EL20_K_3 <= -1 )
replace EL20_K_4 = . if (EL20_K_4 <= -1 )
replace EL21_A = . if (EL21_A <= -1 )
replace EL21_B = . if (EL21_B <= -1 )
replace EL22_M = . if (EL22_M <= -1 )
replace EL22_Y = . if (EL22_Y <= -1 )
replace EL23 = . if (EL23 <= -1 )
replace EL24 = . if (EL24 <= -1 )
replace EL25 = . if (EL25 <= -1 )
replace EL26_M = . if (EL26_M <= -1 )
replace EL26_Y = . if (EL26_Y <= -1 )
replace EL27 = . if (EL27 <= -1 )
replace EL28 = . if (EL28 <= -1 )
replace EL28A_00 = . if (EL28A_00 <= -1 )
replace EL28A_01 = . if (EL28A_01 <= -1 )
replace EL28A_02 = . if (EL28A_02 <= -1 )
replace EL28A_11 = . if (EL28A_11 <= -1 )
replace EL28A_12 = . if (EL28A_12 <= -1 )
replace EL28A_13 = . if (EL28A_13 <= -1 )
replace EL28A_21 = . if (EL28A_21 <= -1 )
replace EL28A_22 = . if (EL28A_22 <= -1 )
replace EL28A_23 = . if (EL28A_23 <= -1 )
replace EL28A_24 = . if (EL28A_24 <= -1 )
replace EL28A_25 = . if (EL28A_25 <= -1 )
replace EL28A_26 = . if (EL28A_26 <= -1 )
replace EL28A_71 = . if (EL28A_71 <= -1 )
replace EL28A_91 = . if (EL28A_91 <= -1 )
replace EL28B = . if (EL28B <= -1 )
replace EL29 = . if (EL29 <= -1 )
replace EL29_A = . if (EL29_A <= -1 )
replace EL29_B_A = . if (EL29_B_A <= -1 )
replace EL29_B_B = . if (EL29_B_B <= -1 )
replace EL29_B_C = . if (EL29_B_C <= -1 )
replace EL29_B_D = . if (EL29_B_D <= -1 )
replace EL29_B_E = . if (EL29_B_E <= -1 )
replace EL29_B_F = . if (EL29_B_F <= -1 )
replace EL29_B_G = . if (EL29_B_G <= -1 )
replace EL29_B_H = . if (EL29_B_H <= -1 )
replace EL29_B_I = . if (EL29_B_I <= -1 )
replace EL29_B_J = . if (EL29_B_J <= -1 )
replace EL29_B_K = . if (EL29_B_K <= -1 )
replace EL29BK_1 = . if (EL29BK_1 <= -1 )
replace EL29BK_2 = . if (EL29BK_2 <= -1 )
replace EL29BK_3 = . if (EL29BK_3 <= -1 )
replace EL29BK_4 = . if (EL29BK_4 <= -1 )
replace EL29_C = . if (EL29_C <= -1 )
replace EL29_D = . if (EL29_D <= -1 )
replace EL29_E = . if (EL29_E <= -1 )
replace EL30 = . if (EL30 <= -1 )
replace EL30_A = . if (EL30_A <= -1 )
replace EL30_B_M = . if (EL30_B_M <= -1 )
replace EL30C_00 = . if (EL30C_00 <= -1 )
replace EL30C_01 = . if (EL30C_01 <= -1 )
replace EL30C_02 = . if (EL30C_02 <= -1 )
replace EL30C_11 = . if (EL30C_11 <= -1 )
replace EL30C_12 = . if (EL30C_12 <= -1 )
replace EL30C_13 = . if (EL30C_13 <= -1 )
replace EL30C_21 = . if (EL30C_21 <= -1 )
replace EL30C_22 = . if (EL30C_22 <= -1 )
replace EL30C_23 = . if (EL30C_23 <= -1 )
replace EL30C_24 = . if (EL30C_24 <= -1 )
replace EL30C_25 = . if (EL30C_25 <= -1 )
replace EL30C_26 = . if (EL30C_26 <= -1 )
replace EL30C_27 = . if (EL30C_27 <= -1 )
replace EL30C_71 = . if (EL30C_71 <= -1 )
replace EL30C_91 = . if (EL30C_91 <= -1 )
replace EL30_D = . if (EL30_D <= -1 )
replace EL31 = . if (EL31 <= -1 )
replace EL32 = . if (EL32 <= -1 )
replace EL33 = . if (EL33 <= -1 )
replace EL33_A = . if (EL33_A <= -1 )
replace EL33_B = . if (EL33_B <= -1 )
replace EL34 = . if (EL34 <= -1 )
replace EL35 = . if (EL35 <= -1 )
replace EL35_A = . if (EL35_A <= -1 )
replace EL36 = . if (EL36 <= -1 )
replace EL37 = . if (EL37 <= -1 )
replace EL38 = . if (EL38 <= -1 )
replace EL39 = . if (EL39 <= -1 )
replace EL39_A = . if (EL39_A <= -1 )
replace EL39_B = . if (EL39_B <= -1 )
replace EL40 = . if (EL40 <= -1 )
replace EL41 = . if (EL41 <= -1 )
replace EL41_A = . if (EL41_A <= -1 )
replace EL42 = . if (EL42 <= -1 )
replace EL43 = . if (EL43 <= -1 )
replace EL44_A = . if (EL44_A <= -1 )
replace EL44_B = . if (EL44_B <= -1 )
replace EL45_A = . if (EL45_A <= -1 )
replace EL45_B = . if (EL45_B <= -1 )
replace EL45_C = . if (EL45_C <= -1 )
replace EL45_D = . if (EL45_D <= -1 )
replace EL45_E = . if (EL45_E <= -1 )
replace EL45_F = . if (EL45_F <= -1 )
replace EL45_G = . if (EL45_G <= -1 )
replace EL45_H = . if (EL45_H <= -1 )
replace EL45_I = . if (EL45_I <= -1 )
replace EL45_J = . if (EL45_J <= -1 )
replace EL45_K = . if (EL45_K <= -1 )
replace EL45_L = . if (EL45_L <= -1 )
replace EL46 = . if (EL46 <= -1 )
replace EL47_01 = . if (EL47_01 <= -1 )
replace EL47_02 = . if (EL47_02 <= -1 )
replace EL47_11 = . if (EL47_11 <= -1 )
replace EL47_12 = . if (EL47_12 <= -1 )
replace EL47_13 = . if (EL47_13 <= -1 )
replace EL47_21 = . if (EL47_21 <= -1 )
replace EL47_22 = . if (EL47_22 <= -1 )
replace EL47_23 = . if (EL47_23 <= -1 )
replace EL47_71 = . if (EL47_71 <= -1 )
replace EL47_91 = . if (EL47_91 <= -1 )
replace EL48_A = . if (EL48_A <= -1 )
replace EL48_B = . if (EL48_B <= -1 )
replace EL48_C = . if (EL48_C <= -1 )
replace EL48_D = . if (EL48_D <= -1 )
replace EL48_E = . if (EL48_E <= -1 )
replace EL48_F = . if (EL48_F <= -1 )
replace EL48_G = . if (EL48_G <= -1 )
replace EL48_H = . if (EL48_H <= -1 )
replace EL48_I = . if (EL48_I <= -1 )
replace EL48_J = . if (EL48_J <= -1 )
replace EL48_K = . if (EL48_K <= -1 )
replace EL48_K_1 = . if (EL48_K_1 <= -1 )
replace EL48_K_2 = . if (EL48_K_2 <= -1 )
replace EL48_K_3 = . if (EL48_K_3 <= -1 )
replace EL48_K_4 = . if (EL48_K_4 <= -1 )
replace EL49_A = . if (EL49_A <= -1 )
replace EL49_B = . if (EL49_B <= -1 )
replace EL50 = . if (EL50 <= -1 )
replace EL50_A = . if (EL50_A <= -1 )
replace EL51 = . if (EL51 <= -1 )
replace EL52 = . if (EL52 <= -1 )
replace EL55 = . if (EL55 <= -1 )
replace EL56 = . if (EL56 <= -1 )
replace EL57 = . if (EL57 <= -1 )
replace EL58 = . if (EL58 <= -1 )
replace EL58_A_1 = . if (EL58_A_1 <= -1 )
replace EL58_A_2 = . if (EL58_A_2 <= -1 )
replace EL58_A_3 = . if (EL58_A_3 <= -1 )
replace EL58_A_4 = . if (EL58_A_4 <= -1 )
replace EL58_B = . if (EL58_B <= -1 )
replace EL58_C_M = . if (EL58_C_M <= -1 )
replace EL58_D = . if (EL58_D <= -1 )
replace EL59_A = . if (EL59_A <= -1 )
replace EL59_B = . if (EL59_B <= -1 )
replace EL60 = . if (EL60 <= -1 )
replace EL63 = . if (EL63 <= -1 )
replace EL64 = . if (EL64 <= -1 )
replace EL65_01 = . if (EL65_01 <= -1 )
replace EL65_02 = . if (EL65_02 <= -1 )
replace EL65_11 = . if (EL65_11 <= -1 )
replace EL65_12 = . if (EL65_12 <= -1 )
replace EL65_13 = . if (EL65_13 <= -1 )
replace EL65_21 = . if (EL65_21 <= -1 )
replace EL65_22 = . if (EL65_22 <= -1 )
replace EL65_23 = . if (EL65_23 <= -1 )
replace EL65_28 = . if (EL65_28 <= -1 )
replace EL65_71 = . if (EL65_71 <= -1 )
replace EL65_91 = . if (EL65_91 <= -1 )
replace EL65_A_1 = . if (EL65_A_1 <= -1 )
replace EL65_A_2 = . if (EL65_A_2 <= -1 )
replace EL66 = . if (EL66 <= -1 )
replace EL66_A = . if (EL66_A <= -1 )
replace EL66_B = . if (EL66_B <= -1 )
replace EL66_C_1 = . if (EL66_C_1 <= -1 )
replace EL66_C_2 = . if (EL66_C_2 <= -1 )
replace EL66_C_3 = . if (EL66_C_3 <= -1 )
replace EL66_C_4 = . if (EL66_C_4 <= -1 )
replace EL66_C_5 = . if (EL66_C_5 <= -1 )
replace EL66_C_6 = . if (EL66_C_6 <= -1 )
replace EL66_C_7 = . if (EL66_C_7 <= -1 )
replace EL66_C_8 = . if (EL66_C_8 <= -1 )
replace EL66_C_9 = . if (EL66_C_9 <= -1 )
replace EL66_D = . if (EL66_D <= -1 )
replace EL66_E = . if (EL66_E <= -1 )
replace EL66_F = . if (EL66_F <= -1 )
replace EL66_G_1 = . if (EL66_G_1 <= -1 )
replace EL66_G_2 = . if (EL66_G_2 <= -1 )
replace EL66_G_3 = . if (EL66_G_3 <= -1 )
replace EL66_G_4 = . if (EL66_G_4 <= -1 )
replace EL66_G_5 = . if (EL66_G_5 <= -1 )
replace EL66_H_1 = . if (EL66_H_1 <= -1 )
replace EL66_H_2 = . if (EL66_H_2 <= -1 )
replace EL66_H_3 = . if (EL66_H_3 <= -1 )
replace EL66_H_4 = . if (EL66_H_4 <= -1 )
replace EL66_H_5 = . if (EL66_H_5 <= -1 )
replace EL66_H_6 = . if (EL66_H_6 <= -1 )
replace EL66_H_7 = . if (EL66_H_7 <= -1 )
replace EL66_H_8 = . if (EL66_H_8 <= -1 )
replace EL66_H_9 = . if (EL66_H_9 <= -1 )
replace EL66_I = . if (EL66_I <= -1 )
replace EL67 = . if (EL67 <= -1 )
replace EL67_A = . if (EL67_A <= -1 )
replace EL67_B = . if (EL67_B <= -1 )
replace EL67_C_1 = . if (EL67_C_1 <= -1 )
replace EL67_C_2 = . if (EL67_C_2 <= -1 )
replace EL67_C_3 = . if (EL67_C_3 <= -1 )
replace EL67_C_4 = . if (EL67_C_4 <= -1 )
replace EL67_C_5 = . if (EL67_C_5 <= -1 )
replace EL67_C_6 = . if (EL67_C_6 <= -1 )
replace EL67_C_7 = . if (EL67_C_7 <= -1 )
replace EL67_C_8 = . if (EL67_C_8 <= -1 )
replace EL67_C_9 = . if (EL67_C_9 <= -1 )
replace EL67_D = . if (EL67_D <= -1 )
replace EL67_E = . if (EL67_E <= -1 )
replace EL67_F = . if (EL67_F <= -1 )
replace EL67_G_1 = . if (EL67_G_1 <= -1 )
replace EL67_G_2 = . if (EL67_G_2 <= -1 )
replace EL67_G_3 = . if (EL67_G_3 <= -1 )
replace EL67_G_4 = . if (EL67_G_4 <= -1 )
replace EL67_G_5 = . if (EL67_G_5 <= -1 )
replace EL67_H_1 = . if (EL67_H_1 <= -1 )
replace EL67_H_2 = . if (EL67_H_2 <= -1 )
replace EL67_H_3 = . if (EL67_H_3 <= -1 )
replace EL67_H_4 = . if (EL67_H_4 <= -1 )
replace EL67_H_5 = . if (EL67_H_5 <= -1 )
replace EL67_H_6 = . if (EL67_H_6 <= -1 )
replace EL67_H_7 = . if (EL67_H_7 <= -1 )
replace EL67_H_8 = . if (EL67_H_8 <= -1 )
replace EL67_H_9 = . if (EL67_H_9 <= -1 )
replace EL67_I = . if (EL67_I <= -1 )
replace EL68 = . if (EL68 <= -1 )
replace EL68A_1 = . if (EL68A_1 <= -1 )
replace EL68A_2 = . if (EL68A_2 <= -1 )
replace EL68A_3 = . if (EL68A_3 <= -1 )
replace EL68A_4 = . if (EL68A_4 <= -1 )
replace EL68A_5 = . if (EL68A_5 <= -1 )
replace EL68A_6 = . if (EL68A_6 <= -1 )
replace EL68B_1 = . if (EL68B_1 <= -1 )
replace EL68C_1 = . if (EL68C_1 <= -1 )
replace EL68D_1 = . if (EL68D_1 <= -1 )
replace EL68E_1 = . if (EL68E_1 <= -1 )
replace EL68F1_1 = . if (EL68F1_1 <= -1 )
replace EL68F1_2 = . if (EL68F1_2 <= -1 )
replace EL68F111 = . if (EL68F111 <= -1 )
replace EL68F112 = . if (EL68F112 <= -1 )
replace EL68F113 = . if (EL68F113 <= -1 )
replace EL68F121 = . if (EL68F121 <= -1 )
replace EL68F122 = . if (EL68F122 <= -1 )
replace EL68F123 = . if (EL68F123 <= -1 )
replace EL68F128 = . if (EL68F128 <= -1 )
replace EL68F171 = . if (EL68F171 <= -1 )
replace EL68F191 = . if (EL68F191 <= -1 )
replace EL68G_1 = . if (EL68G_1 <= -1 )
replace EL68B_2 = . if (EL68B_2 <= -1 )
replace EL68C_2 = . if (EL68C_2 <= -1 )
replace EL68D_2 = . if (EL68D_2 <= -1 )
replace EL68E_2 = . if (EL68E_2 <= -1 )
replace EL68F2_1 = . if (EL68F2_1 <= -1 )
replace EL68F2_2 = . if (EL68F2_2 <= -1 )
replace EL68F211 = . if (EL68F211 <= -1 )
replace EL68F212 = . if (EL68F212 <= -1 )
replace EL68F213 = . if (EL68F213 <= -1 )
replace EL68F221 = . if (EL68F221 <= -1 )
replace EL68F222 = . if (EL68F222 <= -1 )
replace EL68F223 = . if (EL68F223 <= -1 )
replace EL68F228 = . if (EL68F228 <= -1 )
replace EL68F271 = . if (EL68F271 <= -1 )
replace EL68F291 = . if (EL68F291 <= -1 )
replace EL68G_2 = . if (EL68G_2 <= -1 )
replace EL69 = . if (EL69 <= -1 )
replace EL69_A_1 = . if (EL69_A_1 <= -1 )
replace EL69_B_1 = . if (EL69_B_1 <= -1 )
replace EL69_A_2 = . if (EL69_A_2 <= -1 )
replace EL69_B_2 = . if (EL69_B_2 <= -1 )
replace EL69_A_3 = . if (EL69_A_3 <= -1 )
replace EL69_B_3 = . if (EL69_B_3 <= -1 )
replace EL69_A_4 = . if (EL69_A_4 <= -1 )
replace EL69_B_4 = . if (EL69_B_4 <= -1 )
replace EL69_A_5 = . if (EL69_A_5 <= -1 )
replace EL69_B_5 = . if (EL69_B_5 <= -1 )
replace EL70 = . if (EL70 <= -1 )
replace EL71 = . if (EL71 <= -1 )
replace EL72_01 = . if (EL72_01 <= -1 )
replace EL72_02 = . if (EL72_02 <= -1 )
replace EL72_22 = . if (EL72_22 <= -1 )
replace EL72_23 = . if (EL72_23 <= -1 )
replace EL72_24 = . if (EL72_24 <= -1 )
replace EL72_25 = . if (EL72_25 <= -1 )
replace EL72_26 = . if (EL72_26 <= -1 )
replace EL72_71 = . if (EL72_71 <= -1 )
replace EL72_91 = . if (EL72_91 <= -1 )
replace EL72_A1 = . if (EL72_A1 <= -1 )
replace EL72_A2 = . if (EL72_A2 <= -1 )
replace EL73 = . if (EL73 <= -1 )
replace EL73_A = . if (EL73_A <= -1 )
replace EL73_B01 = . if (EL73_B01 <= -1 )
replace EL73_B02 = . if (EL73_B02 <= -1 )
replace EL73_B03 = . if (EL73_B03 <= -1 )
replace EL73_B04 = . if (EL73_B04 <= -1 )
replace EL73_B05 = . if (EL73_B05 <= -1 )
replace EL73_B06 = . if (EL73_B06 <= -1 )
replace EL73_B07 = . if (EL73_B07 <= -1 )
replace EL73_B08 = . if (EL73_B08 <= -1 )
replace EL73_B09 = . if (EL73_B09 <= -1 )
replace EL73_C = . if (EL73_C <= -1 )
replace EL74 = . if (EL74 <= -1 )
replace EL74_A = . if (EL74_A <= -1 )
replace EL74_B01 = . if (EL74_B01 <= -1 )
replace EL74_B02 = . if (EL74_B02 <= -1 )
replace EL74_B03 = . if (EL74_B03 <= -1 )
replace EL74_B04 = . if (EL74_B04 <= -1 )
replace EL74_B05 = . if (EL74_B05 <= -1 )
replace EL74_B06 = . if (EL74_B06 <= -1 )
replace EL74_B07 = . if (EL74_B07 <= -1 )
replace EL74_B08 = . if (EL74_B08 <= -1 )
replace EL74_B09 = . if (EL74_B09 <= -1 )
replace EL74_C = . if (EL74_C <= -1 )
replace EL75 = . if (EL75 <= -1 )
replace EL75_A_1 = . if (EL75_A_1 <= -1 )
replace EL75_A_2 = . if (EL75_A_2 <= -1 )
replace EL75_A_3 = . if (EL75_A_3 <= -1 )
replace EL75_A_4 = . if (EL75_A_4 <= -1 )
replace EL75_A_5 = . if (EL75_A_5 <= -1 )
replace EL75_A_6 = . if (EL75_A_6 <= -1 )
replace EL75B_1 = . if (EL75B_1 <= -1 )
replace EL75C_1 = . if (EL75C_1 <= -1 )
replace EL75D_1 = . if (EL75D_1 <= -1 )
replace EL75E_1 = . if (EL75E_1 <= -1 )
replace EL75F101 = . if (EL75F101 <= -1 )
replace EL75F102 = . if (EL75F102 <= -1 )
replace EL75F122 = . if (EL75F122 <= -1 )
replace EL75F123 = . if (EL75F123 <= -1 )
replace EL75F124 = . if (EL75F124 <= -1 )
replace EL75F125 = . if (EL75F125 <= -1 )
replace EL75F126 = . if (EL75F126 <= -1 )
replace EL75F171 = . if (EL75F171 <= -1 )
replace EL75F191 = . if (EL75F191 <= -1 )
replace EL75G_1 = . if (EL75G_1 <= -1 )
replace EL75B_2 = . if (EL75B_2 <= -1 )
replace EL75C_2 = . if (EL75C_2 <= -1 )
replace EL75D_2 = . if (EL75D_2 <= -1 )
replace EL75E_2 = . if (EL75E_2 <= -1 )
replace EL75F201 = . if (EL75F201 <= -1 )
replace EL75F202 = . if (EL75F202 <= -1 )
replace EL75F222 = . if (EL75F222 <= -1 )
replace EL75F223 = . if (EL75F223 <= -1 )
replace EL75F224 = . if (EL75F224 <= -1 )
replace EL75F225 = . if (EL75F225 <= -1 )
replace EL75F226 = . if (EL75F226 <= -1 )
replace EL75F271 = . if (EL75F271 <= -1 )
replace EL75F291 = . if (EL75F291 <= -1 )
replace EL75G_2 = . if (EL75G_2 <= -1 )
replace EL76 = . if (EL76 <= -1 )
replace EL76_A_1 = . if (EL76_A_1 <= -1 )
replace EL76_A_2 = . if (EL76_A_2 <= -1 )
replace EL76_A_3 = . if (EL76_A_3 <= -1 )
replace EL76_A_4 = . if (EL76_A_4 <= -1 )
replace EL77 = . if (EL77 <= -1 )
replace EL77_A = . if (EL77_A <= -1 )
replace EL77B_01 = . if (EL77B_01 <= -1 )
replace EL77B_02 = . if (EL77B_02 <= -1 )
replace EL77B_11 = . if (EL77B_11 <= -1 )
replace EL77B_12 = . if (EL77B_12 <= -1 )
replace EL77B_13 = . if (EL77B_13 <= -1 )
replace EL77B_21 = . if (EL77B_21 <= -1 )
replace EL77B_22 = . if (EL77B_22 <= -1 )
replace EL77B_23 = . if (EL77B_23 <= -1 )
replace EL77B_24 = . if (EL77B_24 <= -1 )
replace EL77B_25 = . if (EL77B_25 <= -1 )
replace EL77B_26 = . if (EL77B_26 <= -1 )
replace EL77B_27 = . if (EL77B_27 <= -1 )
replace EL77B_28 = . if (EL77B_28 <= -1 )
replace EL77B_71 = . if (EL77B_71 <= -1 )
replace EL77B_91 = . if (EL77B_91 <= -1 )
replace EL77_C_1 = . if (EL77_C_1 <= -1 )
replace EL77_C_2 = . if (EL77_C_2 <= -1 )
replace EL77_C_3 = . if (EL77_C_3 <= -1 )
replace EL77_C_4 = . if (EL77_C_4 <= -1 )
replace EL77_C_5 = . if (EL77_C_5 <= -1 )
replace EL77_C_6 = . if (EL77_C_6 <= -1 )
replace EL77_C_7 = . if (EL77_C_7 <= -1 )
replace EL77_C_8 = . if (EL77_C_8 <= -1 )
replace EL78 = . if (EL78 <= -1 )
replace EL79 = . if (EL79 <= -1 )
replace EL80_01 = . if (EL80_01 <= -1 )
replace EL80_02 = . if (EL80_02 <= -1 )
replace EL80_11 = . if (EL80_11 <= -1 )
replace EL80_12 = . if (EL80_12 <= -1 )
replace EL80_13 = . if (EL80_13 <= -1 )
replace EL80_21 = . if (EL80_21 <= -1 )
replace EL80_22 = . if (EL80_22 <= -1 )
replace EL80_23 = . if (EL80_23 <= -1 )
replace EL80_28 = . if (EL80_28 <= -1 )
replace EL80_71 = . if (EL80_71 <= -1 )
replace EL80_91 = . if (EL80_91 <= -1 )
replace EL80_A1 = . if (EL80_A1 <= -1 )
replace EL80_A2 = . if (EL80_A2 <= -1 )
replace EL81_01 = . if (EL81_01 <= -1 )
replace EL81_02 = . if (EL81_02 <= -1 )
replace EL81_03 = . if (EL81_03 <= -1 )
replace EL81_A = . if (EL81_A <= -1 )
replace EL81_B = . if (EL81_B <= -1 )
replace EL81_C_1 = . if (EL81_C_1 <= -1 )
replace EL81_C_2 = . if (EL81_C_2 <= -1 )
replace EL81_C_3 = . if (EL81_C_3 <= -1 )
replace EL81_C_4 = . if (EL81_C_4 <= -1 )
replace EL81_C_5 = . if (EL81_C_5 <= -1 )
replace EL81_C_6 = . if (EL81_C_6 <= -1 )
replace EL81_D = . if (EL81_D <= -1 )
replace EL81_E = . if (EL81_E <= -1 )
replace EL81_F = . if (EL81_F <= -1 )
replace EL81_G_1 = . if (EL81_G_1 <= -1 )
replace EL81_G_2 = . if (EL81_G_2 <= -1 )
replace EL81_G_3 = . if (EL81_G_3 <= -1 )
replace EL81_G_4 = . if (EL81_G_4 <= -1 )
replace EL81_G_5 = . if (EL81_G_5 <= -1 )
replace EL81_H_1 = . if (EL81_H_1 <= -1 )
replace EL81_H_2 = . if (EL81_H_2 <= -1 )
replace EL81_H_3 = . if (EL81_H_3 <= -1 )
replace EL81_H_4 = . if (EL81_H_4 <= -1 )
replace EL81_H_5 = . if (EL81_H_5 <= -1 )
replace EL81_H_6 = . if (EL81_H_6 <= -1 )
replace EL81_I = . if (EL81_I <= -1 )
replace EL81_J = . if (EL81_J <= -1 )
replace EL81_K_1 = . if (EL81_K_1 <= -1 )
replace EL81_K_2 = . if (EL81_K_2 <= -1 )
replace EL81_K_3 = . if (EL81_K_3 <= -1 )
replace EL81_K_4 = . if (EL81_K_4 <= -1 )
replace EL81_K_5 = . if (EL81_K_5 <= -1 )
replace EL81_K_6 = . if (EL81_K_6 <= -1 )
replace EL81_K_7 = . if (EL81_K_7 <= -1 )
replace EL81_K_8 = . if (EL81_K_8 <= -1 )
replace EL81_L_1 = . if (EL81_L_1 <= -1 )
replace EL81_L_2 = . if (EL81_L_2 <= -1 )
replace EL81_L_3 = . if (EL81_L_3 <= -1 )
replace EL81_L_4 = . if (EL81_L_4 <= -1 )
replace EL81_L_5 = . if (EL81_L_5 <= -1 )
replace EL81_L_6 = . if (EL81_L_6 <= -1 )
replace EL81_M = . if (EL81_M <= -1 )
replace EL82_01 = . if (EL82_01 <= -1 )
replace EL82_02 = . if (EL82_02 <= -1 )
replace EL82_03 = . if (EL82_03 <= -1 )
replace EL82_A = . if (EL82_A <= -1 )
replace EL82_B = . if (EL82_B <= -1 )
replace EL82_C_1 = . if (EL82_C_1 <= -1 )
replace EL82_C_2 = . if (EL82_C_2 <= -1 )
replace EL82_C_3 = . if (EL82_C_3 <= -1 )
replace EL82_C_4 = . if (EL82_C_4 <= -1 )
replace EL82_C_5 = . if (EL82_C_5 <= -1 )
replace EL82_C_6 = . if (EL82_C_6 <= -1 )
replace EL82_D = . if (EL82_D <= -1 )
replace EL82_E = . if (EL82_E <= -1 )
replace EL82_F = . if (EL82_F <= -1 )
replace EL82_G_1 = . if (EL82_G_1 <= -1 )
replace EL82_G_2 = . if (EL82_G_2 <= -1 )
replace EL82_G_3 = . if (EL82_G_3 <= -1 )
replace EL82_G_4 = . if (EL82_G_4 <= -1 )
replace EL82_G_5 = . if (EL82_G_5 <= -1 )
replace EL82_H_1 = . if (EL82_H_1 <= -1 )
replace EL82_H_2 = . if (EL82_H_2 <= -1 )
replace EL82_H_3 = . if (EL82_H_3 <= -1 )
replace EL82_H_4 = . if (EL82_H_4 <= -1 )
replace EL82_H_5 = . if (EL82_H_5 <= -1 )
replace EL82_H_6 = . if (EL82_H_6 <= -1 )
replace EL82_I = . if (EL82_I <= -1 )
replace EL82_J = . if (EL82_J <= -1 )
replace EL82_K_1 = . if (EL82_K_1 <= -1 )
replace EL82_K_2 = . if (EL82_K_2 <= -1 )
replace EL82_K_3 = . if (EL82_K_3 <= -1 )
replace EL82_K_4 = . if (EL82_K_4 <= -1 )
replace EL82_K_5 = . if (EL82_K_5 <= -1 )
replace EL82_K_6 = . if (EL82_K_6 <= -1 )
replace EL82_K_7 = . if (EL82_K_7 <= -1 )
replace EL82_K_8 = . if (EL82_K_8 <= -1 )
replace EL82_L_1 = . if (EL82_L_1 <= -1 )
replace EL82_L_2 = . if (EL82_L_2 <= -1 )
replace EL82_L_3 = . if (EL82_L_3 <= -1 )
replace EL82_L_4 = . if (EL82_L_4 <= -1 )
replace EL82_L_5 = . if (EL82_L_5 <= -1 )
replace EL82_L_6 = . if (EL82_L_6 <= -1 )
replace EL82_M = . if (EL82_M <= -1 )
replace EL83 = . if (EL83 <= -1 )
replace EL83A_1 = . if (EL83A_1 <= -1 )
replace EL83A_2 = . if (EL83A_2 <= -1 )
replace EL83A_3 = . if (EL83A_3 <= -1 )
replace EL83A_4 = . if (EL83A_4 <= -1 )
replace EL83A_5 = . if (EL83A_5 <= -1 )
replace EL83B_1 = . if (EL83B_1 <= -1 )
replace EL83C_1 = . if (EL83C_1 <= -1 )
replace EL83D_1 = . if (EL83D_1 <= -1 )
replace EL83E_1 = . if (EL83E_1 <= -1 )
replace EL83F1_1 = . if (EL83F1_1 <= -1 )
replace EL83F1_2 = . if (EL83F1_2 <= -1 )
replace EL83F111 = . if (EL83F111 <= -1 )
replace EL83F112 = . if (EL83F112 <= -1 )
replace EL83F113 = . if (EL83F113 <= -1 )
replace EL83F121 = . if (EL83F121 <= -1 )
replace EL83F122 = . if (EL83F122 <= -1 )
replace EL83F123 = . if (EL83F123 <= -1 )
replace EL83F128 = . if (EL83F128 <= -1 )
replace EL83F171 = . if (EL83F171 <= -1 )
replace EL83F191 = . if (EL83F191 <= -1 )
replace EL83G_1 = . if (EL83G_1 <= -1 )
replace EL83B_2 = . if (EL83B_2 <= -1 )
replace EL83C_2 = . if (EL83C_2 <= -1 )
replace EL83D_2 = . if (EL83D_2 <= -1 )
replace EL83E_2 = . if (EL83E_2 <= -1 )
replace EL83F2_1 = . if (EL83F2_1 <= -1 )
replace EL83F2_2 = . if (EL83F2_2 <= -1 )
replace EL83F211 = . if (EL83F211 <= -1 )
replace EL83F212 = . if (EL83F212 <= -1 )
replace EL83F213 = . if (EL83F213 <= -1 )
replace EL83F221 = . if (EL83F221 <= -1 )
replace EL83F222 = . if (EL83F222 <= -1 )
replace EL83F223 = . if (EL83F223 <= -1 )
replace EL83F228 = . if (EL83F228 <= -1 )
replace EL83F271 = . if (EL83F271 <= -1 )
replace EL83F291 = . if (EL83F291 <= -1 )
replace EL83G_2 = . if (EL83G_2 <= -1 )
replace EL84 = . if (EL84 <= -1 )
replace EL85 = . if (EL85 <= -1 )
replace EL86_01 = . if (EL86_01 <= -1 )
replace EL86_02 = . if (EL86_02 <= -1 )
replace EL86_11 = . if (EL86_11 <= -1 )
replace EL86_12 = . if (EL86_12 <= -1 )
replace EL86_13 = . if (EL86_13 <= -1 )
replace EL86_21 = . if (EL86_21 <= -1 )
replace EL86_22 = . if (EL86_22 <= -1 )
replace EL86_23 = . if (EL86_23 <= -1 )
replace EL86_27 = . if (EL86_27 <= -1 )
replace EL86_29 = . if (EL86_29 <= -1 )
replace EL86_71 = . if (EL86_71 <= -1 )
replace EL86_91 = . if (EL86_91 <= -1 )
replace EL86_A1 = . if (EL86_A1 <= -1 )
replace EL86_A2 = . if (EL86_A2 <= -1 )
replace EL87_01 = . if (EL87_01 <= -1 )
replace EL87_02 = . if (EL87_02 <= -1 )
replace EL87_03 = . if (EL87_03 <= -1 )
replace EL87_A = . if (EL87_A <= -1 )
replace EL87_B = . if (EL87_B <= -1 )
replace EL87_C = . if (EL87_C <= -1 )
replace EL87_D = . if (EL87_D <= -1 )
replace EL87_E = . if (EL87_E <= -1 )
replace EL87_F = . if (EL87_F <= -1 )
replace EL87_G_1 = . if (EL87_G_1 <= -1 )
replace EL87_G_2 = . if (EL87_G_2 <= -1 )
replace EL87_G_3 = . if (EL87_G_3 <= -1 )
replace EL87_G_4 = . if (EL87_G_4 <= -1 )
replace EL87_G_5 = . if (EL87_G_5 <= -1 )
replace EL87_G_6 = . if (EL87_G_6 <= -1 )
replace EL87_G_7 = . if (EL87_G_7 <= -1 )
replace EL87_G_8 = . if (EL87_G_8 <= -1 )
replace EL87_H = . if (EL87_H <= -1 )
replace EL87_I = . if (EL87_I <= -1 )
replace EL87_J = . if (EL87_J <= -1 )
replace EL87_K = . if (EL87_K <= -1 )
replace EL87_L_1 = . if (EL87_L_1 <= -1 )
replace EL87_L_2 = . if (EL87_L_2 <= -1 )
replace EL87_L_3 = . if (EL87_L_3 <= -1 )
replace EL87_L_4 = . if (EL87_L_4 <= -1 )
replace EL87_L_5 = . if (EL87_L_5 <= -1 )
replace EL87_L_6 = . if (EL87_L_6 <= -1 )
replace EL87_M = . if (EL87_M <= -1 )
replace EL87_N = . if (EL87_N <= -1 )
replace EL87_O = . if (EL87_O <= -1 )
replace EL87_P = . if (EL87_P <= -1 )
replace EL88_01 = . if (EL88_01 <= -1 )
replace EL88_02 = . if (EL88_02 <= -1 )
replace EL88_03 = . if (EL88_03 <= -1 )
replace EL88_A = . if (EL88_A <= -1 )
replace EL88_B = . if (EL88_B <= -1 )
replace EL88_C = . if (EL88_C <= -1 )
replace EL88_D = . if (EL88_D <= -1 )
replace EL88_E = . if (EL88_E <= -1 )
replace EL88_F = . if (EL88_F <= -1 )
replace EL88_G_1 = . if (EL88_G_1 <= -1 )
replace EL88_G_2 = . if (EL88_G_2 <= -1 )
replace EL88_G_3 = . if (EL88_G_3 <= -1 )
replace EL88_G_4 = . if (EL88_G_4 <= -1 )
replace EL88_G_5 = . if (EL88_G_5 <= -1 )
replace EL88_G_6 = . if (EL88_G_6 <= -1 )
replace EL88_G_7 = . if (EL88_G_7 <= -1 )
replace EL88_G_8 = . if (EL88_G_8 <= -1 )
replace EL88_H = . if (EL88_H <= -1 )
replace EL88_I = . if (EL88_I <= -1 )
replace EL88_J = . if (EL88_J <= -1 )
replace EL88_K = . if (EL88_K <= -1 )
replace EL88_L_1 = . if (EL88_L_1 <= -1 )
replace EL88_L_2 = . if (EL88_L_2 <= -1 )
replace EL88_L_3 = . if (EL88_L_3 <= -1 )
replace EL88_L_4 = . if (EL88_L_4 <= -1 )
replace EL88_L_5 = . if (EL88_L_5 <= -1 )
replace EL88_L_6 = . if (EL88_L_6 <= -1 )
replace EL88_M = . if (EL88_M <= -1 )
replace EL88_N = . if (EL88_N <= -1 )
replace EL88_O = . if (EL88_O <= -1 )
replace EL88_P = . if (EL88_P <= -1 )
replace EL89 = . if (EL89 <= -1 )
replace EL89_A_1 = . if (EL89_A_1 <= -1 )
replace EL89_A_2 = . if (EL89_A_2 <= -1 )
replace EL89_A_3 = . if (EL89_A_3 <= -1 )
replace EL89_A_4 = . if (EL89_A_4 <= -1 )
replace EL89_A_5 = . if (EL89_A_5 <= -1 )
replace EL89_A_6 = . if (EL89_A_6 <= -1 )
replace EL89_A_7 = . if (EL89_A_7 <= -1 )
replace EL89_A_8 = . if (EL89_A_8 <= -1 )
replace EL89_A_9 = . if (EL89_A_9 <= -1 )
replace EL89B_1 = . if (EL89B_1 <= -1 )
replace EL89C_1 = . if (EL89C_1 <= -1 )
replace EL89D_1 = . if (EL89D_1 <= -1 )
replace EL89E_1 = . if (EL89E_1 <= -1 )
replace EL89F1_1 = . if (EL89F1_1 <= -1 )
replace EL89F1_2 = . if (EL89F1_2 <= -1 )
replace EL89F111 = . if (EL89F111 <= -1 )
replace EL89F112 = . if (EL89F112 <= -1 )
replace EL89F113 = . if (EL89F113 <= -1 )
replace EL89F121 = . if (EL89F121 <= -1 )
replace EL89F122 = . if (EL89F122 <= -1 )
replace EL89F123 = . if (EL89F123 <= -1 )
replace EL89F127 = . if (EL89F127 <= -1 )
replace EL89F129 = . if (EL89F129 <= -1 )
replace EL89F171 = . if (EL89F171 <= -1 )
replace EL89F191 = . if (EL89F191 <= -1 )
replace EL89G_1 = . if (EL89G_1 <= -1 )
replace EL89B_2 = . if (EL89B_2 <= -1 )
replace EL89C_2 = . if (EL89C_2 <= -1 )
replace EL89D_2 = . if (EL89D_2 <= -1 )
replace EL89E_2 = . if (EL89E_2 <= -1 )
replace EL89F2_1 = . if (EL89F2_1 <= -1 )
replace EL89F2_2 = . if (EL89F2_2 <= -1 )
replace EL89F211 = . if (EL89F211 <= -1 )
replace EL89F212 = . if (EL89F212 <= -1 )
replace EL89F213 = . if (EL89F213 <= -1 )
replace EL89F221 = . if (EL89F221 <= -1 )
replace EL89F222 = . if (EL89F222 <= -1 )
replace EL89F223 = . if (EL89F223 <= -1 )
replace EL89F227 = . if (EL89F227 <= -1 )
replace EL89F229 = . if (EL89F229 <= -1 )
replace EL89F271 = . if (EL89F271 <= -1 )
replace EL89F291 = . if (EL89F291 <= -1 )
replace EL89G_2 = . if (EL89G_2 <= -1 )
replace EL90 = . if (EL90 <= -1 )
replace EL91 = . if (EL91 <= -1 )
replace EL92_01 = . if (EL92_01 <= -1 )
replace EL92_02 = . if (EL92_02 <= -1 )
replace EL92_11 = . if (EL92_11 <= -1 )
replace EL92_12 = . if (EL92_12 <= -1 )
replace EL92_13 = . if (EL92_13 <= -1 )
replace EL92_21 = . if (EL92_21 <= -1 )
replace EL92_22 = . if (EL92_22 <= -1 )
replace EL92_23 = . if (EL92_23 <= -1 )
replace EL92_27 = . if (EL92_27 <= -1 )
replace EL92_29 = . if (EL92_29 <= -1 )
replace EL92_71 = . if (EL92_71 <= -1 )
replace EL92_91 = . if (EL92_91 <= -1 )
replace EL92A_1 = . if (EL92A_1 <= -1 )
replace EL92A_2 = . if (EL92A_2 <= -1 )
replace EL93 = . if (EL93 <= -1 )
replace EL93_A = . if (EL93_A <= -1 )
replace EL93_B_1 = . if (EL93_B_1 <= -1 )
replace EL93_B_2 = . if (EL93_B_2 <= -1 )
replace EL93_B_3 = . if (EL93_B_3 <= -1 )
replace EL93_B_4 = . if (EL93_B_4 <= -1 )
replace EL93_B_5 = . if (EL93_B_5 <= -1 )
replace EL93_B_6 = . if (EL93_B_6 <= -1 )
replace EL93_B_7 = . if (EL93_B_7 <= -1 )
replace EL93_B_8 = . if (EL93_B_8 <= -1 )
replace EL93_C = . if (EL93_C <= -1 )
replace EL94 = . if (EL94 <= -1 )
replace EL94_A = . if (EL94_A <= -1 )
replace EL94_B_1 = . if (EL94_B_1 <= -1 )
replace EL94_B_2 = . if (EL94_B_2 <= -1 )
replace EL94_B_3 = . if (EL94_B_3 <= -1 )
replace EL94_B_4 = . if (EL94_B_4 <= -1 )
replace EL94_B_5 = . if (EL94_B_5 <= -1 )
replace EL94_B_6 = . if (EL94_B_6 <= -1 )
replace EL94_B_7 = . if (EL94_B_7 <= -1 )
replace EL94_B_8 = . if (EL94_B_8 <= -1 )
replace EL94_C = . if (EL94_C <= -1 )
replace EL95 = . if (EL95 <= -1 )
replace EL95_A_1 = . if (EL95_A_1 <= -1 )
replace EL95_A_2 = . if (EL95_A_2 <= -1 )
replace EL95_A_3 = . if (EL95_A_3 <= -1 )
replace EL95_A_4 = . if (EL95_A_4 <= -1 )
replace EL95_A_5 = . if (EL95_A_5 <= -1 )
replace EL95_A_6 = . if (EL95_A_6 <= -1 )
replace EL95B_1 = . if (EL95B_1 <= -1 )
replace EL95C_1 = . if (EL95C_1 <= -1 )
replace EL95D_1 = . if (EL95D_1 <= -1 )
replace EL95E_1 = . if (EL95E_1 <= -1 )
replace EL95F1_1 = . if (EL95F1_1 <= -1 )
replace EL95F1_2 = . if (EL95F1_2 <= -1 )
replace EL95F127 = . if (EL95F127 <= -1 )
replace EL95F129 = . if (EL95F129 <= -1 )
replace EL95F171 = . if (EL95F171 <= -1 )
replace EL95F191 = . if (EL95F191 <= -1 )
replace EL95G_1 = . if (EL95G_1 <= -1 )
replace EL95B_2 = . if (EL95B_2 <= -1 )
replace EL95C_2 = . if (EL95C_2 <= -1 )
replace EL95D_2 = . if (EL95D_2 <= -1 )
replace EL95E_2 = . if (EL95E_2 <= -1 )
replace EL95F2_1 = . if (EL95F2_1 <= -1 )
replace EL95F2_2 = . if (EL95F2_2 <= -1 )
replace EL95F227 = . if (EL95F227 <= -1 )
replace EL95F229 = . if (EL95F229 <= -1 )
replace EL95F271 = . if (EL95F271 <= -1 )
replace EL95F291 = . if (EL95F291 <= -1 )
replace EL95G_2 = . if (EL95G_2 <= -1 )
replace EL96 = . if (EL96 <= -1 )
replace EL97 = . if (EL97 <= -1 )
replace EL98_01 = . if (EL98_01 <= -1 )
replace EL98_02 = . if (EL98_02 <= -1 )
replace EL98_11 = . if (EL98_11 <= -1 )
replace EL98_12 = . if (EL98_12 <= -1 )
replace EL98_13 = . if (EL98_13 <= -1 )
replace EL98_21 = . if (EL98_21 <= -1 )
replace EL98_22 = . if (EL98_22 <= -1 )
replace EL98_23 = . if (EL98_23 <= -1 )
replace EL98_27 = . if (EL98_27 <= -1 )
replace EL98_28 = . if (EL98_28 <= -1 )
replace EL98_29 = . if (EL98_29 <= -1 )
replace EL98_30 = . if (EL98_30 <= -1 )
replace EL98_71 = . if (EL98_71 <= -1 )
replace EL98_91 = . if (EL98_91 <= -1 )
replace EL98A_1 = . if (EL98A_1 <= -1 )
replace EL98A_2 = . if (EL98A_2 <= -1 )
replace EL99 = . if (EL99 <= -1 )
replace EL99_A_1 = . if (EL99_A_1 <= -1 )
replace EL99_A_2 = . if (EL99_A_2 <= -1 )
replace EL99_A_3 = . if (EL99_A_3 <= -1 )
replace EL99_A_4 = . if (EL99_A_4 <= -1 )
replace EL99_A_5 = . if (EL99_A_5 <= -1 )
replace EL99_A_6 = . if (EL99_A_6 <= -1 )
replace EL99_B = . if (EL99_B <= -1 )
replace EL100 = . if (EL100 <= -1 )
replace EL100A_1 = . if (EL100A_1 <= -1 )
replace EL100A_2 = . if (EL100A_2 <= -1 )
replace EL100A_3 = . if (EL100A_3 <= -1 )
replace EL100A_4 = . if (EL100A_4 <= -1 )
replace EL100A_5 = . if (EL100A_5 <= -1 )
replace EL100A_6 = . if (EL100A_6 <= -1 )
replace EL100_B = . if (EL100_B <= -1 )
replace EL101 = . if (EL101 <= -1 )
replace EL101A_1 = . if (EL101A_1 <= -1 )
replace EL101A_2 = . if (EL101A_2 <= -1 )
replace EL101A_3 = . if (EL101A_3 <= -1 )
replace EL101A_4 = . if (EL101A_4 <= -1 )
replace EL101A_5 = . if (EL101A_5 <= -1 )
replace EL101A_6 = . if (EL101A_6 <= -1 )
replace EL101B_1 = . if (EL101B_1 <= -1 )
replace EL101C_1 = . if (EL101C_1 <= -1 )
replace EL101D_1 = . if (EL101D_1 <= -1 )
replace EL101E_1 = . if (EL101E_1 <= -1 )
replace EL101B_2 = . if (EL101B_2 <= -1 )
replace EL101C_2 = . if (EL101C_2 <= -1 )
replace EL101D_2 = . if (EL101D_2 <= -1 )
replace EL101E_2 = . if (EL101E_2 <= -1 )
replace EL102 = . if (EL102 <= -1 )
replace EL103 = . if (EL103 <= -1 )
replace EL104_01 = . if (EL104_01 <= -1 )
replace EL104_02 = . if (EL104_02 <= -1 )
replace EL104_11 = . if (EL104_11 <= -1 )
replace EL104_12 = . if (EL104_12 <= -1 )
replace EL104_13 = . if (EL104_13 <= -1 )
replace EL104_21 = . if (EL104_21 <= -1 )
replace EL104_22 = . if (EL104_22 <= -1 )
replace EL104_23 = . if (EL104_23 <= -1 )
replace EL104_27 = . if (EL104_27 <= -1 )
replace EL104_28 = . if (EL104_28 <= -1 )
replace EL104_29 = . if (EL104_29 <= -1 )
replace EL104_71 = . if (EL104_71 <= -1 )
replace EL104_91 = . if (EL104_91 <= -1 )
replace EL104A_1 = . if (EL104A_1 <= -1 )
replace EL104A_2 = . if (EL104A_2 <= -1 )
replace EL105 = . if (EL105 <= -1 )
replace EL105A_1 = . if (EL105A_1 <= -1 )
replace EL105A_2 = . if (EL105A_2 <= -1 )
replace EL105A_3 = . if (EL105A_3 <= -1 )
replace EL105A_4 = . if (EL105A_4 <= -1 )
replace EL105A_5 = . if (EL105A_5 <= -1 )
replace EL105A_6 = . if (EL105A_6 <= -1 )
replace EL105_B = . if (EL105_B <= -1 )
replace EL106 = . if (EL106 <= -1 )
replace EL106A_1 = . if (EL106A_1 <= -1 )
replace EL106A_2 = . if (EL106A_2 <= -1 )
replace EL106A_3 = . if (EL106A_3 <= -1 )
replace EL106A_4 = . if (EL106A_4 <= -1 )
replace EL106A_5 = . if (EL106A_5 <= -1 )
replace EL106A_6 = . if (EL106A_6 <= -1 )
replace EL106_B = . if (EL106_B <= -1 )
replace EL107 = . if (EL107 <= -1 )
replace EL107A51 = . if (EL107A51 <= -1 )
replace EL107A52 = . if (EL107A52 <= -1 )
replace EL107A53 = . if (EL107A53 <= -1 )
replace EL107A54 = . if (EL107A54 <= -1 )
replace EL107A91 = . if (EL107A91 <= -1 )
replace EL107B_1 = . if (EL107B_1 <= -1 )
replace EL107C_1 = . if (EL107C_1 <= -1 )
replace EL107D_1 = . if (EL107D_1 <= -1 )
replace EL107E_1 = . if (EL107E_1 <= -1 )
replace EL107B_2 = . if (EL107B_2 <= -1 )
replace EL107C_2 = . if (EL107C_2 <= -1 )
replace EL107D_2 = . if (EL107D_2 <= -1 )
replace EL107E_2 = . if (EL107E_2 <= -1 )
replace EL108 = . if (EL108 <= -1 )
replace EL108_A = . if (EL108_A <= -1 )
replace EL108_B = . if (EL108_B <= -1 )
replace EL109 = . if (EL109 <= -1 )
replace EL110 = . if (EL110 <= -1 )
replace EL111_A = . if (EL111_A <= -1 )
replace EL111_B = . if (EL111_B <= -1 )
replace EL113_01 = . if (EL113_01 <= -1 )
replace EL113_02 = . if (EL113_02 <= -1 )
replace EL113_11 = . if (EL113_11 <= -1 )
replace EL113_12 = . if (EL113_12 <= -1 )
replace EL113_13 = . if (EL113_13 <= -1 )
replace EL113_21 = . if (EL113_21 <= -1 )
replace EL113_22 = . if (EL113_22 <= -1 )
replace EL113_23 = . if (EL113_23 <= -1 )
replace EL113_24 = . if (EL113_24 <= -1 )
replace EL113_25 = . if (EL113_25 <= -1 )
replace EL113_26 = . if (EL113_26 <= -1 )
replace EL113_27 = . if (EL113_27 <= -1 )
replace EL113_28 = . if (EL113_28 <= -1 )
replace EL113_29 = . if (EL113_29 <= -1 )
replace EL113_71 = . if (EL113_71 <= -1 )
replace EL113_91 = . if (EL113_91 <= -1 )
replace EL114_A = . if (EL114_A <= -1 )
replace EL114_B = . if (EL114_B <= -1 )
replace EL114_C = . if (EL114_C <= -1 )
replace EL114_D = . if (EL114_D <= -1 )
replace EL114_E = . if (EL114_E <= -1 )
replace EL114_F = . if (EL114_F <= -1 )
replace EL114_G = . if (EL114_G <= -1 )
replace EL114_H = . if (EL114_H <= -1 )
replace EL114_I = . if (EL114_I <= -1 )
replace EL114_J = . if (EL114_J <= -1 )
replace EL114_K = . if (EL114_K <= -1 )
replace EL114K_1 = . if (EL114K_1 <= -1 )
replace EL114K_2 = . if (EL114K_2 <= -1 )
replace EL114K_3 = . if (EL114K_3 <= -1 )
replace EL114K_4 = . if (EL114K_4 <= -1 )
replace EL115 = . if (EL115 <= -1 )
replace EL116 = . if (EL116 <= -1 )
replace EL117 = . if (EL117 <= -1 )
replace EL117_B1 = . if (EL117_B1 <= -1 )
replace EL117_B2 = . if (EL117_B2 <= -1 )
replace EL117_B3 = . if (EL117_B3 <= -1 )
replace EL117_B4 = . if (EL117_B4 <= -1 )
replace EL117_B5 = . if (EL117_B5 <= -1 )
replace EL118 = . if (EL118 <= -1 )
replace EL118_A = . if (EL118_A <= -1 )
replace EL119 = . if (EL119 <= -1 )
replace EL120 = . if (EL120 <= -1 )
replace EL121_A = . if (EL121_A <= -1 )
replace EL121_B = . if (EL121_B <= -1 )
replace EL121_C = . if (EL121_C <= -1 )
replace EL121_D = . if (EL121_D <= -1 )
replace EL121_E = . if (EL121_E <= -1 )
replace EL121_F = . if (EL121_F <= -1 )
replace EL122 = . if (EL122 <= -1 )
replace EL123_W = . if (EL123_W <= -1 )
replace EL124 = . if (EL124 <= -1 )
replace EL125 = . if (EL125 <= -1 )
replace EL126 = . if (EL126 <= -1 )
replace EL127 = . if (EL127 <= -1 )
replace EL128 = . if (EL128 <= -1 )
replace ELDM = . if (ELDM <= -1 )
replace ELTH = . if (ELTH <= -1 )
replace ELTM = . if (ELTM <= -1 )
replace ELAMPM = . if (ELAMPM <= -1 )
replace EM1 = . if (EM1 <= -1 )
replace EM2 = . if (EM2 <= -1 )
replace EM3 = . if (EM3 <= -1 )
replace EM4 = . if (EM4 <= -1 )
replace EM5 = . if (EM5 <= -1 )
replace EM6 = . if (EM6 <= -1 )
replace EM7 = . if (EM7 <= -1 )
replace EM8 = . if (EM8 <= -1 )
replace EM9 = . if (EM9 <= -1 )
replace EM10A = . if (EM10A <= -1 )
replace EM10B = . if (EM10B <= -1 )
replace EM11A = . if (EM11A <= -1 )
replace EM11B = . if (EM11B <= -1 )
replace EM11C = . if (EM11C <= -1 )
replace EM12A = . if (EM12A <= -1 )
replace EM12B = . if (EM12B <= -1 )
replace EM12C = . if (EM12C <= -1 )
replace EM12D = . if (EM12D <= -1 )
replace EM12E = . if (EM12E <= -1 )
replace EM13 = . if (EM13 <= -1 )
replace EM14A = . if (EM14A <= -1 )
replace EM14B = . if (EM14B <= -1 )
replace EM14C = . if (EM14C <= -1 )
replace EM15A = . if (EM15A <= -1 )
replace EM15B = . if (EM15B <= -1 )
replace EM16 = . if (EM16 <= -1 )
replace EM17 = . if (EM17 <= -1 )
replace EM18A = . if (EM18A <= -1 )
replace EM18B = . if (EM18B <= -1 )
replace EM18C = . if (EM18C <= -1 )
replace EM19 = . if (EM19 <= -1 )
replace EM20 = . if (EM20 <= -1 )
replace EM21 = . if (EM21 <= -1 )
replace EMDM = . if (EMDM <= -1 )
replace EMTH = . if (EMTH <= -1 )
replace EMTM = . if (EMTM <= -1 )
replace EMAMPM = . if (EMAMPM <= -1 )
replace EN1 = . if (EN1 <= -1 )
replace EN2 = . if (EN2 <= -1 )
replace EN2A = . if (EN2A <= -1 )
replace EN3_1_1 = . if (EN3_1_1 <= -1 )
replace EN3_1_2 = . if (EN3_1_2 <= -1 )
replace EN3_2_1 = . if (EN3_2_1 <= -1 )
replace EN3_2_2 = . if (EN3_2_2 <= -1 )
replace EN3_3_1 = . if (EN3_3_1 <= -1 )
replace EN3_3_2 = . if (EN3_3_2 <= -1 )
replace EN3_4_1 = . if (EN3_4_1 <= -1 )
replace EN3_4_2 = . if (EN3_4_2 <= -1 )
replace EN4 = . if (EN4 <= -1 )
replace EN4A1 = . if (EN4A1 <= -1 )
replace EN4A2 = . if (EN4A2 <= -1 )
replace EN4A3 = . if (EN4A3 <= -1 )
replace EN4A4 = . if (EN4A4 <= -1 )
replace EN4A5 = . if (EN4A5 <= -1 )
replace EN4A6 = . if (EN4A6 <= -1 )
replace EN5 = . if (EN5 <= -1 )
replace EN6 = . if (EN6 <= -1 )
replace EN6A1 = . if (EN6A1 <= -1 )
replace EN6A2 = . if (EN6A2 <= -1 )
replace JDATE_M = . if (JDATE_M <= -1 )
replace JDATE_Y = . if (JDATE_Y <= -1 )
replace EIA1_1 = . if (EIA1_1 <= -1 )
replace EIA1_2 = . if (EIA1_2 <= -1 )
replace EIA2_1 = . if (EIA2_1 <= -1 )
replace EIA2_2 = . if (EIA2_2 <= -1 )
replace EIA3_1 = . if (EIA3_1 <= -1 )
replace EIA3_2 = . if (EIA3_2 <= -1 )
replace EIA4_1 = . if (EIA4_1 <= -1 )
replace EIA4_2 = . if (EIA4_2 <= -1 )
replace EIA5_1 = . if (EIA5_1 <= -1 )
replace EIA5_2 = . if (EIA5_2 <= -1 )
replace EIA6_1 = . if (EIA6_1 <= -1 )
replace EIA6_2 = . if (EIA6_2 <= -1 )
replace EIA7_1 = . if (EIA7_1 <= -1 )
replace EIA7_2 = . if (EIA7_2 <= -1 )
replace EIA8_1 = . if (EIA8_1 <= -1 )
replace EIA8_2 = . if (EIA8_2 <= -1 )
replace EIA9_1 = . if (EIA9_1 <= -1 )
replace EIA9_2 = . if (EIA9_2 <= -1 )
replace EIA10_1 = . if (EIA10_1 <= -1 )
replace EIA10_2 = . if (EIA10_2 <= -1 )
replace NP1A = . if (NP1A <= -1 )
replace NP1B = . if (NP1B <= -1 )
replace NP1C = . if (NP1C <= -1 )
replace NP1D = . if (NP1D <= -1 )
replace NP1E = . if (NP1E <= -1 )
replace NP1F = . if (NP1F <= -1 )
replace NP1G = . if (NP1G <= -1 )
replace NP1H = . if (NP1H <= -1 )
replace NP1I = . if (NP1I <= -1 )
replace NP1J = . if (NP1J <= -1 )
replace NP1K = . if (NP1K <= -1 )
replace NP1L = . if (NP1L <= -1 )
replace NP1M = . if (NP1M <= -1 )
replace NP1N = . if (NP1N <= -1 )
replace NP2A = . if (NP2A <= -1 )
replace NP3A = . if (NP3A <= -1 )
replace NP2B = . if (NP2B <= -1 )
replace NP3B = . if (NP3B <= -1 )
replace NP2C = . if (NP2C <= -1 )
replace NP3C = . if (NP3C <= -1 )
replace NP2D = . if (NP2D <= -1 )
replace NP3D = . if (NP3D <= -1 )
replace NP2E = . if (NP2E <= -1 )
replace NP3E = . if (NP3E <= -1 )
replace NP2F = . if (NP2F <= -1 )
replace NP3F = . if (NP3F <= -1 )
replace NP2G = . if (NP2G <= -1 )
replace NP3G = . if (NP3G <= -1 )
replace NP2H = . if (NP2H <= -1 )
replace NP3H = . if (NP3H <= -1 )
replace NP2I = . if (NP2I <= -1 )
replace NP3I = . if (NP3I <= -1 )
replace NP2J = . if (NP2J <= -1 )
replace NP3J = . if (NP3J <= -1 )
replace AGE = . if (AGE <= -1 )
replace HLTHINS = . if (HLTHINS <= -1 )
replace FTWORK = . if (FTWORK <= -1 )
replace MSTAT = . if (MSTAT <= -1 )
replace INSCHOOL = . if (INSCHOOL <= -1 )
replace EDLEV = . if (EDLEV <= -1 )
replace HVY_ALC = . if (HVY_ALC <= -1 )
replace ALCR = . if (ALCR <= -1 )
replace MRJR = . if (MRJR <= -1 )
replace HERR = . if (HERR <= -1 )
replace NARR = . if (NARR <= -1 )
replace SEDR = . if (SEDR <= -1 )
replace AMPR = . if (AMPR <= -1 )
replace HALR = . if (HALR <= -1 )
replace INHR = . if (INHR <= -1 )
replace ALCWK = . if (ALCWK <= -1 )
replace MRJWK = . if (MRJWK <= -1 )
replace HERWK = . if (HERWK <= -1 )
replace NARWK = . if (NARWK <= -1 )
replace SEDWK = . if (SEDWK <= -1 )
replace AMPWK = . if (AMPWK <= -1 )
replace HALWK = . if (HALWK <= -1 )
replace INHWK = . if (INHWK <= -1 )
replace MRJ_EV = . if (MRJ_EV <= -1 )
replace HER_EV = . if (HER_EV <= -1 )
replace NAR_EV = . if (NAR_EV <= -1 )
replace SED_EV = . if (SED_EV <= -1 )
replace AMP_EV = . if (AMP_EV <= -1 )
replace HAL_EV = . if (HAL_EV <= -1 )
replace INH_EV = . if (INH_EV <= -1 )
replace CJ_STAT = . if (CJ_STAT <= -1 )
replace IAY_SIA = . if (IAY_SIA <= -1 )
replace MAJSRC = . if (MAJSRC <= -1 )
replace REFER = . if (REFER <= -1 )
replace RESTRICT = . if (RESTRICT <= -1 )
replace DRUGTX = . if (DRUGTX <= -1 )
replace SCHOOL = . if (SCHOOL <= -1 )
replace IAPY = . if (IAPY <= -1 )
replace PDT = . if (PDT <= -1 )
replace CRKR = . if (CRKR <= -1 )
replace CRKWK = . if (CRKWK <= -1 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

